@@ -144,8 +144,8 @@ int CL_GetMessage (void) {
     int           r, i;
     float         f;
 
-    if (cl.paused & 2)
-        return 0;
+    //    if (cl.paused & 2)
+    //        return 0;
 
     CheckDZipCompletion ();
     if (dz_unpacking)
@@ -324,7 +324,7 @@ void CL_Record_f (void) {
 
     Con_Printf ("recording to %s\n", name);
     if (!(cls.demofile = fopen (name, "wb"))) {
-        Con_Printf ("ERROR: couldn't open %s\n", name);
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
@@ -410,7 +410,7 @@ void StartPlayingOpenedDemo (void) {
 
     while ((c = getc (cls.demofile)) != '\n') {
         if (c == EOF) {
-            Con_Printf ("ERROR: corrupted demo file\n");
+            Con_Warnf ("Corrupted demo file\n");
             cls.demonum = -1;          // stop demo loop
             return;
         } else if (c == '-')
@@ -458,7 +458,7 @@ static void CheckDZipCompletion (void) {
     dz_unpacking = false;
 
     if (!(cls.demofile = fopen (tempdem_name, "rb"))) {
-        Con_Printf ("ERROR: couldn't open %s\n", tempdem_name);
+        Con_Warnf ("Couldn't open %s\n", tempdem_name);
         dz_playback = cls.demoplayback = false;
         cls.demonum = -1;
         return;
@@ -521,7 +521,7 @@ static void PlayDZDemo (void) {
 
     // check if the file exists
     if (Sys_FileTime (dz_name) == -1) {
-        Con_Printf ("ERROR: couldn't open %s\n", name);
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
@@ -625,7 +625,7 @@ void CL_PlayDemo_f (void) {
 
     // added by joe, but FIXME!
     if (cl_demorewind.value) {
-        Con_Printf ("ERROR: rewind is on\n");
+        Con_Warnf ("Rewind is on\n");
         cls.demonum = -1;
         return;
     }
@@ -646,7 +646,7 @@ void CL_PlayDemo_f (void) {
 
     Con_Printf ("demo: %s\n", name);
     if (!cls.demofile) {
-        Con_Printf ("ERROR: couldn't open %s\n", name);
+        Con_Warnf ("Couldn't open %s\n", name);
         cls.demonum = -1;              // stop demo loop
         return;
     }
