@@ -32,7 +32,6 @@ cvar_t        cl_shownet = { "cl_shownet", "0" };       // can be 0, 1, or 2
 cvar_t        cl_nolerp = { "cl_nolerp", "0" };
 
 cvar_t        cl_truelightning = { "cl_truelightning", "0" };
-cvar_t        cl_sbar = { "cl_sbar", "0", CVAR_ARCHIVE };
 cvar_t        cl_rocket2grenade = { "cl_r2g", "0" };
 cvar_t        cl_mapname = { "mapname", "", CVAR_ROM };
 cvar_t        cl_muzzleflash = { "cl_muzzleflash", "1" };
@@ -53,6 +52,7 @@ cvar_t        cl_demospeed = { "cl_demospeed", "1", 0, OnChange_cl_demospeed };
 
 cvar_t        cl_demorewind = { "cl_demorewind", "0" };
 cvar_t        cl_bobbing = { "cl_bobbing", "0" };
+
 cvar_t        cl_deadbodyfilter = { "cl_deadbodyfilter", "0" };
 cvar_t        cl_gibfilter = { "cl_gibfilter", "0" };
 
@@ -75,7 +75,7 @@ int           cl_numvisedicts;
 entity_t     *cl_visedicts[MAX_VISEDICTS];
 
 modelindex_t  cl_modelindex[NUM_MODELINDEX];
-char         *cl_modelnames[NUM_MODELINDEX];
+char          cl_modelnames[NUM_MODELINDEX][MAX_QPATH];
 
 tagentity_t   q3player_body, q3player_head;
 
@@ -97,7 +97,7 @@ static qboolean OnChange_cl_demospeed (cvar_t * var, char *string) {
 static qboolean OnChange_cl_maxfps (cvar_t * var, char *string) {
     float         newval = Q_atof (string);
 
-    if (!developer.value && (newval < MIN_FPS || newval > MAX_FPS)) {
+    if (newval < MIN_FPS || newval > MAX_FPS) {
         Con_Printf ("%s should be between %d and %d\n", var->name, MIN_FPS, MAX_FPS);
         return true;
     }
@@ -105,6 +105,135 @@ static qboolean OnChange_cl_maxfps (cvar_t * var, char *string) {
     return false;
 }
 
+enum { LEGACY_MODE = 0, NET_MODE, QUORE_MODE };
+
+void CL_SetMode (int mode) {
+    extern cvar_t cl_bob, cl_bobcycle, cl_bobup;
+    extern cvar_t v_kickpitch, v_kickroll, v_kicktime;
+    extern cvar_t v_ofsy;
+
+    switch (mode) {
+        case QUORE_MODE:
+#ifdef GLQUAKE
+            if (!ambiencehd.value)
+                Cvar_ForceSet (&ambience, "underworld");
+            Cvar_SetValue (&ambiencehd, 1);
+            Cvar_ForceSet (&r_quality, "1");
+            Cvar_SetValue (&scr_hudsize, 0.5);
+#endif
+            Cvar_ResetVar (&cl_bob);
+            Cvar_ResetVar (&cl_bobcycle);
+            Cvar_ResetVar (&cl_bobup);
+            Cvar_SetValue (&scr_viewsize, 120);
+            Cvar_SetValue (&sv_healthimpact, 1);
+            Cvar_ResetVar (&v_kickroll);
+            Cvar_ResetVar (&v_kickpitch);
+            Cvar_ResetVar (&v_kicktime);
+            legacy = 0;
+            quore = 1;
+            break;
+        case LEGACY_MODE:
+#ifdef GLQUAKE
+            Cvar_ForceSet (&ambience, "quake");
+            Cvar_SetValue (&ambiencehd, 0);
+            Cvar_ForceSet (&r_quality, "0.5");
+            Cvar_SetValue (&scr_hudsize, 1.5);     // lxndr: welcome years back
+#endif
+            Cvar_SetValue (&cl_bob, 0.02);
+            Cvar_SetValue (&cl_bobcycle, 0.6);
+            Cvar_SetValue (&cl_bobup, 0.5);
+            Cvar_SetValue (&scr_sbar, 1);
+            Cvar_SetValue (&sv_healthimpact, 0);
+            Cvar_SetValue (&scr_viewsize, 100);
+            Cvar_SetValue (&sv_healthimpact, 0);
+            Cvar_SetValue (&v_idlescale, 0);
+            Cvar_SetValue (&v_ofsy, 0);
+            legacy = 1;
+            quore = 0;
+            break;
+        case NET_MODE:
+#ifdef GLQUAKE
+            Cvar_ForceSet (&ambience, "quake");
+            Cvar_SetValue (&ambiencehd, 0);
+            Cvar_ForceSet (&r_quality, "0.5");
+            Cvar_SetValue (&scr_hudsize, 0.8);
+#endif
+            Cvar_SetValue (&scr_viewsize, 100);
+            Cvar_SetValue (&sv_healthimpact, 0);
+            Cvar_SetValue (&v_idlescale, 0);
+            legacy = 0;
+            quore = 0;
+            break;
+    }
+}
+
+int CL_CheckMode (void) {
+    if (legacy && !v_idlescale.value && !sv_healthimpact.value)
+        return LEGACY_MODE;
+    else if (!legacy && !v_idlescale.value && !sv_healthimpact.value)
+        return NET_MODE;
+    else if (quore)
+        return QUORE_MODE;
+    else
+        return -1;
+}
+
+const char* CL_GetModeString () {
+    switch (CL_CheckMode ()) {
+        case LEGACY_MODE:
+            return "legacy";
+        case NET_MODE:
+            return "net";
+        case QUORE_MODE:
+            return "quore";
+        default:
+            return "none";
+    }
+}
+
+void CL_Mode_f (void) {
+    if (!strcmp (Cmd_Argv (1), "quore")) {
+        CL_SetMode (QUORE_MODE);
+    } else if (!strcmp (Cmd_Argv (1), "legacy")) {
+        CL_SetMode (LEGACY_MODE);
+    } else if (!strcmp (Cmd_Argv (1), "net")) {
+        CL_SetMode (NET_MODE);
+    } else if (Cmd_Argc () == 2) {
+        Con_Printf ("Usage: mode {legacy|quore|net}\n");
+    } else {
+        Con_Printf ("Usage: mode {legacy|quore|net}\n");
+        Con_Printf ("current mode is %s\n", CL_GetModeString ());
+    }
+}
+
+void CL_Mode_Next_f (void) {
+    int i = CL_CheckMode ();
+
+    switch (i) {
+        case LEGACY_MODE:
+        case NET_MODE:
+            CL_SetMode (i + 1);
+            break;
+        default:
+            CL_SetMode (0);
+            break;
+    }
+}
+
+void CL_Mode_Prev_f (void) {
+    int i = CL_CheckMode ();
+
+    switch (i) {
+        case NET_MODE:
+        case QUORE_MODE:
+            CL_SetMode (i - 1);
+            break;
+        default:
+            CL_SetMode (QUORE_MODE);
+            break;
+    }
+}
+
 /*
  * CL_ClearState
  */
@@ -174,6 +303,9 @@ void CL_Disconnect (void) {
         FMOD_Stop_f ();
 #endif
 
+    cls.signon = 0;
+    SCR_UpdateScreen ();               // lxndr: clear the screen before doing anything
+
     // if running a local server, shut it down
     if (cls.demoplayback) {
         CL_StopPlayback ();
@@ -194,7 +326,6 @@ void CL_Disconnect (void) {
     }
 
     cls.demoplayback = cls.timedemo = false;
-    cls.signon = 0;
 
 #ifdef GLQUAKE
     if (nehahra)
@@ -536,28 +667,32 @@ void CL_MuzzleFlash (entity_t * ent, int num) {
 
     dl = CL_AllocDlight (num);
     VectorCopy (ent->origin, dl->origin);
-    dl->origin[2] += 16;
+    dl->origin[2] += 32;               // lxndr: was 16
     AngleVectors (ent->angles, fv, NULL, NULL);
     VectorMA (dl->origin, 18, fv, dl->origin);
     dl->radius = 200 + (rand () & 31);
     dl->minlight = 32;
     dl->die = cl.time + 0.1;
 #ifdef GLQUAKE
-    if ((ent->modelindex == cl_modelindex[mi_shambler]
-         || (ent->model->modhint == MOD_PLAYER && cl.stats[STAT_ACTIVEWEAPON] == IT_LIGHTNING))
-        && qmb_initialized && gl_part_lightning.value)
-        dl->type = lt_blue;
-    else if (ent->modelindex == cl_modelindex[mi_scrag] && qmb_initialized)
-        dl->type = lt_green;
-    else
-        dl->type = lt_muzzleflash;
+    if (gl_polyblend.value) {
+        if (ent->modelindex == cl_modelindex[mi_shambler])
+           dl->type = lt_blue;
+        else if (ent->modelindex == cl_modelindex[mi_player] && cl.stats[STAT_ACTIVEWEAPON] == IT_LIGHTNING)
+           dl->type = lt_blue;
+        else if (ent->modelindex == cl_modelindex[mi_scrag])
+           dl->type = lt_green;
+        else if (ent->modelindex == cl_modelindex[mi_vore])
+           dl->type = lt_redblue;
+        else
+           dl->type = lt_muzzleflash;
+    }
     if (num == cl.viewentity && qmb_initialized && gl_part_muzzleflash.value) {
         vec3_t        rv, uv, smokeorg, smokeorg2;
 
         VectorCopy (cl_entities[cl.viewentity].origin, smokeorg);
         smokeorg[2] += cl.crouch;
 
-        smokeorg[2] += 14;             // move it up
+        smokeorg[2] += 8;              // move it up // lxndr: was 14
 
         // adjust for current view angles
         AngleVectors (cl.viewangles, fv, rv, uv);
@@ -584,7 +719,7 @@ void CL_OtherDlightSettings (entity_t * ent, int num) {
     if (ent->modelindex != cl_modelindex[mi_eyes]
         && ((ent->modelindex != cl_modelindex[mi_player] && ent->modelindex != cl_modelindex[mi_h_player]
              && ent->model->modhint != MOD_PLAYER)
-            || r_powerupglow.value)) { // lxndr: removed STAT_HEALTH check
+            || (r_powerupglow.value && cl.stats[STAT_HEALTH] > 0))) {
         if ((ent->effects & (EF_BLUE | EF_RED)) == (EF_BLUE | EF_RED)) {
             CL_NewDlight (num, ent->origin, 200 + (rand () & 31), 0.1, lt_redblue);
         } else if (ent->effects & EF_BLUE) {
@@ -618,7 +753,7 @@ qboolean CL_Trail (entity_t * ent, int num) {
         Host_Error ("CL_EntityTrail: bad modelindex");
 
     if (model->flags) {
-        if (!ent->traildrawn /*|| !VectorL2Compare (ent->trail_origin, ent->origin, 140) */ ) {
+        if (!ent->traildrawn || !VectorL2Compare (ent->trail_origin, ent->origin, 140)) {
             VectorCopy (ent->origin, oldorg);   // not present last frame or too far away
             ent->traildrawn = true;
         } else {
@@ -845,6 +980,8 @@ void CL_RelinkEntities (void) {
 
         if (cl_numvisedicts < MAX_VISEDICTS)
             cl_visedicts[cl_numvisedicts++] = ent;
+        else
+            COM_CheckLimit (cl_numvisedicts, MAX_VISEDICTS);
     }
 }
 
@@ -1040,7 +1177,6 @@ void CL_Init (void) {
     Cvar_Register (&cl_nolerp);
 
     Cvar_Register (&cl_truelightning);
-    Cvar_Register (&cl_sbar);
     Cvar_Register (&cl_rocket2grenade);
     Cvar_Register (&cl_mapname);
     Cvar_Register (&cl_muzzleflash);
@@ -1066,6 +1202,10 @@ void CL_Init (void) {
     Cvar_Register (&cl_advancedcompletion);
     Cvar_Register (&cl_independentphysics);
 
+    Cmd_AddCommand ("mode", CL_Mode_f);
+    Cmd_AddCommand ("modenext", CL_Mode_Next_f);
+    Cmd_AddCommand ("modeprev", CL_Mode_Prev_f);
+
     Cmd_AddCommand ("entities", CL_PrintEntities_f);
     Cmd_AddCommand ("disconnect", CL_Disconnect_f);
     Cmd_AddCommand ("record", CL_Record_f);
