@@ -74,9 +74,9 @@ char         *svc_strings[] = {
     "svc_skybox",                      // [string] skyname
     "?",                               // 38
     "?",                               // 39
-    "?",                               // 40
-    "?",                               // 41
-    "?",                               // 42
+    "svc_spawnbaseline2",              // 40
+    "svc_spawnstatic2",                // 41
+    "svc_spawnstaticsound2",           // 42
     "?",                               // 43
     "?",                               // 44
     "?",                               // 45
@@ -89,54 +89,58 @@ char         *svc_strings[] = {
 // 
 
 void CL_InitModelnames (void) {
-    int           i;
+    //    int           i;
 
     memset (cl_modelnames, 0, sizeof (cl_modelnames));
 
-    cl_modelnames[mi_player] = "progs/player.mdl";
-    cl_modelnames[mi_q3torso] = "progs/player/upper.md3";
-    cl_modelnames[mi_q3head] = "progs/player/head.md3";
-    cl_modelnames[mi_h_player] = "progs/h_player.mdl";
-    cl_modelnames[mi_eyes] = "progs/eyes.mdl";
-    cl_modelnames[mi_rocket] = "progs/missile.mdl";
-    cl_modelnames[mi_grenade] = "progs/grenade.mdl";
-    cl_modelnames[mi_flame0] = "progs/flame.mdl";       // lxndr: was flame0
-    cl_modelnames[mi_flame0_md3] = "progs/flame.md3";
-    cl_modelnames[mi_flame1] = "progs/flame.mdl";
-    cl_modelnames[mi_flame2] = "progs/flame2.mdl";
-    cl_modelnames[mi_explo1] = "progs/s_explod.spr";
-    cl_modelnames[mi_explo2] = "progs/s_expl.spr";
-    cl_modelnames[mi_bubble] = "progs/s_bubble.spr";
-    cl_modelnames[mi_gib1] = "progs/gib1.mdl";
-    cl_modelnames[mi_gib2] = "progs/gib2.mdl";
-    cl_modelnames[mi_gib3] = "progs/gib3.mdl";
-    cl_modelnames[mi_fish] = "progs/fish.mdl";
-    cl_modelnames[mi_dog] = "progs/dog.mdl";
-    cl_modelnames[mi_soldier] = "progs/soldier.mdl";
-    cl_modelnames[mi_enforcer] = "progs/enforcer.mdl";
-    cl_modelnames[mi_knight] = "progs/knight.mdl";
-    cl_modelnames[mi_hknight] = "progs/hknight.mdl";
-    cl_modelnames[mi_scrag] = "progs/wizard.mdl";
-    cl_modelnames[mi_ogre] = "progs/ogre.mdl";
-    cl_modelnames[mi_fiend] = "progs/demon.mdl";
-    cl_modelnames[mi_vore] = "progs/shalrath.mdl";
-    cl_modelnames[mi_shambler] = "progs/shambler.mdl";
-    cl_modelnames[mi_h_dog] = "progs/h_dog.mdl";
-    cl_modelnames[mi_h_soldier] = "progs/h_guard.mdl";
-    cl_modelnames[mi_h_enforcer] = "progs/h_mega.mdl";
-    cl_modelnames[mi_h_knight] = "progs/h_knight.mdl";
-    cl_modelnames[mi_h_hknight] = "progs/h_hellkn.mdl";
-    cl_modelnames[mi_h_scrag] = "progs/h_wizard.mdl";
-    cl_modelnames[mi_h_ogre] = "progs/h_ogre.mdl";
-    cl_modelnames[mi_h_fiend] = "progs/h_demon.mdl";
-    cl_modelnames[mi_h_vore] = "progs/h_shal.mdl";
-    cl_modelnames[mi_h_shambler] = "progs/h_shams.mdl";
-    cl_modelnames[mi_h_zombie] = "progs/h_zombie.mdl";
+    // lxndr: changed *cl_modelnames[NUM_MODELINDEX] for cl_modelnames[NUM_MODELINDEX][MAX_QPATH]
+    Q_strcpy (cl_modelnames[mi_player], "progs/player.mdl");
+    Q_strcpy (cl_modelnames[mi_q3torso], "progs/player/upper.md3");
+    Q_strcpy (cl_modelnames[mi_q3head], "progs/player/head.md3");
+    Q_strcpy (cl_modelnames[mi_h_player], "progs/h_player.mdl");
+    Q_strcpy (cl_modelnames[mi_eyes], "progs/eyes.mdl");
+    Q_strcpy (cl_modelnames[mi_rocket], "progs/missile.mdl");
+    Q_strcpy (cl_modelnames[mi_grenade], "progs/grenade.mdl");
+    Q_strcpy (cl_modelnames[mi_flame0], "progs/flame.mdl");     // lxndr: was flame0
+    Q_strcpy (cl_modelnames[mi_flame0_md3], "progs/flame.md3");
+    Q_strcpy (cl_modelnames[mi_flame1], "progs/flame.mdl");
+    Q_strcpy (cl_modelnames[mi_flame2], "progs/flame2.mdl");
+    Q_strcpy (cl_modelnames[mi_explo1], "progs/s_explod.spr");
+    Q_strcpy (cl_modelnames[mi_explo2], "progs/s_expl.spr");
+    Q_strcpy (cl_modelnames[mi_bubble], "progs/s_bubble.spr");
+    Q_strcpy (cl_modelnames[mi_gib1], "progs/gib1.mdl");
+    Q_strcpy (cl_modelnames[mi_gib2], "progs/gib2.mdl");
+    Q_strcpy (cl_modelnames[mi_gib3], "progs/gib3.mdl");
+    Q_strcpy (cl_modelnames[mi_fish], "progs/fish.mdl");
+    Q_strcpy (cl_modelnames[mi_dog], "progs/dog.mdl");
+    Q_strcpy (cl_modelnames[mi_soldier], "progs/soldier.mdl");
+    Q_strcpy (cl_modelnames[mi_enforcer], "progs/enforcer.mdl");
+    Q_strcpy (cl_modelnames[mi_knight], "progs/knight.mdl");
+    Q_strcpy (cl_modelnames[mi_hknight], "progs/hknight.mdl");
+    Q_strcpy (cl_modelnames[mi_scrag], "progs/wizard.mdl");
+    Q_strcpy (cl_modelnames[mi_ogre], "progs/ogre.mdl");
+    Q_strcpy (cl_modelnames[mi_fiend], "progs/demon.mdl");
+    Q_strcpy (cl_modelnames[mi_vore], "progs/shalrath.mdl");
+    Q_strcpy (cl_modelnames[mi_shambler], "progs/shambler.mdl");
+    Q_strcpy (cl_modelnames[mi_h_dog], "progs/h_dog.mdl");
+    Q_strcpy (cl_modelnames[mi_h_soldier], "progs/h_guard.mdl");
+    Q_strcpy (cl_modelnames[mi_h_enforcer], "progs/h_mega.mdl");
+    Q_strcpy (cl_modelnames[mi_h_knight], "progs/h_knight.mdl");
+    Q_strcpy (cl_modelnames[mi_h_hknight], "progs/h_hellkn.mdl");
+    Q_strcpy (cl_modelnames[mi_h_scrag], "progs/h_wizard.mdl");
+    Q_strcpy (cl_modelnames[mi_h_ogre], "progs/h_ogre.mdl");
+    Q_strcpy (cl_modelnames[mi_h_fiend], "progs/h_demon.mdl");
+    Q_strcpy (cl_modelnames[mi_h_vore], "progs/h_shal.mdl");
+    Q_strcpy (cl_modelnames[mi_h_shambler], "progs/h_shams.mdl");
+    Q_strcpy (cl_modelnames[mi_h_zombie], "progs/h_zombie.mdl");
 
-    for (i = 0; i < NUM_MODELINDEX; i++) {
-        if (!cl_modelnames[i])
-            Sys_Error ("cl_modelnames[%d] not initialized", i);
-    }
+    // lxndr: TESTME: see CL_ParseServerInfo
+    /*
+     * for (i = 0; i < NUM_MODELINDEX; i++) {
+     * if (!cl_modelnames[i])
+     * Sys_Error ("cl_modelnames[%d] not initialized", i);
+     * }
+     */
 }
 
 /*
@@ -246,29 +250,31 @@ void CL_KeepaliveMessage (void) {
     SZ_Clear (&cls.message);
 }
 
-char          model_precache[MAX_MODELS][MAX_QPATH];
 #ifdef __DEVEL__
 extern int    mod_numknown;
 void CL_ReloadModels (void) {
     int           i;
     int           t;
     model_t      *mod;
+    char          model_precache[MAX_MODELS][MAX_QPATH];
 
     //    memset (cl.model_precache, 0, sizeof (cl.model_precache));
     //    Mod_ClearAll ();
     t = mod_numknown;
 
+#  ifdef GLQUAKE
     GL_ResetTextures ();
+#  endif
 
     for (i = 1; i < t; i++) {
         mod = Mod_FindName (model_precache[i]);
         if (mod) {
-            if (mod->type == mod_brush || mod->type == mod_alias || mod->type == mod_md3) {
+            if (mod->type == mod_brush || mod->type == mod_alias /*|| mod->type == mod_md3 */ ) {
                 mod->needload = true;
                 if (!Cache_Check (&mod->cache)) {
-                    Con_Printf ("model %s %i found but not in cache, aborting\n", model_precache[i], i);
+                    Con_Printf ("model %s %i found but not in cache, aborting\n", cl.model_precache[i], i);
                 } else {
-                    Con_Printf ("model %s %i found in cache\n", model_precache[i], i);
+                    Con_Printf ("model %s %i found in cache\n", cl.model_precache[i], i);
                     Cache_Free (&mod->cache);
                 }
                 cl.model_precache[i] = Mod_ForName (model_precache[i], false);
@@ -287,18 +293,62 @@ void CL_ReloadModels (void) {
 }
 #endif
 
+#ifdef GLQUAKE
+void CL_PrecacheQ3models (int nummodels, char **str) {
+    char          tempname[MAX_QPATH];
+    extern qboolean r_loadq3player;
+    if (gl_loadq3models.value) {
+        if (!strcmp (*str, cl_modelnames[mi_player]) && COM_FindFile ("progs/player/head.md3")
+            && COM_FindFile ("progs/player/upper.md3")
+            && COM_FindFile ("progs/player/lower.md3")) {
+            Q_strncpyz (tempname, "progs/player/lower.md3", MAX_QPATH);
+            *str = tempname;
+            cl_modelindex[mi_player] = nummodels;
+            r_loadq3player = true;
+        } else {
+            COM_StripExtension (*str, tempname);
+            strcat (tempname, ".md3");
+            if (COM_FindFile (tempname))
+                *str = tempname;
+        }
+    }
+}
+
+void CL_PrecacheExtramodels (int nummodels, char *model_precache[MAX_QPATH]) {
+    extern qboolean r_loadq3player;
+    // load the extra "no-flamed-torch" model
+    if (nummodels == MAX_MODELS) {
+        Con_Printf ("Server sent too many model precaches -> replacing flame0.mdl with flame.mdl\n");
+        cl_modelindex[mi_flame0] = cl_modelindex[mi_flame1];
+    } else {
+        Q_strncpyz (model_precache[nummodels], cl_modelnames[mi_flame0], sizeof (model_precache[nummodels]));
+        cl_modelindex[mi_flame0] = nummodels++;
+    }
+    // load the rest of the q3 player model if possible
+    if (r_loadq3player) {
+        if (nummodels + 1 >= MAX_MODELS) {
+            Con_Printf ("Server sent too many model precaches -> can't load Q3 player model\n");
+            Q_strncpyz (model_precache[cl_modelindex[mi_player]], cl_modelnames[mi_player],
+                        sizeof (model_precache[cl_modelindex[mi_player]]));
+        } else {
+            Q_strncpyz (model_precache[nummodels], "progs/player/upper.md3", sizeof (model_precache[nummodels]));
+            cl_modelindex[mi_q3torso] = nummodels++;
+            Q_strncpyz (model_precache[nummodels], "progs/player/head.md3", sizeof (model_precache[nummodels]));
+            cl_modelindex[mi_q3head] = nummodels++;
+        }
+    }
+}
+#endif
+
 /*
  * CL_ParseServerInfo
  */
 void CL_ParseServerInfo (void) {
     int           i, nummodels, numsounds;
     char         *str, tempname[MAX_QPATH];
-    //    char          model_precache[MAX_MODELS][MAX_QPATH], sound_precache[MAX_SOUNDS][MAX_QPATH];
+    char          model_precache[MAX_MODELS][MAX_QPATH];
     char          sound_precache[MAX_SOUNDS][MAX_QPATH];
     extern void   R_PreMapLoad (char *);
-#ifdef GLQUAKE
-    extern qboolean r_loadq3player;
-#endif
 
     Con_DPrintf ("\nServerinfo packet received\n");
 
@@ -327,8 +377,7 @@ void CL_ParseServerInfo (void) {
     strncpy (cl.levelname, str, sizeof (cl.levelname) - 1);
 
     // seperate the printfs so the server message can have a color
-    Con_Printf
-        ("\n\n\35\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\36\37\n\n");
+    Con_Printf ("\n\n%s\n", LINESEP);
     Con_Printf ("%c%s\n", 2, str);
 
     // first we go through and touch all of the precache data that still
@@ -348,56 +397,31 @@ void CL_ParseServerInfo (void) {
             Host_Error ("Server sent too many model precaches");
 
 #ifdef GLQUAKE
-        if (gl_loadq3models.value) {
-            if (!strcmp (str, cl_modelnames[mi_player]) && COM_FindFile ("progs/player/head.md3")
-                && COM_FindFile ("progs/player/upper.md3")
-                && COM_FindFile ("progs/player/lower.md3")) {
-                Q_strncpyz (tempname, "progs/player/lower.md3", MAX_QPATH);
-                str = tempname;
-                cl_modelindex[mi_player] = nummodels;
-                r_loadq3player = true;
-            } else {
-                COM_StripExtension (str, tempname);
-                strcat (tempname, ".md3");
-
-                if (COM_FindFile (tempname))
-                    str = tempname;
-            }
-        }
+        CL_PrecacheQ3models (nummodels, &str);
 #endif
 
         Q_strncpyz (model_precache[nummodels], str, sizeof (model_precache[nummodels]));
-
         for (i = 0; i < NUM_MODELINDEX; i++) {
-            if (!strcmp (cl_modelnames[i], model_precache[nummodels])) {
-                cl_modelindex[i] = nummodels;
-                break;
+            if (cl_modelnames[i][0]) {
+                if (!strcmp (cl_modelnames[i], model_precache[nummodels])) {
+                    cl_modelindex[i] = nummodels;
+                    break;
+                }
+                /*
+                 * } else {
+                 * Q_strncpyz (cl_modelnames[i], str, sizeof (cl_modelnames[i]));
+                 * cl_modelindex[i] = nummodels;
+                 * break;
+                 */
             }
         }
+        //        if (i == NUM_MODELINDEX)
+        //            Con_DPrintf ("CL_ParseServerInfo: ", str);
     }
 #ifdef GLQUAKE
-    // load the extra "no-flamed-torch" model
-    if (nummodels == MAX_MODELS) {
-        Con_Printf ("Server sent too many model precaches -> replacing flame0.mdl with flame.mdl\n");
-        cl_modelindex[mi_flame0] = cl_modelindex[mi_flame1];
-    } else {
-        Q_strncpyz (model_precache[nummodels], cl_modelnames[mi_flame0], sizeof (model_precache[nummodels]));
-        cl_modelindex[mi_flame0] = nummodels++;
-    }
-    // load the rest of the q3 player model if possible
-    if (r_loadq3player) {
-        if (nummodels + 1 >= MAX_MODELS) {
-            Con_Printf ("Server sent too many model precaches -> can't load Q3 player model\n");
-            Q_strncpyz (model_precache[cl_modelindex[mi_player]], cl_modelnames[mi_player],
-                        sizeof (model_precache[cl_modelindex[mi_player]]));
-        } else {
-            Q_strncpyz (model_precache[nummodels], "progs/player/upper.md3", sizeof (model_precache[nummodels]));
-            cl_modelindex[mi_q3torso] = nummodels++;
-            Q_strncpyz (model_precache[nummodels], "progs/player/head.md3", sizeof (model_precache[nummodels]));
-            cl_modelindex[mi_q3head] = nummodels++;
-        }
-    }
+    //    CL_PrecacheExtramodels (nummodels, (char **) model_precache);
 #endif
+    COM_CheckLimit (nummodels, MAX_MODELS);
 
     // precache sounds
     memset (cl.sound_precache, 0, sizeof (cl.sound_precache));
@@ -411,6 +435,7 @@ void CL_ParseServerInfo (void) {
         Q_strncpyz (sound_precache[numsounds], str, sizeof (sound_precache[numsounds]));
         S_TouchSound (str);
     }
+    COM_CheckLimit (numsounds, MAX_SOUNDS);
 
     COM_StripExtension (COM_SkipPath (model_precache[1]), tempname);
     R_PreMapLoad (tempname);
@@ -462,8 +487,7 @@ void CL_ParseUpdate (int bits) {
     int           skin;
 #endif
 
-    if (cls.signon == SIGNONS - 1) {   // first update is the final signon
-        // stage
+    if (cls.signon == SIGNONS - 1) {   // first update is the final signon stage
         cls.signon = SIGNONS;
         CL_SignonReply ();
     }
@@ -471,6 +495,10 @@ void CL_ParseUpdate (int bits) {
     if (bits & U_MOREBITS)
         bits |= (MSG_ReadByte () << 8);
 
+    // lxndr: from fitzquake
+    if (bits & U_EXTEND1)
+        bits |= (MSG_ReadByte () << 16);
+
     num = (bits & U_LONGENTITY) ? MSG_ReadShort () : MSG_ReadByte ();
 
     ent = CL_EntityNum (num);
@@ -485,27 +513,13 @@ void CL_ParseUpdate (int bits) {
 
     if (bits & U_MODEL) {
         ent->modelindex = MSG_ReadByte ();
+
         if (ent->modelindex >= MAX_MODELS)
             Host_Error ("CL_ParseUpdate: bad modelindex");
     } else {
         ent->modelindex = ent->baseline.modelindex;
     }
 
-    model = cl.model_precache[ent->modelindex];
-    if (model != ent->model) {
-        ent->model = model;
-        // automatic animation (torches, etc) can be either all together or
-        // randomized
-        if (model)
-            ent->syncbase = (model->synctype == ST_RAND) ? (float) (rand () & 0x7fff) / 0x7fff : 0.0;
-        else
-            forcelink = true;          // hack to make null model players work
-#ifdef GLQUAKE
-        if (num > 0 && num <= cl.maxclients)
-            R_TranslatePlayerSkin (num - 1);
-#endif
-    }
-
     ent->frame = (bits & U_FRAME) ? MSG_ReadByte () : ent->baseline.frame;
 
     i = (bits & U_COLORMAP) ? MSG_ReadByte () : ent->baseline.colormap;
@@ -540,6 +554,29 @@ void CL_ParseUpdate (int bits) {
     ent->msg_origins[0][2] = (bits & U_ORIGIN3) ? MSG_ReadCoord () : ent->baseline.origin[2];
     ent->msg_angles[0][2] = (bits & U_ANGLE3) ? MSG_ReadAngle () : ent->baseline.angles[2];
 
+    if (bits & U_NOLERP)
+        ent->forcelink = true;
+
+    // lxndr: from fitzquake
+    if (bits & U_FRAME2)
+        ent->frame = (ent->frame & 0x00FF) | (MSG_ReadByte () << 8);
+    if (bits & U_MODEL2)
+        ent->modelindex = (ent->modelindex & 0x00FF) | (MSG_ReadByte () << 8);
+
+    model = cl.model_precache[ent->modelindex];
+    if (model != ent->model) {
+        ent->model = model;
+        // automatic animation (torches, etc) can be either all together or randomized
+        if (model)
+            ent->syncbase = (model->synctype == ST_RAND) ? (float) (rand () & 0x7fff) / 0x7fff : 0.0;
+        else
+            forcelink = true;          // hack to make null model players work
+#ifdef GLQUAKE
+        if (num > 0 && num <= cl.maxclients)
+            R_TranslatePlayerSkin (num - 1);
+#endif
+    }
+
 #ifdef GLQUAKE
     if (bits & U_TRANS) {
         int           fullbright, temp;
@@ -556,9 +593,6 @@ void CL_ParseUpdate (int bits) {
     }
 #endif
 
-    if (bits & U_NOLERP)
-        ent->forcelink = true;
-
     if (forcelink) {                   // didn't have an update last message
         VectorCopy (ent->msg_origins[0], ent->msg_origins[1]);
         VectorCopy (ent->msg_origins[0], ent->origin);
@@ -571,11 +605,22 @@ void CL_ParseUpdate (int bits) {
 /*
  * CL_ParseBaseline
  */
-void CL_ParseBaseline (entity_t * ent) {
+void CL_ParseBaseline (entity_t * ent, int version) {
     int           i;
+    int           bits = 0;
+
+    // lxndr: from fitzquake
+    if (version)
+        bits = MSG_ReadByte ();
+    if (bits & B_MODEL)
+        ent->baseline.modelindex = MSG_ReadShort ();
+    else
+        ent->baseline.modelindex = MSG_ReadByte ();
+    if (bits & B_FRAME)
+        ent->baseline.frame = MSG_ReadShort ();
+    else
+        ent->baseline.frame = MSG_ReadByte ();
 
-    ent->baseline.modelindex = MSG_ReadByte ();
-    ent->baseline.frame = MSG_ReadByte ();
     ent->baseline.colormap = MSG_ReadByte ();
     ent->baseline.skin = MSG_ReadByte ();
     for (i = 0; i < 3; i++) {
@@ -594,6 +639,13 @@ extern float  cl_ideal_punchangle;
 void CL_ParseClientdata (int bits) {
     int           i, j;
 
+    // lxndr: from fitzquake
+    //    bits = (unsigned short)MSG_ReadShort ();
+    if (bits & SU_EXTEND1)
+        bits |= (MSG_ReadByte () << 16);
+    if (bits & SU_EXTEND2)
+        bits |= (MSG_ReadByte () << 24);
+
     cl.viewheight = (bits & SU_VIEWHEIGHT) ? MSG_ReadChar () : DEFAULT_VIEWHEIGHT;
     cl.idealpitch = (bits & SU_IDEALPITCH) ? MSG_ReadChar () : 0;
 
@@ -658,8 +710,7 @@ void CL_ParseClientdata (int bits) {
     }
 
     i = MSG_ReadByte ();
-
-    if (hipnotic || rogue) {
+    if (hipnotic || rogue || quore) { // lxndr: added quore
         if (cl.stats[STAT_ACTIVEWEAPON] != (1 << i)) {
             cl.stats[STAT_ACTIVEWEAPON] = (1 << i);
             Sbar_Changed ();
@@ -670,6 +721,24 @@ void CL_ParseClientdata (int bits) {
             Sbar_Changed ();
         }
     }
+
+    // lxndr: from fitzquake
+    if (bits & SU_WEAPON2)
+        cl.stats[STAT_WEAPON] |= (MSG_ReadByte () << 8);
+    if (bits & SU_ARMOR2)
+        cl.stats[STAT_ARMOR] |= (MSG_ReadByte () << 8);
+    if (bits & SU_AMMO2)
+        cl.stats[STAT_AMMO] |= (MSG_ReadByte () << 8);
+    if (bits & SU_SHELLS2)
+        cl.stats[STAT_SHELLS] |= (MSG_ReadByte () << 8);
+    if (bits & SU_NAILS2)
+        cl.stats[STAT_NAILS] |= (MSG_ReadByte () << 8);
+    if (bits & SU_ROCKETS2)
+        cl.stats[STAT_ROCKETS] |= (MSG_ReadByte () << 8);
+    if (bits & SU_CELLS2)
+        cl.stats[STAT_CELLS] |= (MSG_ReadByte () << 8);
+    if (bits & SU_WEAPONFRAME2)
+        cl.stats[STAT_WEAPONFRAME] |= (MSG_ReadByte () << 8);
 }
 
 /*
@@ -693,8 +762,7 @@ void CL_NewTranslation (int slot) {
 #endif
 
     for (i = 0; i < VID_GRADES; i++, dest += 256, source += 256) {
-        if (top < 128)                 // the artists made some backward
-            // ranges. sigh.
+        if (top < 128)                 // the artists made some backward ranges. sigh.
             memcpy (dest + TOP_RANGE, source + top, 16);
         else
             for (j = 0; j < 16; j++)
@@ -711,14 +779,14 @@ void CL_NewTranslation (int slot) {
 /*
  * CL_ParseStatic
  */
-void CL_ParseStatic (void) {
+void CL_ParseStatic (int version) {
     entity_t     *ent;
 
     if (cl.num_statics >= MAX_STATIC_ENTITIES)
         Host_Error ("Too many static entities");
     ent = &cl_static_entities[cl.num_statics];
     cl.num_statics++;
-    CL_ParseBaseline (ent);
+    CL_ParseBaseline (ent, version);
 
     // copy it to the current state
     ent->model = cl.model_precache[ent->baseline.modelindex];
@@ -735,13 +803,19 @@ void CL_ParseStatic (void) {
 /*
  * CL_ParseStaticSound
  */
-void CL_ParseStaticSound (void) {
+void CL_ParseStaticSound (int version) {
     int           i, sound_num, vol, atten;
     vec3_t        org;
 
     for (i = 0; i < 3; i++)
         org[i] = MSG_ReadCoord ();
-    sound_num = MSG_ReadByte ();
+
+    // lxndr: from fitzquake
+    if (version)
+        sound_num = MSG_ReadShort ();
+    else
+        sound_num = MSG_ReadByte ();
+
     vol = MSG_ReadByte ();
     atten = MSG_ReadByte ();
 
@@ -755,11 +829,8 @@ void CL_ParseString (char *string) {
     int           ping;
     char         *s, *s2, *s3;
     static int    checkping = -1;
-    static int    checkip = -1;        // player whose IP address we're
-    // expecting
-    static int    remove_status = 0, begin_status = 0, playercount = 0; // for
-    // ip
-    // logging
+    static int    checkip = -1;        // player whose IP address we're expecting
+    static int    remove_status = 0, begin_status = 0, playercount = 0; // for ip logging
 
     s = string;
     if (!strcmp (string, "Client ping times:\n")) {
@@ -891,7 +962,7 @@ void CL_ParseServerMessage (void) {
         // other commands
         switch (cmd) {
             default:
-                Host_Error ("CL_ParseServerMessage: Illegible server message");
+                Host_Error ("CL_ParseServerMessage: Illegible server message (%d)", cmd);
                 break;
 
             case svc_nop:
@@ -903,7 +974,7 @@ void CL_ParseServerMessage (void) {
                 break;
 
             case svc_clientdata:
-                i = MSG_ReadShort ();
+                i = (unsigned short) MSG_ReadShort ();
                 CL_ParseClientdata (i);
                 break;
 
@@ -938,8 +1009,7 @@ void CL_ParseServerMessage (void) {
 
             case svc_serverinfo:
                 CL_ParseServerInfo ();
-                vid.recalc_refdef = true;       // leave intermission full
-                // screen
+                vid.recalc_refdef = true;       // leave intermission full screen
                 break;
 
             case svc_setangle:
@@ -1000,11 +1070,11 @@ void CL_ParseServerMessage (void) {
             case svc_spawnbaseline:
                 i = MSG_ReadShort ();
                 // must use CL_EntityNum() to force cl.num_entities up
-                CL_ParseBaseline (CL_EntityNum (i));
+                CL_ParseBaseline (CL_EntityNum (i), 0);
                 break;
 
             case svc_spawnstatic:
-                CL_ParseStatic ();
+                CL_ParseStatic (0);
                 break;
 
             case svc_temp_entity:
@@ -1050,7 +1120,7 @@ void CL_ParseServerMessage (void) {
                 break;
 
             case svc_spawnstaticsound:
-                CL_ParseStaticSound ();
+                CL_ParseStaticSound (0);
                 break;
 
             case svc_cdtrack:
@@ -1101,6 +1171,21 @@ void CL_ParseServerMessage (void) {
                 Cvar_Set (&r_skybox, MSG_ReadString ());
                 break;
 #endif
+
+                // lxndr: from fitzquake
+            case svc_spawnbaseline2:
+                i = MSG_ReadShort ();
+                // must use CL_EntityNum() to force cl.num_entities up
+                CL_ParseBaseline (CL_EntityNum (i), 1);
+                break;
+
+            case svc_spawnstatic2:
+                CL_ParseStatic (1);
+                break;
+
+            case svc_spawnstaticsound2:
+                CL_ParseStaticSound (1);
+                break;
         }
     }
 }
