@@ -144,11 +144,15 @@ void Cbuf_Execute (void) {
             memcpy (text, text + i, cmd_text.cursize);
         }
 
+#ifdef __DEBUG__
+        if (developer.value > 1)
+            Sys_Printf ("Cbuf_Execute: %s\n", line);
+#endif
+
         // execute the command line
         Cmd_ExecuteString (line, src_command);
 
-        if (cmd_wait) {                // skip out while text still remains in
-            // buffer, leaving it for next frame
+        if (cmd_wait) {                // skip out while text still remains in buffer, leaving it for next frame
             cmd_wait = false;
             break;
         }
@@ -264,7 +268,7 @@ void Cmd_Exec_f (void) {
         }
 
         if (!f) {
-            Con_Printf ("couldn't exec %s\n", name);
+            Con_Warnf ("Couldn't exec %s\n", name);
             return;
         }
     }
@@ -378,7 +382,7 @@ legacycmd_t  *Cmd_FindLegacyCommand (char *oldname) {
 
 static qboolean Cmd_LegacyCommand (void) {
     char          text[1024];
-    qboolean      recursive = false;
+    static qboolean recursive = false;
     legacycmd_t  *cmd;
 
     for (cmd = legacycmds; cmd; cmd = cmd->next)
@@ -861,6 +865,7 @@ void Cmd_Dir_f (void) {
     PrintEntries ();
 }
 
+#ifdef _WIN32
 static void toLower (char *str) {      // for strings
     char         *s;
     int           i;
@@ -875,16 +880,17 @@ static void toLower (char *str) {      // for strings
         s++;
     }
 }
+#endif
 
 static void AddNewEntry (char *fname, int ftype, long fsize) {
     int           i, pos;
 
     filelist = Q_realloc (filelist, (num_files + 1) * sizeof (direntry_t));
 
-    //#ifdef _WIN32
+#ifdef _WIN32
     toLower (fname);                   // lxndr: marker
     // else don't convert, linux is case sensitive
-    //#endif
+#endif
 
     // inclusion sort
     for (i = 0; i < num_files; i++) {
@@ -910,10 +916,10 @@ static void AddNewEntry (char *fname, int ftype, long fsize) {
 static void AddNewEntry_unsorted (char *fname, int ftype, long fsize) {
     filelist = Q_realloc (filelist, (num_files + 1) * sizeof (direntry_t));
 
-    //#ifdef _WIN32
+#ifdef _WIN32
     toLower (fname);                   // lxndr: marker
     // else don't convert, linux is case sensitive
-    //#endif
+#endif
     filelist[num_files].name = Q_strdup (fname);
     filelist[num_files].type = ftype;
     filelist[num_files].size = fsize;
@@ -939,6 +945,19 @@ static qboolean CheckEntryName (char *ename) {
     return false;
 }
 
+qboolean CheckRealBSP (char *bspname) {
+    if (!strcmp (bspname, "b_batt0.bsp") || !strcmp (bspname, "b_batt1.bsp")
+        || !strcmp (bspname, "b_bh10.bsp") || !strcmp (bspname, "b_bh100.bsp")
+        || !strcmp (bspname, "b_bh25.bsp") || !strcmp (bspname, "b_explob.bsp")
+        || !strcmp (bspname, "b_nail0.bsp") || !strcmp (bspname, "b_nail1.bsp")
+        || !strcmp (bspname, "b_rock0.bsp") || !strcmp (bspname, "b_rock1.bsp")
+        || !strcmp (bspname, "b_shell0.bsp") || !strcmp (bspname, "b_shell1.bsp")
+        || !strcmp (bspname, "b_exbox2.bsp"))
+        return false;
+
+    return true;
+}
+
 #define SLASHJMP(x, y)	(x = !(x = strrchr(y, '/')) ? y : x + 1)
 
 /*
@@ -954,7 +973,9 @@ void ReadDir (char *path, char *the_arg) {
     glob_t        fd;
     struct stat   fileinfo;
 #endif
+#ifdef __DEBUG__
     Con_DPrintf ("path:%s arg:%s\n", path, the_arg);
+#endif
 
     if (path[strlen (path) - 1] == '/')
         path[strlen (path) - 1] = 0;
@@ -1050,6 +1071,9 @@ void ReadDir (char *path, char *the_arg) {
             if (RDFlags & RD_MENU_DEMOS && Q_strcasecmp (ext, "dem") && Q_strcasecmp (ext, "dz"))
                 continue;
 
+            if (!Q_strcasecmp (ext, "bsp") && !CheckRealBSP (foundname))
+                continue;
+
             fdtype = 0;
             fdsize = fileinfo.st_size;
             if (Q_strcasecmp (ext, "dz") && RDFlags & (RD_STRIPEXT | RD_MENU_DEMOS)) {
@@ -1090,19 +1114,6 @@ void ReadDir (char *path, char *the_arg) {
     RDFlags = 0;
 }
 
-qboolean CheckRealBSP (char *bspname) {
-    if (!strcmp (bspname, "b_batt0.bsp") || !strcmp (bspname, "b_batt1.bsp")
-        || !strcmp (bspname, "b_bh10.bsp") || !strcmp (bspname, "b_bh100.bsp")
-        || !strcmp (bspname, "b_bh25.bsp") || !strcmp (bspname, "b_explob.bsp")
-        || !strcmp (bspname, "b_nail0.bsp") || !strcmp (bspname, "b_nail1.bsp")
-        || !strcmp (bspname, "b_rock0.bsp") || !strcmp (bspname, "b_rock1.bsp")
-        || !strcmp (bspname, "b_shell0.bsp") || !strcmp (bspname, "b_shell1.bsp")
-        || !strcmp (bspname, "b_exbox2.bsp"))
-        return false;
-
-    return true;
-}
-
 int           pak_files = 0;
 
 /*
@@ -1367,7 +1378,7 @@ void Cmd_PrintTxt_f (void) {
 
     Q_strncpyz (buf, va ("%s/%s", com_gamedir, name), sizeof (buf));
     if (!(f = fopen (buf, "rt"))) {
-        Con_Printf ("ERROR: couldn't open %s\n", name);
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
