@@ -50,11 +50,15 @@ char        **com_argv;
 #define CMDLINE_LENGTH	256
 char          com_cmdline[CMDLINE_LENGTH];
 
-int           rogue = 0, hipnotic = 0, nehahra = 0, runequake = 0, quore = 0;
+qboolean      hipnotic = false, rogue = false;
+qboolean      nehahra = false, quore = false, runequake = false;
+qboolean      legacy = false;
 
 void          COM_Path_f (void);
 void          COM_Gamedir_f (void);
 
+char          debugstr[100];
+
 /*
  *
  * All of Quake's data access is through a hierchal file system, but the
@@ -537,7 +541,8 @@ void         *SZ_GetSpace (sizebuf_t * buf, int length) {
 
     if (buf->cursize + length > buf->maxsize) {
         if (!buf->allowoverflow)
-            Sys_Error ("SZ_GetSpace: overflow without allowoverflow set");
+            Sys_Error ("SZ_GetSpace: overflow without allowoverflow set (c=%d m=%d)", buf->cursize + length,
+                       buf->maxsize);
 
         if (length > buf->maxsize)
             Sys_Error ("SZ_GetSpace: %i is > full buffer size", length);
@@ -786,7 +791,7 @@ void COM_CheckRegistered (void) {
     COM_FOpenFile ("gfx/pop.lmp", &h);
     if (h) {
         Cvar_Set (&cmdline, com_cmdline);
-        Cvar_SetValue (&registered, 1);
+        Cvar_SetDefault (&registered, "1");
         fclose (h);
     }
 }
@@ -846,28 +851,29 @@ void COM_InitArgv (int argc, char **argv) {
     largv[com_argc] = argvdummy;
     com_argv = largv;
 
+    if (COM_CheckParm ("-hipnotic"))
+        hipnotic = true;
     if (COM_CheckParm ("-rogue"))
-        rogue = 1;
-
-    if (COM_CheckParm ("-quoth")) {
-        hipnotic = 1;
-    } else {
-        if (COM_CheckParm ("-hipnotic"))
-            hipnotic = 1;
-    }
+        rogue = true;
 
 #ifdef GLQUAKE
     if (COM_CheckParm ("-nehahra"))
-        nehahra = 1;
+        nehahra = true;
 #endif
 
-    if (COM_CheckParm ("-runequake"))
-        runequake = 1;
+    if (COM_CheckParm ("-legacy"))
+        legacy = true;
     if (COM_CheckParm ("-quore"))
-        quore = 1;
+        quore = true;
+    if (COM_CheckParm ("-quoth"))
+        hipnotic = true;
+    if (COM_CheckParm ("-runequake"))
+        runequake = true;
 
     if (hipnotic && rogue)
         Sys_Error ("You can't run both mission packs at the same time");
+    if (legacy && (hipnotic || quore || rogue || runequake))
+        Sys_Printf ("Undefined behaviour as both legacy and a modification option are enable\n");
 }
 
 /*
@@ -1135,8 +1141,8 @@ int COM_FOpenFile (char *filename, FILE ** file) {
             // look through all the pak file elements
             pak = search->pack;
             for (i = 0; i < pak->numfiles; i++) {
-                if (!strcmp (pak->files[i].name, filename))     // found it!
-                {
+                if (!strcmp (pak->files[i].name, filename)) {   // found it!
+
                     if (developer.value > 1)
                         Sys_Printf ("PackFile: %s : %s\n", pak->filename, filename);
                     // open a new file on the pakfile
@@ -1443,6 +1449,7 @@ void COM_Gamedir_f (void) {
 void COM_InitFilesystem (void) {
     int           i;
     char         *home;
+    searchpath_t *search;
 
     // -basedir <path>
     // Overrides the system supplied base directory (under GAMENAME)
@@ -1462,22 +1469,22 @@ void COM_InitFilesystem (void) {
     // start up with GAMENAME by default (id1)
     COM_AddGameDirectory (va ("%s/" GAMENAME, com_basedir));
 
-    if (COM_CheckParm ("-rogue"))
+    if (rogue)
         COM_AddGameDirectory (va ("%s/rogue", com_basedir));
-    if (COM_CheckParm ("-hipnotic"))
+    if (hipnotic)
         COM_AddGameDirectory (va ("%s/hipnotic", com_basedir));
 
 #ifdef GLQUAKE
-    if (COM_CheckParm ("-nehahra"))
+    if (nehahra)
         COM_AddGameDirectory (va ("%s/nehahra", com_basedir));
 #endif
 
+    if (quore)
+        COM_AddGameDirectory (va ("%s/quore", com_basedir));
     if (COM_CheckParm ("-quoth"))
         COM_AddGameDirectory (va ("%s/quoth", com_basedir));
-    if (COM_CheckParm ("-runequake"))
+    if (runequake)
         COM_AddGameDirectory (va ("%s/runequake", com_basedir));
-    if (COM_CheckParm ("-quore"))
-        COM_AddGameDirectory (va ("%s/quore", com_basedir));
 
     // any set gamedirs will be freed up to here
     com_base_searchpaths = com_searchpaths;
@@ -1498,7 +1505,6 @@ void COM_InitFilesystem (void) {
         // initializing demodir
         Q_snprintfz (demodir, sizeof (demodir), "%s/.%s/demos", home, ENGINE_FSNAME);
         Sys_mkdir (demodir);
-        searchpath_t *search;
         search = Q_malloc (sizeof (searchpath_t));
         Q_strncpyz (search->filename, demodir, sizeof (demodir));
         search->pack = NULL;
