@@ -67,15 +67,19 @@ static float  Diamond4x[4][4] = {
     {0.3f, 0.4f, 0.4f, 0.3f}
 };
 
+static float  BLOOM_ALPHA;
+static float  BLOOM_INTENSITY;
 static int    BLOOM_SIZE;
 
 cvar_t        gl_bloom = { "gl_bloom", "0", CVAR_ARCHIVE };
 cvar_t        gl_bloomalpha = { "gl_bloomalpha", "0.4", CVAR_ARCHIVE };
+cvar_t        gl_bloomcolor = { "gl_bloomcolor", "0.5", CVAR_ARCHIVE };
+cvar_t        gl_bloomdiamond = { "gl_bloomdiamond", "1", CVAR_ARCHIVE };
 cvar_t        gl_bloomdiamondsize = { "gl_bloomdiamondsize", "8", CVAR_INIT };
 cvar_t        gl_bloomintensity = { "gl_bloomintensity", "4", CVAR_ARCHIVE };
 cvar_t        gl_bloomdarken = { "gl_bloomdarken", "2", CVAR_ARCHIVE };
 cvar_t        gl_bloomsamplesize = { "gl_bloomsamplesize", "512", CVAR_INIT };
-cvar_t        gl_bloomfastsample = { "gl_bloomfastsample", "0" };
+cvar_t        gl_bloomfastsample = { "gl_bloomfastsample", "1", CVAR_ARCHIVE };
 
 int           bloomscreentexture;
 int           bloomeffecttexture;
@@ -99,6 +103,8 @@ static float  screenText_tch;
 static int    sample_width;
 static int    sample_height;
 
+static int    current_pass;
+
 // Texture coordinates of adjusted textures.
 static float  sampleText_tcw;
 static float  sampleText_tch;
@@ -205,7 +211,7 @@ void R_Bloom_InitTextures (void) {
     size = screen_texture_width * screen_texture_height * sizeof (int);
     data = Q_malloc (size);
     memset (data, 255, size);
-    //bloomscreentexture = GL_LoadTexture ( "***r_screenbackuptexture***", screen_texture_width, screen_texture_height, data, 0, 4); // false, false, 4);
+    bloomscreentexture = GL_LoadTexture ("***r_screenbackuptexture***", screen_texture_width, screen_texture_height, data, 0, 4);       // false, false, 4);
 
     if (!bloomscreentexture)
         bloomscreentexture = texture_extension_number++;
@@ -244,6 +250,17 @@ void R_Bloom_InitTextures (void) {
 // =================
 void R_InitBloomTextures (void) {
     BLOOM_SIZE = 0;
+
+    Cvar_Register (&gl_bloom);
+    Cvar_Register (&gl_bloomalpha);
+    Cvar_Register (&gl_bloomcolor);
+    Cvar_Register (&gl_bloomdarken);
+    Cvar_Register (&gl_bloomdiamond);
+    Cvar_Register (&gl_bloomdiamondsize);
+    Cvar_Register (&gl_bloomfastsample);
+    Cvar_Register (&gl_bloomintensity);
+    Cvar_Register (&gl_bloomsamplesize);
+
     if (!gl_bloom.value) {
         return;
     }
@@ -252,6 +269,13 @@ void R_InitBloomTextures (void) {
     R_Bloom_InitTextures ();
 }
 
+// =================
+// R_BloomClear
+// =================
+void R_BloomClear (void) {
+    current_pass = 0;
+}
+
 // =================
 // R_Bloom_DrawEffect
 // =================
@@ -260,7 +284,7 @@ void R_Bloom_DrawEffect (void) {
 
     glEnable (GL_BLEND);
     glBlendFunc (GL_ONE, GL_ONE);
-    glColor4f (gl_bloomalpha.value, gl_bloomalpha.value, gl_bloomalpha.value, 1.0f);
+    glColor4f (BLOOM_ALPHA, BLOOM_ALPHA, BLOOM_ALPHA, 1.0f);
     glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
     glBegin (GL_QUADS);
     glTexCoord2f (0, sampleText_tch);
@@ -282,10 +306,9 @@ void R_Bloom_DrawEffect (void) {
 void R_Bloom_GeneratexCross (void) {
     int           i;
     static int    BLOOM_BLUR_RADIUS = 8;
-    //static float  BLOOM_BLUR_INTENSITY = 2.5f;
-    float         BLOOM_BLUR_INTENSITY;
     static float  intensity;
     static float  range;
+    float         rgb[3];
 
     // Setup sample size workspace.
     glViewport (0, 0, sample_width, sample_height);
@@ -297,7 +320,6 @@ void R_Bloom_GeneratexCross (void) {
 
     // Copy small scene into bloomeffecttexture.
     GL_Bind (bloomeffecttexture);
-    //glBindTexture(GL_TEXTURE_2D, bloomeffecttexture);
     glCopyTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, 0, 0, sample_width, sample_height);
 
     // Start modifying the small scene corner.
@@ -316,11 +338,12 @@ void R_Bloom_GeneratexCross (void) {
     }
     // Bluring passes.
     if (BLOOM_BLUR_RADIUS) {
-        glBlendFunc (GL_ONE, GL_ONE);
+        //        glBlendFunc (GL_ONE, GL_ONE);
+        glBlendFunc (GL_ONE, GL_ONE_MINUS_SRC_COLOR);
 
         range = (float) BLOOM_BLUR_RADIUS;
+        R_CalcRGB (gl_bloomcolor.value, 1, (float *) rgb);
 
-        BLOOM_BLUR_INTENSITY = gl_bloomintensity.value;
         //diagonal-cross draw 4 passes to add initial smooth
         glColor4f (0.5f, 0.5f, 0.5f, 1.0);
         R_Bloom_SamplePass (1, 1);
@@ -330,11 +353,11 @@ void R_Bloom_GeneratexCross (void) {
         glCopyTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, 0, 0, sample_width, sample_height);
 
         for (i = -(BLOOM_BLUR_RADIUS + 1); i < BLOOM_BLUR_RADIUS; i++) {
-            intensity = BLOOM_BLUR_INTENSITY / (range * 2 + 1) * (1 - fabs (i * i) / (float) (range * range));
+            intensity = BLOOM_INTENSITY / (range * 2 + 1) * (1 - fabs (i * i) / (float) (range * range));
             if (intensity < 0.05f) {
                 continue;
             }
-            glColor4f (intensity, intensity, intensity, 1.0f);
+            glColor4f (intensity * rgb[0], intensity * rgb[1], intensity * rgb[2], 1.0f);
             R_Bloom_SamplePass (i, 0);
             //R_Bloom_SamplePass( -i, 0 );
         }
@@ -343,11 +366,11 @@ void R_Bloom_GeneratexCross (void) {
 
         //for(i = 0; i < BLOOM_BLUR_RADIUS; i++)
         for (i = -(BLOOM_BLUR_RADIUS + 1); i < BLOOM_BLUR_RADIUS; i++) {
-            intensity = BLOOM_BLUR_INTENSITY / (range * 2 + 1) * (1 - fabs (i * i) / (float) (range * range));
+            intensity = BLOOM_INTENSITY / (range * 2 + 1) * (1 - fabs (i * i) / (float) (range * range));
             if (intensity < 0.05f) {
                 continue;
             }
-            glColor4f (intensity, intensity, intensity, 1.0f);
+            glColor4f (intensity * rgb[0], intensity * rgb[1], intensity * rgb[2], 1.0f);
             R_Bloom_SamplePass (0, i);
             //R_Bloom_SamplePass( 0, -i );
         }
@@ -369,6 +392,7 @@ void R_Bloom_GeneratexCross (void) {
 void R_Bloom_GeneratexDiamonds (void) {
     int           i, j;
     static float  intensity;
+    float         rgb[3];
 
     // Setup sample size workspace
     glViewport (0, 0, sample_width, sample_height);
@@ -380,7 +404,6 @@ void R_Bloom_GeneratexDiamonds (void) {
 
     // Copy small scene into bloomeffecttexture.
     GL_Bind (bloomeffecttexture);
-    //glBindTexture(GL_TEXTURE_2D, bloomeffecttexture);
     glCopyTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, 0, 0, sample_width, sample_height);
 
     // Start modifying the small scene corner.
@@ -401,6 +424,8 @@ void R_Bloom_GeneratexDiamonds (void) {
     //glBlendFunc(GL_ONE, GL_ONE);
     glBlendFunc (GL_ONE, GL_ONE_MINUS_SRC_COLOR);
 
+    R_CalcRGB (gl_bloomcolor.value, 1, (float *) rgb);
+
     if (gl_bloomdiamondsize.value > 7 || gl_bloomdiamondsize.value <= 3) {
         if (gl_bloomdiamondsize.value != 8) {
             Cvar_SetValue (&gl_bloomdiamondsize, 8);
@@ -408,11 +433,11 @@ void R_Bloom_GeneratexDiamonds (void) {
 
         for (i = 0; i < gl_bloomdiamondsize.value; i++) {
             for (j = 0; j < gl_bloomdiamondsize.value; j++) {
-                intensity = gl_bloomintensity.value * 0.3 * Diamond8x[i][j];
+                intensity = BLOOM_INTENSITY * 0.2 * Diamond8x[i][j];    // lxndr: was 0.3
                 if (intensity < 0.01f) {
                     continue;
                 }
-                glColor4f (intensity, intensity, intensity, 1.0);
+                glColor4f (intensity * rgb[0], intensity * rgb[1], intensity * rgb[2], 1.0);
                 R_Bloom_SamplePass (i - 4, j - 4);
             }
         }
@@ -423,11 +448,11 @@ void R_Bloom_GeneratexDiamonds (void) {
 
         for (i = 0; i < gl_bloomdiamondsize.value; i++) {
             for (j = 0; j < gl_bloomdiamondsize.value; j++) {
-                intensity = gl_bloomintensity.value * 0.5 * Diamond6x[i][j];
+                intensity = BLOOM_INTENSITY * 0.5 * Diamond6x[i][j];
                 if (intensity < 0.01f) {
                     continue;
                 }
-                glColor4f (intensity, intensity, intensity, 1.0);
+                glColor4f (intensity * rgb[0], intensity * rgb[1], intensity * rgb[2], 1.0);
                 R_Bloom_SamplePass (i - 3, j - 3);
             }
         }
@@ -438,10 +463,10 @@ void R_Bloom_GeneratexDiamonds (void) {
 
         for (i = 0; i < gl_bloomdiamondsize.value; i++) {
             for (j = 0; j < gl_bloomdiamondsize.value; j++) {
-                intensity = gl_bloomintensity.value * 0.8f * Diamond4x[i][j];
+                intensity = BLOOM_INTENSITY * 0.8 * Diamond4x[i][j];
                 if (intensity < 0.01f)
                     continue;
-                glColor4f (intensity, intensity, intensity, 1.0);
+                glColor4f (intensity * rgb[0], intensity * rgb[1], intensity * rgb[2], 1.0);
                 R_Bloom_SamplePass (i - 2, j - 2);
             }
         }
@@ -507,21 +532,21 @@ void R_Bloom_DownsampleView (void) {
 // =================
 void R_BloomBlend (void) {
     extern vrect_t scr_vrect;
+    int l;
 
-    if (!gl_bloom.value) {
+#ifdef __DEVEL__
+    if (!((int) gl_bloom.value & (0x00000001 << current_pass++)))
         return;
-    }
+#else
+    if (!gl_bloom.value)
+        return;
+#endif
 
-    if (!BLOOM_SIZE || screen_texture_width < glwidth || screen_texture_height < glheight) {
+    if (!BLOOM_SIZE || screen_texture_width < glwidth || screen_texture_height < glheight)
         R_Bloom_InitTextures ();
-    }
 
-    if (screen_texture_width < BLOOM_SIZE || screen_texture_height < BLOOM_SIZE) {
+    if (screen_texture_width < BLOOM_SIZE || screen_texture_height < BLOOM_SIZE)
         return;
-    }
-
-    if (gl_fog.value)
-        glDisable (GL_FOG);
 
     // Set up full screen workspace.
     glViewport (0, 0, glwidth, glheight);
@@ -557,18 +582,44 @@ void R_BloomBlend (void) {
     sample_width = BLOOM_SIZE * sampleText_tcw;
     sample_height = BLOOM_SIZE * sampleText_tch;
 
-    // Copy the screen space we'll use to work into the backup texture.
     if (cl.stats[STAT_HEALTH] > 0)     // lxndr: ... but i like this effect
         glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);   // lxndr: fixes a rendering issue when DrawViewModel is turned off ...
     GL_Bind (bloombackuptexture);
-    //glBindTexture(GL_TEXTURE_2D, bloombackuptexture);
+
+    // Copy the screen space we'll use to work into the backup texture.
     glCopyTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, 0, 0, r_screenbackuptexture_size * sampleText_tcw,
                          r_screenbackuptexture_size * sampleText_tch);
 
     // Create the bloom image.
     R_Bloom_DownsampleView ();
-    R_Bloom_GeneratexDiamonds ();
-    //    R_Bloom_GeneratexCross();
+    BLOOM_ALPHA = gl_bloomalpha.value;
+    BLOOM_INTENSITY = gl_bloomintensity.value;
+    if (gl_dcontrast.value) {
+        if (v_lumhist[0] > v_lummean)
+            BLOOM_ALPHA *= (1 + gl_dcontrastscale.value * (v_lumhist[0] - v_lummean) / v_lumhist[0]);
+        l = 0.5 + v_gamma.value;
+        l =  (v_lummean - l) / l;
+        if (l > 0)
+            BLOOM_INTENSITY /= (1 + (l / 10) * gl_dcontrastscale.value);
+    }
+#ifdef __DEVEL__
+    if (gl_bloomdiamond.value >= 0) {
+        if (current_pass <= gl_bloomdiamond.value)
+            R_Bloom_GeneratexDiamonds ();
+        else
+            R_Bloom_GeneratexCross ();
+    } else {
+        if (current_pass <= fabs (gl_bloomdiamond.value))
+            R_Bloom_GeneratexCross ();
+        else
+            R_Bloom_GeneratexDiamonds ();
+    }
+#else
+    if (gl_bloomdiamond.value)
+        R_Bloom_GeneratexDiamonds ();
+    else
+        R_Bloom_GeneratexCross ();
+#endif
 
     // Restore the screen-backup to the screen.
     glDisable (GL_BLEND);
@@ -581,7 +632,4 @@ void R_BloomBlend (void) {
     R_Bloom_DrawEffect ();
 
     glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
-    if (gl_fog.value)
-        glEnable (GL_FOG);
 }
