@@ -21,7 +21,7 @@
 
 #include "quakedef.h"
 
-#define DEFAULT_NUM_DECALS		4096
+#define DEFAULT_NUM_DECALS		"4096"
 #define ABSOLUTE_MIN_DECALS		256
 #define ABSOLUTE_MAX_DECALS		32768
 #define MAX_DECAL_VERTICES		128
@@ -57,13 +57,17 @@ static int    r_numdecals;
 static plane_t leftPlane, rightPlane, bottomPlane, topPlane, backPlane, frontPlane;
 
 qboolean      OnChange_gl_decal (cvar_t * var, char *value);
-cvar_t        gl_decal = { "gl_decal", "0", CVAR_ARCHIVE | CVAR_AGGREGATE, OnChange_gl_decal };
-cvar_t        gl_decal_blood = { "gl_decal_blood", "0", CVAR_ARCHIVE };
-cvar_t        gl_decal_bullets = { "gl_decal_bullets", "0", CVAR_ARCHIVE };
-cvar_t        gl_decal_explosions = { "gl_decal_explosions", "0", CVAR_ARCHIVE };
-cvar_t        gl_decal_sparks = { "gl_decal_sparks", "0", CVAR_ARCHIVE };
-cvar_t        gl_decaltime = { "gl_decaltime", "12" };
-cvar_t        gl_decaldistance = { "gl_decaldistance", "1024" };
+cvar_t        gl_decal = { "gl_decal", "1", CVAR_ARCHIVE | CVAR_AGGREGATE, OnChange_gl_decal };
+cvar_t        gl_decalalpha = { "gl_decalalpha", "0.2", CVAR_ARCHIVE };
+cvar_t        gl_decaldistance = { "gl_decaldistance", "2048" };
+qboolean      OnChange_gl_decalmax (cvar_t * var, char *value);
+cvar_t        gl_decalmax = { "gl_decalmax", DEFAULT_NUM_DECALS, CVAR_ARCHIVE, OnChange_gl_decalmax };
+cvar_t        gl_decaltime = { "gl_decaltime", "128", CVAR_ARCHIVE };
+
+cvar_t        gl_decal_blood = { "gl_decal_blood", "1", CVAR_ARCHIVE };
+cvar_t        gl_decal_bullets = { "gl_decal_bullets", "1", CVAR_ARCHIVE };
+cvar_t        gl_decal_explosions = { "gl_decal_explosions", "1", CVAR_ARCHIVE };
+cvar_t        gl_decal_sparks = { "gl_decal_sparks", "1", CVAR_ARCHIVE };
 
 void          DecalClipLeaf (decal_t * dec, mleaf_t * leaf);
 void          DecalWalkBsp_R (decal_t * dec, mnode_t * node);
@@ -99,6 +103,27 @@ qboolean OnChange_gl_decal (cvar_t * var, char *value) {
     return false;
 }
 
+qboolean OnChange_gl_decalmax (cvar_t * var, char *string) {
+    int          value = Q_atoi (string);
+
+    if (value < ABSOLUTE_MIN_DECALS || value > ABSOLUTE_MAX_DECALS) {
+        Con_Printf ("Valid values for %s are between %d and %d\n", var->name, ABSOLUTE_MIN_DECALS, ABSOLUTE_MAX_DECALS);
+        return true;
+    }
+
+    if (!decals)
+        return false;
+
+    if (value == r_numdecals)
+        return true;
+    r_numdecals = value;
+
+    decals = Q_realloc (decals, r_numdecals * sizeof (decal_t));
+    R_ClearDecals ();
+
+    return false;
+}
+
 float RandomMinMax (float min, float max) {
     return min + ((rand () % 10000) / 10000.0) * (max - min);
 }
@@ -110,42 +135,35 @@ void R_InitDecals (void) {
     int           i;
 
     Cvar_Register (&gl_decal);
+    Cvar_Register (&gl_decalalpha);
+    Cvar_Register (&gl_decaldistance);
+    Cvar_Register (&gl_decalmax);
+    Cvar_Register (&gl_decaltime);
     Cvar_Register (&gl_decal_blood);
     Cvar_Register (&gl_decal_bullets);
     Cvar_Register (&gl_decal_explosions);
     Cvar_Register (&gl_decal_sparks);
-    Cvar_Register (&gl_decaltime);
-    Cvar_Register (&gl_decaldistance);
 
     if (!qmb_initialized)
         return;
 
-    decal_blood1 =
-        GL_LoadTextureImage ("textures/decals/blood_splat01", "decals:blood_splat01", 128, 128,
-                             TEX_ALPHA | TEX_COMPLAIN);
-    decal_blood2 =
-        GL_LoadTextureImage ("textures/decals/blood_splat02", "decals:blood_splat02", 128, 128,
-                             TEX_ALPHA | TEX_COMPLAIN);
-    decal_blood3 =
-        GL_LoadTextureImage ("textures/decals/blood_splat03", "decals:blood_splat03", 128, 128,
-                             TEX_ALPHA | TEX_COMPLAIN);
-    decal_q3blood =
-        GL_LoadTextureImage ("textures/decals/blood_stain", "decals:blood_stain", 64, 64, TEX_ALPHA | TEX_COMPLAIN);
-    decal_burn =
-        GL_LoadTextureImage ("textures/decals/explo_burn01", "decals:explo_burn01", 128, 128, TEX_ALPHA | TEX_COMPLAIN);
-    decal_mark =
-        GL_LoadTextureImage ("textures/decals/particle_burn01", "decals:particle_burn01", 64, 64,
-                             TEX_ALPHA | TEX_COMPLAIN);
-    decal_glow = GL_LoadTextureImage ("textures/decals/glow2", "decals:glow2", 64, 64, TEX_ALPHA | TEX_COMPLAIN);
+    decal_blood1 = GL_LoadTextureImage ("gfx/decals/blood_splat01", "decals:blood_splat01", 128, 128, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_blood2 = GL_LoadTextureImage ("gfx/decals/blood_splat02", "decals:blood_splat02", 128, 128, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_blood3 = GL_LoadTextureImage ("gfx/decals/blood_splat03", "decals:blood_splat03", 128, 128, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_q3blood = GL_LoadTextureImage ("gfx/decals/blood_stain", "decals:blood_stain", 64, 64, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_burn = GL_LoadTextureImage ("gfx/decals/explo_burn01", "decals:explo_burn01", 128, 128, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_mark = GL_LoadTextureImage ("gfx/decals/particle_burn01", "decals:particle_burn01", 64, 64, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
+    decal_glow = GL_LoadTextureImage ("gfx/decals/glow2", "decals:glow2", 64, 64, TEX_ALPHA | TEX_COMPLAIN | TEX_DECAL);
 
     if ((i = COM_CheckParm ("-decals")) && i + 1 < com_argc) {
         r_numdecals = Q_atoi (com_argv[i + 1]);
         r_numdecals = bound (ABSOLUTE_MIN_DECALS, r_numdecals, ABSOLUTE_MAX_DECALS);
     } else {
-        r_numdecals = DEFAULT_NUM_DECALS;
+        r_numdecals = gl_decalmax.value;
     }
 
-    decals = Hunk_AllocName (r_numdecals * sizeof (decal_t), "decals");
+//    decals = Hunk_AllocName (r_numdecals * sizeof (decal_t), "decals");
+    decals = Q_malloc (r_numdecals * sizeof (decal_t)); // lxndr: use dynamic allocation for allowing numdecals changes
 }
 
 /*
@@ -160,7 +178,6 @@ void R_ClearDecals (void) {
     memset (decals, 0, r_numdecals * sizeof (decal_t));
     free_decals = &decals[0];
     active_decals = NULL;
-
     for (i = 0; i < r_numdecals; i++)
         decals[i].next = &decals[i + 1];
     decals[r_numdecals - 1].next = NULL;
@@ -259,7 +276,6 @@ void R_SpawnDecal (vec3_t center, vec3_t normal, vec3_t tangent, int tex, int si
 
 void R_SpawnDecalStatic (vec3_t org, int tex, int size) {
     int           i;
-    float         frac, bestfrac;
     vec3_t        tangent, v, bestorg, normal, bestnormal, org2;
 
     if (!qmb_initialized)
@@ -268,36 +284,31 @@ void R_SpawnDecalStatic (vec3_t org, int tex, int size) {
     VectorClear (bestorg);
     VectorClear (bestnormal);
 
-    bestfrac = 10;
     for (i = 0; i < 14; i++) {
         VectorRandom (org2);
         VectorMA (org, 20, org2, org2);
         TraceLineN (org, org2, v, normal);
-        frac = 0.5;
-        if (bestfrac > frac) {
-            bestfrac = frac;
+        if (i == 0) {
             VectorCopy (v, bestorg);
             VectorCopy (normal, bestnormal);
             CrossProduct (normal, bestnormal, tangent);
         }
 
-        if (VectorLength (bestnormal) && VectorLength (bestorg)) {      // lxndr:
+        if (VectorLength (bestnormal) && VectorLength (bestorg))
             continue;
-        } else {
-            VectorNegate (org2, org2);
-            VectorMA (org, 20, org2, org2);
-            TraceLineN (org, org2, v, normal);
-            VectorCopy (v, bestorg);
-            VectorCopy (normal, bestnormal);
-            CrossProduct (normal, bestnormal, tangent);
-        }
 
-        if (VectorLength (bestnormal) && VectorLength (bestorg))        // lxndr:
+        VectorNegate (org2, org2);
+        VectorMA (org, 20, org2, org2);
+        TraceLineN (org, org2, v, normal);
+        VectorCopy (v, bestorg);
+        VectorCopy (normal, bestnormal);
+        CrossProduct (normal, bestnormal, tangent);
+
+        if (VectorLength (bestnormal) && VectorLength (bestorg))
             continue;
     }
 
-    if (bestfrac < 1)
-        R_SpawnDecal (bestorg, bestnormal, tangent, tex, size);
+    R_SpawnDecal (bestorg, bestnormal, tangent, tex, size);
 }
 
 void DecalWalkBsp_R (decal_t * dec, mnode_t * node) {
@@ -494,15 +505,6 @@ void R_DrawDecals (void) {
     if (!qmb_initialized)
         return;
 
-    glEnable (GL_BLEND);
-    glEnable (GL_ALPHA_TEST);
-    glAlphaFunc (GL_GREATER, 0.000);
-    glEnable (GL_POLYGON_OFFSET_FILL);
-    glPolygonOffset (-1, -1);
-    glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-    glDepthMask (GL_FALSE);
-    glShadeModel (GL_SMOOTH);
-
     for (;;) {
         kill = active_decals;
 
@@ -515,6 +517,15 @@ void R_DrawDecals (void) {
         break;
     }
 
+    glEnable (GL_BLEND);
+    glEnable (GL_ALPHA_TEST);
+    glAlphaFunc (GL_GREATER, 0.000);
+    glEnable (GL_POLYGON_OFFSET_FILL);
+    glPolygonOffset (-1, -1);
+    glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
+    glDepthMask (GL_FALSE);
+    glShadeModel (GL_SMOOTH);
+
     for (p = active_decals; p; p = p->next) {
         for (;;) {
             kill = p->next;
@@ -544,7 +555,7 @@ void R_DrawDecals (void) {
             float         scale = 2 * (p->die - cl.time);
             glColor4f (dcolor * scale, dcolor * scale, dcolor * scale, scale);
         } else {
-            dcolor = (1 - (VectorLength (decaldist) / gl_decaldistance.value));
+            dcolor = (1 - (VectorLength (decaldist) / gl_decaldistance.value)) * gl_decalalpha.value;
             glColor4f (dcolor, dcolor, dcolor, dcolor);
         }
 
