@@ -35,11 +35,11 @@ model_t      *Mod_LoadModel (model_t * mod, qboolean crash);
 
 byte          mod_novis[MAX_MAP_LEAFS / 8];
 
-#define	MAX_MOD_KNOWN	512
+#define	MAX_MOD_KNOWN	2048           // lxndr: was 512
 model_t       mod_known[MAX_MOD_KNOWN];
 int           mod_numknown;
 
-cvar_t        gl_subdivide_size = { "gl_subdivide_size", "128", CVAR_ARCHIVE };
+cvar_t        gl_subdivide_size = { "gl_subdivide_size", "64", CVAR_ARCHIVE };
 
 qboolean OnChange_gl_picmip (cvar_t * var, char *string) {
     int           i;
@@ -226,6 +226,76 @@ void Mod_TouchModel (char *name) {
         Cache_Check (&mod->cache);
 }
 
+/*
+ * Mod_FindHint
+ */
+void Mod_FindHint (model_t * mod) {
+    if (!strcmp (mod->name, "progs/missile.md3") || !strcmp (mod->name, "progs/lavaball.md3")
+        || !strcmp (mod->name, "progs/grenade.md3"))
+        mod->modhint = MOD_Q3BULLET;
+    else if (!strcmp (mod->name, "progs/bullet.md3"))
+        mod->modhint = MOD_Q3GUNSHOT;
+    else if (!strcmp (mod->name, "progs/telep.md3"))
+        mod->modhint = MOD_Q3TELEPORT;
+    else if (!strncmp (mod->name, "progs/flame", 11) || !strncmp (mod->name, "progs/longtrch", 14))
+        mod->modhint = MOD_FLAME;
+    else if (!strncmp (mod->name, "progs/h_player", 14) || !strncmp (mod->name, "progs/gib1", 10)
+             || !strncmp (mod->name, "progs/gib2", 10) || !strncmp (mod->name, "progs/gib3", 10))
+        mod->modhint = MOD_GIB;
+    else if (!strncmp (mod->name, "maps/b_nail", 11) || !strncmp (mod->name, "maps/b_rock", 11)
+             || !strncmp (mod->name, "maps/b_shell", 12) || !strncmp (mod->name, "maps/b_bh", 9)
+             || !strncmp (mod->name, "maps/b_explob", 13) || !strncmp (mod->name, "maps/b_exbox2", 13)
+             || !strncmp (mod->name, "progs/armor", 11))
+        mod->modhint = MOD_ITEM;
+    else if (!strncmp (mod->name, "progs/invulner", 14) || !strncmp (mod->name, "progs/suit", 10)
+             || !strncmp (mod->name, "progs/invisibl", 14) || !strncmp (mod->name, "progs/quaddama", 14)
+             || !strncmp (mod->name, "progs/end1", 10) || !strncmp (mod->name, "progs/end2", 10)
+             || !strncmp (mod->name, "progs/end3", 10) || !strncmp (mod->name, "progs/end4", 10))
+        mod->modhint = MOD_ITEM;
+    else if (!strncmp (mod->name, "progs/b_g_key", 13) || !strncmp (mod->name, "progs/b_s_key", 13)
+             || !strncmp (mod->name, "progs/m_g_key", 13) || !strncmp (mod->name, "progs/m_s_key", 13)
+             || !strncmp (mod->name, "progs/w_g_key", 13) || !strncmp (mod->name, "progs/w_s_key", 13))
+        mod->modhint = MOD_KEYS;
+    else if (!strncmp (mod->name, "progs/laser", 11))
+        mod->modhint = MOD_LASER;
+    else if (!strncmp (mod->name, "progs/lavaball", 14))
+        mod->modhint = MOD_LAVABALL;
+    else if (!strncmp (mod->name, "progs/player", 12))
+        mod->modhint = MOD_PLAYER;
+    else if (!strncmp (mod->name, "progs/eyes", 10))
+        mod->modhint = MOD_EYES;
+    else if (!strncmp (mod->name, "progs/shambler", 14))
+        mod->modhint = MOD_SHAMBLER;
+    else if (!strncmp (mod->name, "progs/k_spike", 13))
+        mod->modhint = MOD_KSPIKE;
+    else if (!strncmp (mod->name, "progs/spike", 11) || !strncmp (mod->name, "progs/s_spike", 13))
+        mod->modhint = MOD_SPIKE;
+    else if (!strncmp (mod->name, "progs/v_spike", 13))
+        mod->modhint = MOD_VSPIKE;
+    else if (!strncmp (mod->name, "progs/bolt", 10))
+        mod->modhint = MOD_THUNDERBOLT;
+    else if (!strncmp (mod->name, "progs/v_shot", 12) || !strncmp (mod->name, "progs/v_nail", 12)
+             || !strncmp (mod->name, "progs/v_rock", 12) || !strncmp (mod->name, "progs/v_light", 13)
+             || !strncmp (mod->name, "progs/v_axe", 11)
+             // hipnotic weapons
+             || !strcmp (mod->name, "progs/v_laserg.mdl") || !strcmp (mod->name, "progs/v_prox.mdl")
+             // rogue weapons
+             || !strcmp (mod->name, "progs/v_grpple.mdl")
+             || !strncmp (mod->name, "progs/v_lava", 12) || !strncmp (mod->name, "progs/v_multi", 13)
+             || !strcmp (mod->name, "progs/v_plasma.mdl") || !strcmp (mod->name, "progs/v_star.mdl"))
+        mod->modhint = MOD_WEAPON;
+    else if (!strncmp (mod->name, "progs/g_shot", 12) || !strncmp (mod->name, "progs/g_nail", 12)
+             || !strncmp (mod->name, "progs/g_rock", 12) || !strncmp (mod->name, "progs/g_light", 13))
+        mod->modhint = MOD_WEAPON;
+    else if (!legacy && (!strncmp (mod->name, "progs/g_", 8) || !strncmp (mod->name, "progs/v_", 8)))
+        mod->modhint = MOD_WEAPON;
+    else
+        mod->modhint = MOD_NORMAL;
+#ifdef __DEBUG__
+    Con_Printf ("%s %d\n", mod->name, mod->modhint);
+#endif
+}
+
 /*
  * Mod_LoadModel
  *
@@ -253,14 +323,13 @@ model_t      *Mod_LoadModel (model_t * mod, qboolean crash) {
     }
     // allocate a new model
     COM_FileBase (mod->name, loadname);
-
     loadmodel = mod;
 
     // fill it in
+    Mod_FindHint (mod);
 
     // call the apropriate loader
     mod->needload = false;
-
     switch (LittleLong (*(unsigned *) buf)) {
         case IDPOLYHEADER:
             Mod_LoadAliasModel (mod, buf);
@@ -331,6 +400,16 @@ int Mod_LoadBrushModelTexture (texture_t * tx, int flags) {
     mapname = CL_MapName ();
 
     if (loadmodel->isworldmodel) {
+        if (ISTURBTEX (name)) {
+            if (!Q_strncasecmp (name + 1, "lava", 4))
+                flags |= TEX_LAVA;
+            else if (!Q_strncasecmp (name + 1, "slime", 5))
+                flags |= TEX_SLIME;
+            else if (!Q_strncasecmp (name + 1, "teleport", 8))
+                flags |= TEX_TELEPORT;
+            else
+                flags |= TEX_WATER;
+        }
         if ((tx->gl_texturenum = GL_LoadTextureImage (va ("textures/%s/%s", mapname, name), name, 0, 0, flags))) {
             if (!ISTURBTEX (name))
                 tx->fb_texturenum =
@@ -386,6 +465,19 @@ void Mod_LoadTextures (lump_t * l) {
 
     brighten_flag = (lightmode == 2) ? TEX_BRIGHTEN : 0;
     texture_flag = TEX_MIPMAP;
+    switch (loadmodel->modhint) {
+        case MOD_ITEM:
+            texture_flag |= TEX_ITEM;
+            break;
+        case MOD_KEYS:
+            texture_flag |= TEX_KEYS;
+            break;
+        case MOD_WEAPON:
+            texture_flag |= TEX_WEAPON;
+            break;
+        default:
+            texture_flag |= TEX_BRUSH;
+    }
 
     for (i = 0; i < m->nummiptex; i++) {
         m->dataofs[i] = LittleLong (m->dataofs[i]);
@@ -544,6 +636,11 @@ static byte  *LoadColoredLighting (char *name, char **litfilename) {
         data = COM_LoadHunkFile (*litfilename);
     }
 
+    if (data)
+        Con_DPrintf ("lit file: %s\n", *litfilename);
+    else
+        Con_DPrintf ("no lit file for %s\n", tmpname);
+
     return data;
 }
 
@@ -553,6 +650,7 @@ static byte  *LoadColoredLighting (char *name, char **litfilename) {
 void Mod_LoadLighting (lump_t * l) {
     int           i, lit_ver, mark;
     byte         *in, *out, *data, d;
+    float         b;
     char         *litfilename;
 
     loadmodel->lightdata = NULL;
@@ -564,28 +662,30 @@ void Mod_LoadLighting (lump_t * l) {
     data = LoadColoredLighting (loadmodel->name, &litfilename);
     if (data) {
         if (com_filesize < 8 || strncmp ((char *) data, "QLIT", 4))     // lxndr: cast added
-            Con_Printf ("Corrupt .lit file (%s)...ignoring\n", COM_SkipPath (litfilename));
+            Con_Warnf ("Corrupt .lit file (%s)...ignoring\n", COM_SkipPath (litfilename));
         else if (l->filelen * 3 + 8 != com_filesize)
-            Con_Printf ("Warning: .lit file (%s) has incorrect size\n", COM_SkipPath (litfilename));
+            Con_Warnf (".lit file (%s) has incorrect size\n", COM_SkipPath (litfilename));
         else if ((lit_ver = LittleLong (((int *) data)[1])) != 1)
-            Con_Printf ("Unknown .lit file version (v%d)\n", lit_ver);
+            Con_Warnf ("Unknown .lit file version (v%d)\n", lit_ver);
         else {
             Con_DPrintf ("Static coloured lighting loaded\n");
 
             loadmodel->lightdata = data + 8;
             in = mod_base + l->fileofs;
             out = loadmodel->lightdata;
-            for (i = 0; i < l->filelen; i++) {  // lxndr: I see no difference if this loop is commented out...
-                int           b = max (out[3 * i], max (out[3 * i + 1], out[3 * i + 2]));
+
+            // lxndr: I see no difference if this loop is commented out...
+            for (i = 0; i < l->filelen; i++, out += 3) {
+                b = max (out[0], max (out[1], out[2]));
 
                 if (!b) {
-                    out[3 * i] = out[3 * i + 1] = out[3 * i + 2] = in[i];
+                    out[0] = out[1] = out[2] = in[i];
                 } else {               // too bright
-                    float         r = in[i] / (float) b;
+                    float         r = in[i] / b;
 
-                    out[3 * i + 0] = (int) (r * out[3 * i + 0]);
-                    out[3 * i + 1] = (int) (r * out[3 * i + 1]);
-                    out[3 * i + 2] = (int) (r * out[3 * i + 2]);
+                    out[0] = (r * (float) out[0]);
+                    out[1] = (r * (float) out[1]);
+                    out[2] = (r * (float) out[2]);
                 }
             }
             return;
@@ -643,11 +743,13 @@ void Mod_LoadVertexes (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadVertexes: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_VERTS);
+
     loadmodel->vertexes = out;
     loadmodel->numvertexes = count;
 
@@ -667,7 +769,7 @@ void Mod_LoadSubmodels (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadSubmodels: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     if (count > MAX_MODELS)
@@ -690,6 +792,15 @@ void Mod_LoadSubmodels (lump_t * l) {
         out->firstface = LittleLong (in->firstface);
         out->numfaces = LittleLong (in->numfaces);
     }
+
+    // lxndr: from fitzquake
+    out = loadmodel->submodels;
+
+    if (out->visleafs > MAX_MAP_LEAFS)
+        Sys_Error ("Mod_LoadSubmodels: too many visleafs (%d, max = %d) in %s", out->visleafs, MAX_MAP_LEAFS,
+                   loadmodel->name);
+
+    COM_CheckLimit (out->visleafs, 8192);
 }
 
 /*
@@ -702,11 +813,13 @@ void Mod_LoadEdges (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadEdges: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName ((count + 1) * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_EDGES);
+
     loadmodel->edges = out;
     loadmodel->numedges = count;
 
@@ -726,11 +839,13 @@ void Mod_LoadTexinfo (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadTexinfo: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_TEXINFO);
+
     loadmodel->texinfo = out;
     loadmodel->numtexinfo = count;
 
@@ -747,10 +862,21 @@ void Mod_LoadTexinfo (lump_t * l) {
         } else {
             if (miptex >= loadmodel->numtextures)
                 Sys_Error ("Mod_LoadTexinfo: miptex >= loadmodel->numtextures");
+
             out->texture = loadmodel->textures[miptex];
             if (!out->texture) {
+                Con_DWarnf ("Mod_LoadTexinfo: texture %s not found", out->texture->name);
                 out->texture = r_notexture_mip; // texture not found
                 out->flags = 0;
+            } else if (ISTURBTEX (out->texture->name)) {
+                if (!Q_strncasecmp (out->texture->name + 1, "lava", 4))
+                    out->flags |= TEX_LAVA;
+                else if (!Q_strncasecmp (out->texture->name + 1, "slime", 5))
+                    out->flags |= TEX_SLIME;
+                else if (!Q_strncasecmp (out->texture->name + 1, "teleport", 8))
+                    out->flags |= TEX_TELEPORT;
+                else
+                    out->flags |= TEX_WATER;
             }
         }
     }
@@ -797,7 +923,7 @@ void CalcSurfaceExtents (msurface_t * s) {
         s->texturemins[i] = bmins[i] * 16;
         s->extents[i] = (bmaxs[i] - bmins[i]) * 16;
         if (!(tex->flags & TEX_SPECIAL) && s->extents[i] > 512)
-            Host_Error ("CalcSurfaceExtents: Bad surface extents");
+            Sys_Error ("CalcSurfaceExtents: Bad surface extents");      // lxndr: was Host_Error
     }
 }
 
@@ -811,11 +937,13 @@ void Mod_LoadFaces (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadFaces: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_FACES);
+
     loadmodel->surfaces = out;
     loadmodel->numsurfaces = count;
 
@@ -840,22 +968,14 @@ void Mod_LoadFaces (lump_t * l) {
         out->samples = (i == -1) ? NULL : loadmodel->lightdata + i * 3;
 
         // set the drawing flags flag
-        if (ISSKYTEX (out->texinfo->texture->name))     // sky
-        {
+        if (ISSKYTEX (out->texinfo->texture->name)) {   // sky
             out->flags |= (SURF_DRAWSKY | SURF_DRAWTILED);
             GL_SubdivideSurface (out); // cut up polygon for warps
             continue;
         }
 
-        if (ISTURBTEX (out->texinfo->texture->name))    // turbulent
-        {
+        if (ISTURBTEX (out->texinfo->texture->name)) {  // turbulent
             out->flags |= (SURF_DRAWTURB | SURF_DRAWTILED);
-            if (!Q_strncasecmp (out->texinfo->texture->name + 1, "lava", 4))
-                out->flags |= SURF_LAVA;
-            else if (!Q_strncasecmp (out->texinfo->texture->name + 1, "slime", 5))
-                out->flags |= SURF_SLIME;
-            else if (!Q_strncasecmp (out->texinfo->texture->name + 1, "teleport", 8))
-                out->flags |= SURF_TELEPORT;
             for (i = 0; i < 2; i++) {
                 out->extents[i] = 16384;
                 out->texturemins[i] = -8192;
@@ -887,11 +1007,13 @@ void Mod_LoadNodes (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadNodes: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_NODES);
+
     loadmodel->nodes = out;
     loadmodel->numnodes = count;
 
@@ -904,15 +1026,29 @@ void Mod_LoadNodes (lump_t * l) {
         p = LittleLong (in->planenum);
         out->plane = loadmodel->planes + p;
 
-        out->firstsurface = LittleShort (in->firstface);
-        out->numsurfaces = LittleShort (in->numfaces);
+        out->firstsurface = (unsigned short) LittleShort (in->firstface);
+        out->numsurfaces = (unsigned short) LittleShort (in->numfaces);
 
+        // lxndr: from fitzquake
         for (j = 0; j < 2; j++) {
-            p = LittleShort (in->children[j]);
-            if (p >= 0)
+            //johnfitz -- hack to handle nodes > 32k, adapted from darkplaces
+            p = (unsigned short) LittleShort (in->children[j]);
+
+            if (p >= 0 && p < count) {
                 out->children[j] = loadmodel->nodes + p;
-            else
-                out->children[j] = (mnode_t *) (loadmodel->leafs + (-1 - p));
+            } else {
+                //                out->children[j] = (mnode_t *) (loadmodel->leafs + (-1 - p));
+                p = 65535 - p;         //note this uses 65535 intentionally, -1 is leaf 0
+
+                if (p < loadmodel->numleafs) {
+                    out->children[j] = (mnode_t *) (loadmodel->leafs + p);
+                } else {
+                    Con_DWarnf ("Mod_LoadNodes: invalid leaf index %i (file has only %i leafs)\n", p,
+                                loadmodel->numleafs);
+
+                    out->children[j] = (mnode_t *) (loadmodel->leafs);  //map it to the solid leaf
+                }
+            }
         }
     }
 
@@ -929,11 +1065,13 @@ void Mod_LoadLeafs (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadLeafs: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_LEAFS);
+
     loadmodel->leafs = out;
     loadmodel->numleafs = count;
 
@@ -946,8 +1084,8 @@ void Mod_LoadLeafs (lump_t * l) {
         p = LittleLong (in->contents);
         out->contents = p;
 
-        out->firstmarksurface = loadmodel->marksurfaces + LittleShort (in->firstmarksurface);
-        out->nummarksurfaces = LittleShort (in->nummarksurfaces);
+        out->firstmarksurface = loadmodel->marksurfaces + (unsigned short) LittleShort (in->firstmarksurface);
+        out->nummarksurfaces = (unsigned short) LittleShort (in->nummarksurfaces);
 
         p = LittleLong (in->visofs);
         out->compressed_vis = (p == -1) ? NULL : loadmodel->visdata + p;
@@ -957,7 +1095,7 @@ void Mod_LoadLeafs (lump_t * l) {
             out->ambient_sound_level[j] = in->ambient_level[j];
 
         if (out->contents != CONTENTS_EMPTY) {
-            for (j = 0; j < out->nummarksurfaces; j++)
+            for (j = 0; j < out->nummarksurfaces - 1; j++)
                 out->firstmarksurface[j]->flags |= SURF_UNDERWATER;
         }
     }
@@ -973,11 +1111,13 @@ void Mod_LoadClipnodes (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadClipnodes: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_CLIPNODES);
+
     loadmodel->clipnodes = out;
     loadmodel->numclipnodes = count;
 
@@ -1007,8 +1147,18 @@ void Mod_LoadClipnodes (lump_t * l) {
 
     for (i = 0; i < count; i++, out++, in++) {
         out->planenum = LittleLong (in->planenum);
-        out->children[0] = LittleShort (in->children[0]);
-        out->children[1] = LittleShort (in->children[1]);
+
+        // lxndr: from fitzquake
+        if (out->planenum < 0 || out->planenum >= loadmodel->numplanes)
+            Host_Error ("Mod_LoadClipnodes: planenum out of bounds");
+
+        out->children[0] = (unsigned short) LittleShort (in->children[0]);
+        out->children[1] = (unsigned short) LittleShort (in->children[1]);
+
+        if (out->children[0] >= count)
+            out->children[0] -= 65536;
+        if (out->children[1] >= count)
+            out->children[1] -= 65536;
     }
 }
 
@@ -1056,18 +1206,21 @@ void Mod_LoadMarksurfaces (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadMarksurfaces: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_MARKSURFACES);
+
     loadmodel->marksurfaces = out;
     loadmodel->nummarksurfaces = count;
 
     for (i = 0; i < count; i++) {
-        j = LittleShort (in[i]);
+        j = (unsigned short) LittleShort (in[i]);
         if (j >= loadmodel->numsurfaces)
             Sys_Error ("Mod_ParseMarksurfaces: bad surface number");
+
         out[i] = loadmodel->surfaces + j;
     }
 }
@@ -1080,11 +1233,13 @@ void Mod_LoadSurfedges (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadSurfedges: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_SURFEDGES);
+
     loadmodel->surfedges = out;
     loadmodel->numsurfedges = count;
 
@@ -1102,11 +1257,13 @@ void Mod_LoadPlanes (lump_t * l) {
 
     in = (void *) (mod_base + l->fileofs);
     if (l->filelen % sizeof (*in))
-        Sys_Error ("MOD_LoadBrushModel: funny lump size in %s", loadmodel->name);
+        Sys_Error ("Mod_LoadPlanes: funny lump size in %s", loadmodel->name);
 
     count = l->filelen / sizeof (*in);
     out = Hunk_AllocName (count * 2 * sizeof (*out), loadname);
 
+    COM_CheckLimit (count, MAX_MAP_PLANES);
+
     loadmodel->planes = out;
     loadmodel->numplanes = count;
 
@@ -1181,7 +1338,6 @@ void Mod_LoadBrushModel (model_t * mod, void *buffer) {
     Mod_MakeHull0 ();
 
     mod->numframes = 2;                // regular and alternate animation
-
     // set up the submodels (FIXME: this is confusing)
     for (i = 0; i < mod->numsubmodels; i++) {
         bm = &mod->submodels[i];
@@ -1416,6 +1572,19 @@ void         *Mod_LoadAllSkins (int numskins, daliasskintype_t * pskintype) {
     COM_StripExtension (COM_SkipPath (loadmodel->name), basename);
 
     texture_flag = TEX_MIPMAP;
+    switch (loadmodel->modhint) {
+        case MOD_ITEM:
+            texture_flag |= TEX_ITEM;
+            break;
+        case MOD_KEYS:
+            texture_flag |= TEX_KEYS;
+            break;
+        case MOD_WEAPON:
+            texture_flag |= TEX_WEAPON;
+            break;
+        default:
+            texture_flag |= TEX_ALIAS;
+    }
 
     for (i = 0; i < numskins; i++) {
         if (pskintype->type == ALIAS_SKIN_SINGLE) {
@@ -1513,40 +1682,6 @@ void Mod_LoadAliasModel (model_t * mod, void *buffer) {
     daliasframetype_t *pframetype;
     daliasskintype_t *pskintype;
 
-    // some models are special
-    // NOTE: comparing not only with player.mdl, but with all models
-    // begin with "player" coz we need to support DME models as well!
-    if (!strncmp (mod->name, "progs/player", 12))
-        mod->modhint = MOD_PLAYER;
-    else if (!strcmp (mod->name, "progs/eyes.mdl"))
-        mod->modhint = MOD_EYES;
-    else if (!strncmp (mod->name, "progs/flame", 11) || !strcmp (mod->name, "progs/longtrch.mdl"))
-        mod->modhint = MOD_FLAME;
-    else if (!strncmp (mod->name, "progs/bolt", 10))
-        mod->modhint = MOD_THUNDERBOLT;
-    else if (!strcmp (mod->name, "progs/v_shot.mdl") || !strcmp (mod->name, "progs/v_shot2.mdl")
-             || !strcmp (mod->name, "progs/v_nail.mdl") || !strcmp (mod->name, "progs/v_nail2.mdl")
-             || !strcmp (mod->name, "progs/v_rock.mdl") || !strcmp (mod->name, "progs/v_rock2.mdl")
-             // hipnotic weapons
-             || !strcmp (mod->name, "progs/v_laserg.mdl") || !strcmp (mod->name, "progs/v_prox.mdl")
-             // rogue weapons
-             || !strcmp (mod->name, "progs/v_grpple.mdl")
-             || !strncmp (mod->name, "progs/v_lava", 12) || !strncmp (mod->name, "progs/v_multi", 13)
-             || !strcmp (mod->name, "progs/v_plasma.mdl") || !strcmp (mod->name, "progs/v_star.mdl"))
-        mod->modhint = MOD_WEAPON;
-    else if (!strcmp (mod->name, "progs/laser.mdl"))
-        mod->modhint = MOD_LASER;
-    else if (!strcmp (mod->name, "progs/lavaball.mdl"))
-        mod->modhint = MOD_LAVABALL;
-    else if (!strcmp (mod->name, "progs/k_spike.mdl"))
-        mod->modhint = MOD_KSPIKE;
-    else if (!strcmp (mod->name, "progs/spike.mdl") || !strcmp (mod->name, "progs/s_spike.mdl"))
-        mod->modhint = MOD_SPIKE;
-    else if (!strcmp (mod->name, "progs/shambler.mdl"))
-        mod->modhint = MOD_SHAMBLER;
-    else
-        mod->modhint = MOD_NORMAL;
-
     start = Hunk_LowMark ();
 
     pinmodel = (mdl_t *) buffer;
@@ -1658,8 +1793,10 @@ void Mod_LoadAliasModel (model_t * mod, void *buffer) {
     total = end - start;
 
     Cache_Alloc (&mod->cache, total, loadname);
-    if (!mod->cache.data)
+    if (!mod->cache.data) {
+        Con_DWarnf ("Mod_LoadAliasModel: couldn't load model %s in cache.", loadname);
         return;
+    }
 
     memcpy (mod->cache.data, pheader, total);
 
@@ -1706,7 +1843,7 @@ void Mod_LoadQ3Animation (void) {
     animdata_t    tmp1, tmp2;
 
     if (!(animdata = (char *) COM_LoadFile ("progs/player/animation.cfg", 0))) {
-        Con_Printf ("ERROR: Couldn't open animation file\n");
+        Con_Warnf ("Couldn't open animation file\n");
         return;
     }
 
@@ -1796,26 +1933,6 @@ void Mod_LoadQ3Model (model_t * mod, void *buffer) {
              || !strcmp (mod->name, "progs/gib2.md3") || !strcmp (mod->name, "progs/gib3.md3"))
         mod->flags |= EF_GIB;
 
-    // some models are special
-    if (!strncmp (mod->name, "progs/player", 12))
-        mod->modhint = MOD_PLAYER;
-    else if (!strcmp (mod->name, "progs/flame.md3"))
-        mod->modhint = MOD_FLAME;
-    else if (!strcmp (mod->name, "progs/v_shot.md3") || !strcmp (mod->name, "progs/v_shot2.md3")
-             || !strcmp (mod->name, "progs/v_nail.md3") || !strcmp (mod->name, "progs/v_nail2.md3")
-             || !strcmp (mod->name, "progs/v_rock.md3") || !strcmp (mod->name, "progs/v_rock2.md3"))
-        mod->modhint = MOD_WEAPON;
-    else if (!strcmp (mod->name, "progs/lavaball.md3"))
-        mod->modhint = MOD_LAVABALL;
-    else if (!strcmp (mod->name, "progs/spike.md3") || !strcmp (mod->name, "progs/s_spike.md3"))
-        mod->modhint = MOD_SPIKE;
-    else if (!strcmp (mod->name, "progs/bullet.md3"))
-        mod->modhint = MOD_Q3GUNSHOT;
-    else if (!strcmp (mod->name, "progs/telep.md3"))
-        mod->modhint = MOD_Q3TELEPORT;
-    else
-        mod->modhint = MOD_NORMAL;
-
     header = (md3header_t *) buffer;
 
     version = LittleLong (header->version);
@@ -1956,12 +2073,8 @@ void Mod_LoadQ3Model (model_t * mod, void *buffer) {
     for (size = 0, i = 0; i < header->numsurfs; i++) {
         if (numskinsfound)
             surf->numshaders = numskinsfound;
-        size += surf->numshaders * sizeof (md3shader_mem_t);    // shader
-        // containing
-        // texnum
-        size += surf->numverts * surf->numframes * sizeof (md3vert_mem_t);      // floating
-        // point
-        // vertices
+        size += surf->numshaders * sizeof (md3shader_mem_t);    // shader containing texnum
+        size += surf->numverts * surf->numframes * sizeof (md3vert_mem_t);      // floating point vertices
         surf = (md3surface_t *) ((byte *) surf + surf->ofsend);
     }
 
@@ -1996,6 +2109,19 @@ void Mod_LoadQ3Model (model_t * mod, void *buffer) {
         Mod_LoadQ3Animation ();
 
     texture_flag = TEX_MIPMAP;
+    switch (loadmodel->modhint) {
+        case MOD_ITEM:
+            texture_flag |= TEX_ITEM;
+            break;
+        case MOD_KEYS:
+            texture_flag |= TEX_KEYS;
+            break;
+        case MOD_WEAPON:
+            texture_flag |= TEX_WEAPON;
+            break;
+        default:
+            texture_flag |= TEX_BRUSH;
+    }
 
     surf = (md3surface_t *) ((byte *) header + header->ofssurfs);
     for (i = 0; i < header->numsurfs; i++) {
