@@ -119,7 +119,7 @@ qboolean      qmb_initialized = false;
 int           colorStart, colorLength;
 qboolean      colorMapped = false;
 
-cvar_t        gl_bounceparticles = { "gl_bounceparticles", "1" };
+cvar_t        gl_bounceparticles = { "gl_bounceparticles", "1", CVAR_ARCHIVE };
 
 void          R_CalcBeamVerts (float *vert, vec3_t org1, vec3_t org2, float width);
 void          R_DrawQ3Model (entity_t * ent);
@@ -130,7 +130,7 @@ void          QMB_Q3Teleport (vec3_t org, float alpha);
 
 #define ISUNDERWATER(x) ((x) == CONTENTS_WATER || (x) == CONTENTS_SLIME || (x) == CONTENTS_LAVA)
 
-static byte  *ColorForParticle (part_type_t type) {
+static byte *ColorForParticle (part_type_t type) {
     int           lambda;
     static col_t  color;
 
@@ -144,7 +144,7 @@ static byte  *ColorForParticle (part_type_t type) {
         case p_smoke:
         case p_glow:
         case p_muzzleflash:
-            color[0] = color[1] = color[2] = 255;
+            color[0] = color[1] = color[2] = 128; // lnxdr: was 255
             break;
 
         case p_q3rocketsmoke:
@@ -177,8 +177,8 @@ static byte  *ColorForParticle (part_type_t type) {
             break;
 
         case p_gunblast:
-            color[0] = 224 + (rand () & 31);
-            color[1] = 170 + (rand () & 31);
+            color[0] = 192 + (rand () & 31); // lxndr: was 224
+            color[1] = 128 + (rand () & 31); // lxndr: was 170
             color[2] = 0;
             break;
 
@@ -215,11 +215,11 @@ static byte  *ColorForParticle (part_type_t type) {
 
         case p_blood1:
         case p_blood2:
-            color[0] = color[1] = color[2] = 180 + (rand () & 63);
+            color[0] = color[1] = color[2] = (rand () & 63); // lxndr: was + 180
             break;
 
         case p_blood3:
-            color[0] = 100 + (rand () & 31);
+            color[0] = (rand () & 31); // lxndr: was + 100
             color[1] = color[2] = 0;
             break;
 
@@ -296,69 +296,62 @@ void QMB_InitParticles (void) {
 
     Cvar_Register (&gl_bounceparticles);
 
-    if (!
-        (particleimage =
-         GL_LoadTextureImage ("textures/particles/particlefont", "qmb:particlefont", 256, 256,
-                              TEX_ALPHA | TEX_COMPLAIN)))
+    if ((particleimage = GL_LoadTextureImage ("gfx/particles/particlefont", "qmb:particlefont", 256, 256, TEX_ALPHA | TEX_COMPLAIN))) {
+        max_s = max_t = 256.0;
+        ADD_PARTICLE_TEXTURE (ptex_none, 0, 0, 1, 0, 0, 0, 0);
+        ADD_PARTICLE_TEXTURE (ptex_blood1, particleimage, 0, 1, 0, 0, 64, 64);
+        ADD_PARTICLE_TEXTURE (ptex_blood2, particleimage, 0, 1, 64, 0, 128, 64);
+        ADD_PARTICLE_TEXTURE (ptex_lava, particleimage, 0, 1, 128, 0, 192, 64);
+        ADD_PARTICLE_TEXTURE (ptex_blueflare, particleimage, 0, 1, 192, 0, 256, 64);
+        ADD_PARTICLE_TEXTURE (ptex_generic, particleimage, 0, 1, 0, 96, 96, 192);
+        ADD_PARTICLE_TEXTURE (ptex_smoke, particleimage, 0, 1, 96, 96, 192, 192);
+        ADD_PARTICLE_TEXTURE (ptex_blood3, particleimage, 0, 1, 192, 96, 256, 160);
+        ADD_PARTICLE_TEXTURE (ptex_bubble, particleimage, 0, 1, 192, 160, 224, 192);
+        for (i = 0; i < 8; i++)
+            ADD_PARTICLE_TEXTURE (ptex_dpsmoke, particleimage, i, 8, i * 32, 64, (i + 1) * 32, 96);
+    } else {
         return;
-
-    max_s = max_t = 256.0;
-    ADD_PARTICLE_TEXTURE (ptex_none, 0, 0, 1, 0, 0, 0, 0);
-    ADD_PARTICLE_TEXTURE (ptex_blood1, particleimage, 0, 1, 0, 0, 64, 64);
-    ADD_PARTICLE_TEXTURE (ptex_blood2, particleimage, 0, 1, 64, 0, 128, 64);
-    ADD_PARTICLE_TEXTURE (ptex_lava, particleimage, 0, 1, 128, 0, 192, 64);
-    ADD_PARTICLE_TEXTURE (ptex_blueflare, particleimage, 0, 1, 192, 0, 256, 64);
-    ADD_PARTICLE_TEXTURE (ptex_generic, particleimage, 0, 1, 0, 96, 96, 192);
-    ADD_PARTICLE_TEXTURE (ptex_smoke, particleimage, 0, 1, 96, 96, 192, 192);
-    ADD_PARTICLE_TEXTURE (ptex_blood3, particleimage, 0, 1, 192, 96, 256, 160);
-    ADD_PARTICLE_TEXTURE (ptex_bubble, particleimage, 0, 1, 192, 160, 224, 192);
-    for (i = 0; i < 8; i++)
-        ADD_PARTICLE_TEXTURE (ptex_dpsmoke, particleimage, i, 8, i * 32, 64, (i + 1) * 32, 96);
+    }
 
     // load the rest of the images
 
-    if (!
-        (particleimage =
-         GL_LoadTextureImage ("textures/particles/q3particlefont", "qmb:q3particlefont", 384, 192,
-                              TEX_ALPHA | TEX_COMPLAIN)))
+    if ((particleimage = GL_LoadTextureImage ("gfx/particles/q3particlefont", "qmb:q3particlefont", 384, 192, TEX_ALPHA | TEX_COMPLAIN))) {
+        max_s = 384.0;
+        max_t = 192.0;
+        for (i = 0, ti = 0; i < 2; i++)
+            for (j = 0; j < 4; j++, ti++)
+                ADD_PARTICLE_TEXTURE (ptex_q3explosion, particleimage, ti, 8, j * 64, i * 64, (j + 1) * 64, (i + 1) * 64);
+        for (i = 0; i < 5; i++)
+            ADD_PARTICLE_TEXTURE (ptex_q3blood, particleimage, i, 5, i * 64, 128, (i + 1) * 64, 192);
+        ADD_PARTICLE_TEXTURE (ptex_q3smoke, particleimage, 0, 1, 256, 0, 384, 128);
+        ADD_PARTICLE_TEXTURE (ptex_q3blood_trail, particleimage, 0, 1, 320, 128, 384, 192);
+    } else {
         return;
+    }
 
-    max_s = 384.0;
-    max_t = 192.0;
-    for (i = 0, ti = 0; i < 2; i++)
-        for (j = 0; j < 4; j++, ti++)
-            ADD_PARTICLE_TEXTURE (ptex_q3explosion, particleimage, ti, 8, j * 64, i * 64, (j + 1) * 64, (i + 1) * 64);
-    for (i = 0; i < 5; i++)
-        ADD_PARTICLE_TEXTURE (ptex_q3blood, particleimage, i, 5, i * 64, 128, (i + 1) * 64, 192);
-    ADD_PARTICLE_TEXTURE (ptex_q3smoke, particleimage, 0, 1, 256, 0, 384, 128);
-    ADD_PARTICLE_TEXTURE (ptex_q3blood_trail, particleimage, 0, 1, 320, 128, 384, 192);
+    if ((particleimage = GL_LoadTextureImage ("gfx/particles/q3flames", "qmb:q3flames", 512, 512, TEX_ALPHA | TEX_COMPLAIN))) {
+        max_s = max_t = 512.0;
+        for (i = 0, ti = 0; i < 2; i++)
+            for (j = 0; j < 4; j++, ti++)
+                ADD_PARTICLE_TEXTURE (ptex_q3flame, particleimage, ti, 8, j * 128, i * 256, (j + 1) * 128, (i + 1) * 256);
+    } else {
+        Cvar_SetReadonly (&gl_part_flames, "0");
+    }
 
-    if (!
-        (particleimage =
-         GL_LoadTextureImage ("textures/particles/q3flames", "qmb:q3flames", 512, 512, TEX_ALPHA | TEX_COMPLAIN)))
-        return;
+    if ((particleimage = GL_LoadTextureImage ("gfx/particles/zing1", "qmb:lightning", 256, 128, TEX_ALPHA | TEX_COMPLAIN))) {
+        max_s = 256.0;
+        max_t = 128.0;
+        ADD_PARTICLE_TEXTURE (ptex_lightning, particleimage, 0, 1, 0, 0, 256, 128);
+    } else {
+        Cvar_SetReadonly (&gl_part_lightning, "0");
+    }
 
-    max_s = max_t = 512.0;
-    for (i = 0, ti = 0; i < 2; i++)
-        for (j = 0; j < 4; j++, ti++)
-            ADD_PARTICLE_TEXTURE (ptex_q3flame, particleimage, ti, 8, j * 128, i * 256, (j + 1) * 128, (i + 1) * 256);
-
-    if (!
-        (particleimage =
-         GL_LoadTextureImage ("textures/particles/zing1", "qmb:lightning", 256, 128, TEX_ALPHA | TEX_COMPLAIN)))
-        return;
-
-    max_s = 256.0;
-    max_t = 128.0;
-    ADD_PARTICLE_TEXTURE (ptex_lightning, particleimage, 0, 1, 0, 0, 256, 128);
-
-    if (!
-        (particleimage =
-         GL_LoadTextureImage ("textures/particles/muzzleflash", "qmb:muzzleflash", 128, 128, TEX_ALPHA | TEX_COMPLAIN)))
-        return;
-
-    max_s = max_t = 128.0;
-    ADD_PARTICLE_TEXTURE (ptex_muzzleflash, particleimage, 0, 1, 0, 0, 128, 128);
+    if ((particleimage = GL_LoadTextureImage ("gfx/particles/muzzleflash", "qmb:muzzleflash", 128, 128, TEX_ALPHA | TEX_COMPLAIN))) {
+        max_s = max_t = 128.0;
+        ADD_PARTICLE_TEXTURE (ptex_muzzleflash, particleimage, 0, 1, 0, 0, 128, 128);
+    } else {
+        Cvar_SetReadonly (&gl_part_muzzleflash, "0");
+    }
 
     if ((i = COM_CheckParm ("-particles")) && i + 1 < com_argc) {
         r_numparticles = Q_atoi (com_argv[i + 1]);
@@ -384,14 +377,12 @@ void QMB_InitParticles (void) {
 
     ADD_PARTICLE_TYPE (p_teleflare, pd_billboard, GL_ONE, GL_ONE, ptex_blueflare, 255, 0, 0, pm_die, -1);
 
-    ADD_PARTICLE_TYPE (p_blood1, pd_billboard, GL_ZERO, GL_ONE_MINUS_SRC_COLOR, ptex_blood1, 255, -20, 0, pm_die, 0);
-    ADD_PARTICLE_TYPE (p_blood2, pd_billboard_vel, GL_ZERO, GL_ONE_MINUS_SRC_COLOR, ptex_blood2, 255, -25, 0, pm_die,
-                       0.018);
+    ADD_PARTICLE_TYPE (p_blood1, pd_billboard, GL_ZERO, GL_ONE_MINUS_SRC_COLOR, ptex_blood1, 63, -20, 0, pm_die, 0); // lxndr: 63 was 255
+    ADD_PARTICLE_TYPE (p_blood2, pd_billboard_vel, GL_ZERO, GL_ONE_MINUS_SRC_COLOR, ptex_blood2, 63, -25, 0, pm_die, 0.018); // lnxdr: 63 was 255
 
     ADD_PARTICLE_TYPE (p_lavasplash, pd_billboard, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, ptex_lava, 170, 0, 0,
                        pm_nophysics, 0);
-    ADD_PARTICLE_TYPE (p_blood3, pd_billboard, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, ptex_blood3, 255, -20, 0,
-                       pm_normal, 0);
+    ADD_PARTICLE_TYPE (p_blood3, pd_billboard, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, ptex_blood3, 255, -20, 0, pm_normal, 0);
     ADD_PARTICLE_TYPE (p_bubble, pd_billboard, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, ptex_bubble, 204, 8, 0, pm_float,
                        0);
     ADD_PARTICLE_TYPE (p_staticbubble, pd_billboard, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, ptex_bubble, 204, 0, 0,
@@ -526,20 +517,20 @@ static void QMB_UpdateParticles (void) {
 
             switch (pt->move) {
                 case pm_static:
-                    /*
-                     * VectorCopy (p->org, oldorg); VectorMA (p->org,
-                     * frametime, p->vel, p->org); TraceLineN (oldorg, p->org,
-                     * stop, normal); if (stop != p->org && VectorLength(stop)
-                     * != 0) { vec3_t tangent;
-                     *
-                     * VectorCopy (stop, p->org); VectorCopy (normal, p->vel);
-                     * CrossProduct (normal, p->vel, tangent); if (pt->id ==
-                     * p_q3explosion && gl_decal_explosions.value) R_SpawnDecal
-                     * (p->org, normal, tangent, decal_burn, 32); else if
-                     * (pt->id == p_q3gunshot && gl_decal_bullets.value)
-                     * R_SpawnDecal (p->org, normal, tangent, decal_mark, 10);
-                     * } VectorCopy (oldorg, p->org); VectorClear (p->vel);
-                     */
+/*
+                      VectorCopy (p->org, oldorg); VectorMA (p->org,
+                      frametime, p->vel, p->org); TraceLineN (oldorg, p->org,
+                      stop, normal); if (stop != p->org && VectorLength(stop)
+                      != 0) { vec3_t tangent;
+                     
+                      VectorCopy (stop, p->org); VectorCopy (normal, p->vel);
+                      CrossProduct (normal, p->vel, tangent); if (pt->id ==
+                      p_q3explosion && gl_decal_explosions.value) R_SpawnDecal
+                      (p->org, normal, tangent, decal_burn, 32); else if
+                      (pt->id == p_q3gunshot && gl_decal_bullets.value)
+                      R_SpawnDecal (p->org, normal, tangent, decal_mark, 10);
+                      } VectorCopy (oldorg, p->org); VectorClear (p->vel);
+*/
                     break;
 
                 case pm_normal:
@@ -693,6 +684,8 @@ void QMB_DrawParticles (void) {
 
     glDepthMask (GL_FALSE);
     glEnable (GL_BLEND);
+    glEnable (GL_ALPHA_TEST);
+    glAlphaFunc (GL_GREATER, 0.000);
     glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
     glShadeModel (GL_SMOOTH);
 
@@ -899,6 +892,8 @@ void QMB_DrawParticles (void) {
     glDepthMask (GL_TRUE);
     glDisable (GL_BLEND);
     glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    glDisable (GL_ALPHA_TEST);
+    glAlphaFunc (GL_GREATER, 0.666);
     glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);
     glShadeModel (GL_FLAT);
 }
@@ -1183,11 +1178,11 @@ __inline static void AddParticleTrail (part_type_t type, vec3_t start, vec3_t en
 
         case p_trailpart:
         case p_lavatrail:
-            count = length / 1.1;
+            count = length; // lxndr: was / 1.1;
             break;
 
         case p_blood3:
-            count = length / 8.0;
+            count = length / 5.0; // lxndr: was 8.0
             break;
 
         case p_bubble:
@@ -1293,8 +1288,11 @@ __inline static void AddParticleTrail (part_type_t type, vec3_t start, vec3_t en
 
             case p_lavatrail:
                 VectorCopy (point, p->org);
-                for (j = 0; j < 3; j++)
-                    p->org[j] += (rand () & 7) - 4;
+//                for (j = 0; j < 2; j++)
+//                    p->org[j] += (rand () & 7) - 4;
+                p->org[0] += (rand () & 3);
+                p->org[1] += (rand () & 3);
+                p->org[2] += 5;
                 p->vel[0] = p->vel[1] = 0;
                 p->vel[2] = rand () & 3;
                 break;
@@ -1358,8 +1356,8 @@ void QMB_RunParticleEffect (vec3_t org, vec3_t dir, int col, int count) {
             bloodcount = Q_rint (count / 28);
             bloodcount = bound (2, bloodcount, 8);
             for (i = 0; i < bloodcount; i++) {
-                AddParticle (p_blood1, org, 1, 4.5, 2 + (rand () & 15) / 16, NULL, zerodir);
-                AddParticle (p_blood2, org, 1, 4.5, 2 + (rand () & 15) / 16, NULL, zerodir);
+                AddParticle (p_blood1, org, 1, 5, 2 + (rand () & 15) / 16, NULL, zerodir); // lxndr: 5 was 4.5
+                AddParticle (p_blood2, org, 1, 5, 2 + (rand () & 15) / 16, NULL, zerodir); // lxndr: 5 was 4.5
             }
         }
         return;
@@ -1396,8 +1394,7 @@ void QMB_RunParticleEffect (vec3_t org, vec3_t dir, int col, int count) {
     switch (count) {
         case 9:
         case 10:
-            if (nehahra && count == 10) // ventillation's wind
-            {
+            if (nehahra && count == 10) { // ventillation's wind
                 for (i = 0; i < count; i++) {
                     for (j = 0; j < 3; j++) {
                         neworg[j] = org[j] + ((rand () % 24) - 12);
@@ -1431,7 +1428,7 @@ void QMB_RunParticleEffect (vec3_t org, vec3_t dir, int col, int count) {
                 AddParticle (p_q3gunshot, org, 1, 1, 0.3, NULL, zerodir);
             } else {
                 particlecount = count >> 1;
-                AddParticle (p_gunblast, org, 15, 5, 0.15, NULL, zerodir);
+                AddParticle (p_gunblast, org, 15, 5, 0.15, NULL, zerodir); // lxndr: size was 5
                 for (i = 0; i < particlecount; i++) {
                     for (j = 0; j < 3; j++)
                         neworg[j] = org[j] + ((rand () & 15) - 8);
@@ -1509,8 +1506,7 @@ void QMB_RocketTrail (vec3_t start, vec3_t end, vec3_t * trail_origin, trail_typ
                 if (r_grenadetrail.value == 3) {
                     AddParticleTrail (p_dpfire, start, end, 3, 0.26, NULL);
                     AddParticleTrail (p_dpsmoke, start, end, 3, 0.825, NULL);
-                } else if (r_grenadetrail.value == 2)   // QMB rocket
-                {
+                } else if (r_grenadetrail.value == 2) {  // QMB rocket
                     AddParticleTrail (p_trailpart, start, end, 6.2, 0.31, ColorForParticle (p_missilefire));
                     AddParticleTrail (p_smoke, start, end, 1.8, 0.825, NULL);
                 } else {
@@ -1524,31 +1520,33 @@ void QMB_RocketTrail (vec3_t start, vec3_t end, vec3_t * trail_origin, trail_typ
             if (gl_part_trails.value == 2)
                 AddParticleTrail (p_q3blood_trail, start, end, 15, 2, NULL);
             else
-                AddParticleTrail (p_blood3, start, end, type == BLOOD_TRAIL ? 1.35 : 2.4, 2, NULL);
+                AddParticleTrail (p_blood3, start, end, type == BLOOD_TRAIL ? 0.5 : 1.5, 1, NULL);
+//                AddParticleTrail (p_blood3, start, end, type == BLOOD_TRAIL ? 1.35 : 2.4, 2, NULL);
             break;
 
         case TRACER1_TRAIL:
-            color[0] = color[2] = 0;
-            color[1] = 124;
-            AddParticleTrail (p_trailpart, start, end, 3.75, 0.5, color);
+            color[0] = 7; // lxndr: was 0
+            color[1] = 15; // lxndr: was 124
+            color[2] = 0;
+            AddParticleTrail (p_trailpart, start, end, 0.75, 0.5, color); // lxndr: was 3.75
             break;
 
         case TRACER2_TRAIL:
-            color[0] = 255;
-            color[1] = 77;
-            color[2] = 0;
-            AddParticleTrail (p_trailpart, start, end, 3.75, 0.5, color);
+            color[0] = 63; // lxndr: was 255
+            color[1] = 63; // lxndr: was 77
+            color[2] = 63; // lxndr: was 0
+            AddParticleTrail (p_trailpart, start, end, 0.75, 0.5, color); // lxndr: was 3.75
             break;
 
         case VOOR_TRAIL:
-            color[0] = 77;
-            color[1] = 0;
-            color[2] = 255;
+            color[0] = 3; // lxndr: was 77
+            color[1] = 1;
+            color[2] = 3; // lxndr: was 255
             AddParticleTrail (p_trailpart, start, end, 3.75, 0.5, color);
             break;
 
         case LAVA_TRAIL:
-            AddParticleTrail (p_lavatrail, start, end, 5, 1, NULL);
+            AddParticleTrail (p_lavatrail, start, end, 1, 1, NULL); // lxndr: was 5, 1, NULL
             break;
 
         case BUBBLE_TRAIL:
@@ -1698,6 +1696,7 @@ void QMB_TorchFlame (vec3_t org, float size, float time) {
 }
 
 void QMB_Q3TorchFlame (vec3_t org, float size) {
+return;
     static double flametime = 0;
 
     if (flametime + 0.125 < cl.time || flametime >= cl.time)
