@@ -55,6 +55,8 @@
 
 int           glx, gly, glwidth, glheight;
 
+int           hudwidth, hudheight;
+
 // only the refresh window will be updated unless these variables are flagged
 int           scr_copytop;
 int           scr_copyeverything;
@@ -64,18 +66,25 @@ float         scr_conlines;            // lines of console to display
 
 float         oldscreensize, oldfov, oldsbar;
 
+qboolean      oldzoomstate;
+//double        zoomtime;
+
 cvar_t        scr_autoid = { "scr_autoid", "0" };
 cvar_t        scr_centertime = { "scr_centertime", "2" };
-cvar_t        scr_consize = { "scr_consize", "0.5", CVAR_ARCHIVE };
+cvar_t        scr_consize = { "scr_consize", "0.2", CVAR_ARCHIVE };
 cvar_t        scr_conspeed = { "scr_conspeed", "1000" };
 cvar_t        scr_conswitch = { "scr_conswitch", "1", CVAR_ARCHIVE };
 cvar_t        scr_fov = { "fov", "90" };        // 10 - 170
+qboolean      OnChange_scr_hudsize (cvar_t * var, char *string);
+cvar_t        scr_hudsize = { "scr_hudsize", "0.5", CVAR_ARCHIVE, OnChange_scr_hudsize };
 cvar_t        scr_printspeed = { "scr_printspeed", "8" };
-cvar_t        scr_showram = { "showram", "1" };
+cvar_t        scr_shownet = { "shownet", "0" };
+cvar_t        scr_showram = { "showram", "0" };
 cvar_t        scr_showturtle = { "showturtle", "0" };
 cvar_t        scr_showpause = { "showpause", "1" };
 cvar_t        scr_sshot_format = { "scr_sshot_format", "png" };
-cvar_t        scr_viewsize = { "viewsize", "120", CVAR_ARCHIVE };
+qboolean OnChange_scr_viewsize (cvar_t * var, char *string);
+cvar_t        scr_viewsize = { "viewsize", "120", CVAR_ARCHIVE, OnChange_scr_viewsize };
 cvar_t        gl_triplebuffer = { "gl_triplebuffer", "1", CVAR_ARCHIVE };
 
 extern cvar_t crosshair;
@@ -105,6 +114,32 @@ qboolean      block_drawing;
 
 void          SCR_ScreenShot_f (void);
 
+qboolean OnChange_scr_hudsize (cvar_t * var, char *string) {
+    float         value = Q_atof (string);
+
+    if (value < 0 || value > 1.5001) { // lxndr: float hazard
+        Con_Printf ("Valid values for %s are between 0 and 1.5\n", var->name);
+        return true;
+    }
+
+    vid.recalc_refdef = true;
+
+    return false;
+}
+
+qboolean OnChange_scr_viewsize (cvar_t * var, char *string) {
+    float         value = Q_atof (string);
+
+    if (value < 30 || value > 120) { // lxndr: float hazard
+        Con_Printf ("Valid values for %s are between 30 and 120\n", var->name);
+        return true;
+    }
+
+    vid.recalc_refdef = true;
+
+    return false;
+}
+
 /*
  *
  *
@@ -127,10 +162,34 @@ int           scr_erase_center;
  * for a few moments
  */
 void SCR_CenterPrint (char *str) {
+int l;
+char out[48];
+char *p = str;
+
+    if (!str[0])
+        return;
+
     Q_strncpyz (scr_centerstring, str, sizeof (scr_centerstring));
     scr_centertime_off = scr_centertime.value;
     scr_centertime_start = cl.time;
 
+    while (*p) {
+        for (l = 0; l < 40; l++) {
+            if (p[l] == '\n' || !p[l])
+                break;
+            out[l] = p[l];
+        }
+        p += l;
+        if (*p == '\n')
+            p++;
+        while (l < 40)
+            out[l++] = ' ';
+        out[l] = '\0';
+        Con_Printf ("\x1d\x1e %s \x1e\x1f\n", out);
+    }
+    Con_Printf ("\n");
+    Con_ClearNotify ();
+
     // count the number of lines for centering
     scr_center_lines = 1;
     while (*str) {
@@ -154,16 +213,18 @@ void SCR_DrawCenterString (void) {
     start = scr_centerstring;
 
     if (scr_center_lines <= 4)
-        y = vid.height * 0.35;
+        y = hudheight * 0.35;
     else
         y = 48;
 
     do {
         // scan the width of the line
+
         for (l = 0; l < 40; l++)
             if (start[l] == '\n' || !start[l])
                 break;
-        x = (vid.width - l * 8) / 2;
+
+        x = (hudwidth - l * 8) / 2;
         for (j = 0; j < l; j++, x += 8) {
             Draw_Character (x, y, start[j]);
             if (!remaining--)
@@ -200,36 +261,6 @@ void SCR_CheckDrawCenterString (void) {
 
 // 
 
-/*
- * CalcFov
- */
-float CalcFov (float fov_x, float width, float height) {
-    float         a, x;
-
-    if (fov_x < 1 || fov_x > 179)
-        Sys_Error ("Bad fov: %f", fov_x);
-
-    x = width / tan (fov_x / 360 * M_PI);
-
-    a = atan (height / x);
-
-    a = a * 360 / M_PI;
-
-    return a;
-}
-
-float InvCalcFov (float fov_y, float width, float height) {
-    float         a, x, fov_x;
-
-    a = fov_y * M_PI / 360;
-
-    x = height / tan (a);
-
-    fov_x = atan (width / x) * (360 / M_PI);
-
-    return fov_x;
-}
-
 /*
  * SCR_CalcRefdef
  *
@@ -241,28 +272,23 @@ static void SCR_CalcRefdef (void) {
     qboolean      full = false;
 
     scr_fullupdate = 0;                // force a background redraw
-    vid.recalc_refdef = 0;
+    vid.recalc_refdef = false;
 
     // force the status bar to redraw
     Sbar_Changed ();
 
-    // 
-
-    // bound viewsize
-    if (scr_viewsize.value < 30)
-        Cvar_SetValue (&scr_viewsize, 30);
-    if (scr_viewsize.value > 120)
-        Cvar_SetValue (&scr_viewsize, 120);
-
     // bound field of view
     if (scr_fov.value < 10)
         Cvar_SetValue (&scr_fov, 10);
     if (scr_fov.value > 170)
         Cvar_SetValue (&scr_fov, 170);
 
-    // intermission is always full screen
-    size = cl.intermission ? 120 : scr_viewsize.value;
-
+    if (cl.intermission || scr_drawloading) // lxndr: drawloading requires an external recalc request (cl_parse.c)
+        full = true;
+    if (scr_viewsize.value >= 100.0 && !(scr_hudsize.value == 1.5 && scr_sbar.value))
+        full = true;
+    
+    size = scr_viewsize.value;
     if (size >= 120)
         sb_lines = 0;                  // no status bar at all
     else if (size >= 110)
@@ -270,21 +296,11 @@ static void SCR_CalcRefdef (void) {
     else
         sb_lines = 24 + 16 + 8;
 
-    if (scr_viewsize.value >= 100.0) {
-        full = true;
-        size = 100.0;
-    } else {
-        size = scr_viewsize.value;
-    }
-
-    if (cl.intermission) {
-        full = true;
-        size = 100.0;
-        sb_lines = 0;
-    }
+    if (size >= 100 || full)
+        size = 100;
     size /= 100.0;
 
-    h = (!cl_sbar.value && full) ? vid.height : vid.height - sb_lines;
+    h = full ? vid.height : vid.height - sb_lines * vid.height / hudheight;
 
     r_refdef.vrect.width = vid.width * size;
     if (r_refdef.vrect.width < 96) {
@@ -294,9 +310,9 @@ static void SCR_CalcRefdef (void) {
 
     r_refdef.vrect.height = vid.height * size;
 
-    if (cl_sbar.value || !full) {
-        if (r_refdef.vrect.height > vid.height - sb_lines)
-            r_refdef.vrect.height = vid.height - sb_lines;
+    if (!full) {
+        if (r_refdef.vrect.height > vid.height - sb_lines * vid.height / hudheight)
+            r_refdef.vrect.height = vid.height - sb_lines * vid.height / hudheight;
     } else if (r_refdef.vrect.height > vid.height) {
         r_refdef.vrect.height = vid.height;
     }
@@ -308,9 +324,7 @@ static void SCR_CalcRefdef (void) {
     else
         r_refdef.vrect.y = (h - r_refdef.vrect.height) / 2;
 
-    r_refdef.fov_x = scr_fov.value;
-    r_refdef.fov_y = CalcFov (r_refdef.fov_x, r_refdef.vrect.width, r_refdef.vrect.height);
-    // r_refdef.fov_x = InvCalcFov (r_refdef.fov_y, 640, 400); //oldman
+    V_CalcFov (); // lxndr: new method
 
     scr_vrect = r_refdef.vrect;
 }
@@ -322,7 +336,7 @@ static void SCR_CalcRefdef (void) {
  */
 void SCR_SizeUp_f (void) {
     Cvar_SetValue (&scr_viewsize, scr_viewsize.value + 10);
-    vid.recalc_refdef = 1;
+    vid.recalc_refdef = true;
 }
 
 /*
@@ -332,7 +346,7 @@ void SCR_SizeUp_f (void) {
  */
 void SCR_SizeDown_f (void) {
     Cvar_SetValue (&scr_viewsize, scr_viewsize.value - 10);
-    vid.recalc_refdef = 1;
+    vid.recalc_refdef = true;
 }
 
 // 
@@ -347,7 +361,9 @@ void SCR_Init (void) {
     Cvar_Register (&scr_conspeed);
     Cvar_Register (&scr_conswitch);
     Cvar_Register (&scr_fov);
+    Cvar_Register (&scr_hudsize);
     Cvar_Register (&scr_printspeed);
+    Cvar_Register (&scr_shownet);
     Cvar_Register (&scr_showram);
     Cvar_Register (&scr_showturtle);
     Cvar_Register (&scr_showpause);
@@ -360,8 +376,8 @@ void SCR_Init (void) {
     Cmd_AddCommand ("sizeup", SCR_SizeUp_f);
     Cmd_AddCommand ("sizedown", SCR_SizeDown_f);
 
-    scr_ram = Draw_PicFromWad ("ram");
     scr_net = Draw_PicFromWad ("net");
+    scr_ram = Draw_PicFromWad ("ram");
     scr_turtle = Draw_PicFromWad ("turtle");
 
 #ifdef _WIN32
@@ -406,6 +422,10 @@ void SCR_DrawTurtle (void) {
  * SCR_DrawNet
  */
 void SCR_DrawNet (void) {
+
+    if (!scr_shownet.value)
+        return;
+
     if (realtime - cl.last_received_message < 0.3 || cls.demoplayback)
         return;
 
@@ -413,7 +433,7 @@ void SCR_DrawNet (void) {
 }
 
 /*
- * DrawPause
+ * SCR_DrawPause
  */
 void SCR_DrawPause (void) {
     mpic_t       *pic;
@@ -424,8 +444,9 @@ void SCR_DrawPause (void) {
     if (!cl.paused)
         return;
 
+    Draw_FadeScreen ();
     pic = Draw_CachePic ("gfx/pause.lmp");
-    Draw_Pic ((vid.width - pic->width) / 2, (vid.height - 48 - pic->height) / 2, pic);
+    Draw_TransPic ((hudwidth - pic->width) / 2, (hudheight - 48 - pic->height) / 2, pic);
 }
 
 /*
@@ -437,8 +458,9 @@ void SCR_DrawLoading (void) {
     if (!scr_drawloading)
         return;
 
+    Draw_FadeScreen ();
     pic = Draw_CachePic ("gfx/loading.lmp");
-    Draw_Pic ((vid.width - pic->width) / 2, (vid.height - 48 - pic->height) / 2, pic);
+    Draw_TransPic ((hudwidth - pic->width) / 2, (hudheight - 48 - pic->height) / 2, pic);
 }
 
 // 
@@ -449,41 +471,50 @@ void SCR_DrawLoading (void) {
 void SCR_SetUpToDrawConsole (void) {
     float         conspeed;
 
+    if (scr_hudsize.value) {
+        conwidth = vid.conwidth / (1 + scr_hudsize.value);
+        conheight = conwidth * vid.conheight / vid.conwidth;
+    } else {
+        conwidth = vid.conwidth > vid.width ? vid.width : vid.conwidth;
+        conheight = vid.conheight > vid.height ? vid.height : vid.conheight;
+    }
+    conback->width = conwidth;
+    conback->height = conheight;
+
     Con_CheckResize ();
 
     if (scr_drawloading)
         return;                        // never a console with loading plaque
 
     // decide on the height of the console
-    con_forcedup = !cl.worldmodel || cls.signon != SIGNONS;
-
+    con_forcedup = (!cl.worldmodel || cls.signon != SIGNONS);
     if (con_forcedup) {
-        scr_conlines = vid.height;     // full screen
+        scr_conlines = conheight;      // full screen
         scr_con_current = scr_conlines;
     } else if (key_dest == key_console) {
-        if (scr_conswitch.value && vid.width > 640)
-            scr_conlines = vid.height;
+        if (scr_conswitch.value && conwidth > 480)
+            scr_conlines = conheight;
         else
-            scr_conlines = vid.height * scr_consize.value;
-        if (scr_conlines < 30)
-            scr_conlines = 30;
-        if (scr_conlines > vid.height)
-            scr_conlines = vid.height;
+            scr_conlines = conheight * scr_consize.value;
+        if (scr_conlines < 20)
+            scr_conlines = 20;
+        if (scr_conlines > conheight)
+            scr_conlines = conheight;
     } else {
         scr_conlines = 0;              // none visible
     }
 
     conspeed = scr_conspeed.value;
-    if (scr_conswitch.value && vid.width > 640)
+    if (scr_conswitch.value && conwidth > 480 && !con_forcedup)
         conspeed *= 2;
 
     if (scr_conlines < scr_con_current) {
-        scr_con_current -= conspeed * host_frametime * vid.height / 320;
+        scr_con_current -= conspeed * host_frametime * conheight / 320;
         if (scr_conlines > scr_con_current)
             scr_con_current = scr_conlines;
 
     } else if (scr_conlines > scr_con_current) {
-        scr_con_current += conspeed * host_frametime * vid.height / 320;
+        scr_con_current += conspeed * host_frametime * conheight / 320;
         if (scr_conlines < scr_con_current)
             scr_con_current = scr_conlines;
     }
@@ -500,15 +531,31 @@ void SCR_SetUpToDrawConsole (void) {
  */
 void SCR_DrawConsole (void) {
     if (scr_con_current) {
+        if (scr_hudsize.value) {
+            glPushMatrix ();
+            glMatrixMode (GL_PROJECTION);
+            glLoadIdentity ();
+            glOrtho (0, conwidth, conheight, 0, -99999, 99999);
+        }
         scr_copyeverything = 1;
         Con_DrawConsole (scr_con_current, true);
         clearconsole = 0;
-    } else {
-        if (key_dest == key_game || key_dest == key_message)
-            Con_DrawNotify ();         // only draw notify in game
+        if (scr_hudsize.value) {
+            glMatrixMode (GL_PROJECTION);
+            glLoadIdentity ();
+            glOrtho (0, vid.width, vid.height, 0, -99999, 99999);
+            glPopMatrix ();
+        }
     }
 }
 
+/*
+ * SCR_DrawNotify
+ */
+void SCR_DrawNotify (void) {
+    if (!scr_con_current && (key_dest == key_game || key_dest == key_message))
+        Con_DrawNotify ();             // only draw notify in game
+}
 // 
 
 int qglProject (float objx, float objy, float objz, float *model, float *proj, int *view, float *winx, float *winy,
@@ -697,13 +744,15 @@ void SCR_BeginLoadingPlaque (void) {
 
     scr_drawloading = true;
     scr_fullupdate = 0;
-    Sbar_Changed ();
+    //    Sbar_Changed (); // lxndr: no thanks
     SCR_UpdateScreen ();
     scr_drawloading = false;
 
     scr_disabled_for_loading = true;
     scr_disabled_time = realtime;
     scr_fullupdate = 0;
+
+    R_ClearLevels ();
 }
 
 /*
@@ -754,18 +803,22 @@ void SCR_DrawNotifyString (void) {
 void SCR_TileClear (void) {
     if (r_refdef.vrect.x > 0) {
         // left
-        Draw_TileClear (0, 0, r_refdef.vrect.x, vid.height - sb_lines);
+        Draw_TileClear (0, 0, r_refdef.vrect.x, vid.height - sb_lines * vid.height / hudheight);
         // right
         Draw_TileClear (r_refdef.vrect.x + r_refdef.vrect.width, 0, vid.width - r_refdef.vrect.x + r_refdef.vrect.width,
-                        vid.height - sb_lines);
+                        vid.height - sb_lines * vid.height / hudheight);
     }
     if (r_refdef.vrect.y > 0) {
         // top
         Draw_TileClear (r_refdef.vrect.x, 0, r_refdef.vrect.x + r_refdef.vrect.width, r_refdef.vrect.y);
         // bottom
         Draw_TileClear (r_refdef.vrect.x, r_refdef.vrect.y + r_refdef.vrect.height, r_refdef.vrect.width,
-                        vid.height - sb_lines - (r_refdef.vrect.height + r_refdef.vrect.y));
+                        vid.height - sb_lines * vid.height / hudheight - (r_refdef.vrect.height + r_refdef.vrect.y));
     }
+    // lxndr: sbar area
+    if (!scr_drawloading && !cl.intermission && ((scr_hudsize.value == 1.5 && scr_sbar.value) || scr_viewsize.value < 100.0))
+        Draw_TileClear (0, vid.height - sb_lines * vid.height / hudheight, vid.width,
+                        sb_lines * vid.height / hudheight);
 }
 
 /*
@@ -778,6 +831,8 @@ void SCR_TileClear (void) {
  * needs almost the entire 256k of stack space!
  */
 void SCR_UpdateScreen (void) {
+    extern double zoomtime;
+
     if (block_drawing)
         return;
 
@@ -800,52 +855,69 @@ void SCR_UpdateScreen (void) {
     }
 #endif
 
+    if (scr_hudsize.value) {
+        hudwidth = 320 / (scr_hudsize.value / 2 + 0.25);
+        hudheight = hudwidth * vid.height / vid.width;
+    } else {
+        hudwidth = vid.width;
+        hudheight = vid.height;
+    }
+
     vid.numpages = 2 + gl_triplebuffer.value;
 
     scr_copytop = 0;
     scr_copyeverything = 0;
 
-    if (oldsbar != cl_sbar.value) {
-        oldsbar = cl_sbar.value;
+    if (oldsbar != scr_sbar.value) {
+        oldsbar = scr_sbar.value;
         vid.recalc_refdef = true;
     }
-    // determine size of refresh window
     if (oldfov != scr_fov.value) {
         oldfov = scr_fov.value;
         vid.recalc_refdef = true;
     }
-
     if (oldscreensize != scr_viewsize.value) {
         oldscreensize = scr_viewsize.value;
         vid.recalc_refdef = true;
     }
+    if ((in_zoom.state & 1) != oldzoomstate || (zoomtime > 0 && zoomtime < 5)) {
+        oldzoomstate = (in_zoom.state & 1);
+        vid.recalc_refdef = true;
+    }
 
-    if (vid.recalc_refdef)
+    if (vid.recalc_refdef || scr_drawloading)
         SCR_CalcRefdef ();
 
     if ((v_contrast.value > 1 && !vid_hwgamma_enabled) || gl_clear.value)
         Sbar_Changed ();
 
+    SCR_SetUpToDrawConsole ();
+
     // do 3D refresh drawing, and then update the screen
     GL_BeginRendering (&glx, &gly, &glwidth, &glheight);
 
-    SCR_SetUpToDrawConsole ();
-
     V_RenderView ();
 
     SCR_SetupAutoID ();
-
     GL_Set2D ();
 
     // added by joe - IMPORTANT: this _must_ be here so that
     // palette flashes take effect in windowed mode too.
     R_PolyBlend ();
-
     R_Q3DamageDraw ();
 
+    R_BrightenScreen ();
+    R_CalcLuminance ();
+    R_DynamicContrast ();
+    V_UpdatePalette ();
+
     // draw any areas not covered by the refresh
     SCR_TileClear ();
-
+    if (scr_hudsize.value) {
+        glMatrixMode (GL_PROJECTION);
+        glLoadIdentity ();
+        glOrtho (0, hudwidth, hudheight, 0, -99999, 99999);
+    }
     if (scr_drawdialog) {
         Sbar_Draw ();
         Draw_FadeScreen ();
@@ -853,7 +925,6 @@ void SCR_UpdateScreen (void) {
         scr_copyeverything = true;
     } else if (scr_drawloading) {
         SCR_DrawLoading ();
-        Sbar_Draw ();
     } else if (cl.intermission == 1 && key_dest == key_game) {
         Sbar_IntermissionOverlay ();
         SCR_DrawVolume ();
@@ -872,20 +943,22 @@ void SCR_UpdateScreen (void) {
             SHOWLMP_drawall ();
         SCR_CheckDrawCenterString ();
         SCR_DrawClock ();
+        SCR_DrawDebug ();
         SCR_DrawFPS ();
         SCR_DrawSpeed ();
         SCR_DrawStats ();
-        SCR_DrawVolume ();
-        SCR_DrawPlaybackStats ();
+        //        SCR_DrawVolume ();
+        //        SCR_DrawPlaybackStats ();
+        SCR_DrawNotify ();
         Sbar_Draw ();
         SCR_DrawConsole ();
         M_Draw ();
     }
-
-    R_BrightenScreen ();
-
-    V_UpdatePalette ();
-
+    if (scr_hudsize.value) {
+        glMatrixMode (GL_PROJECTION);
+        glLoadIdentity ();
+        glOrtho (0, vid.width, vid.height, 0, -99999, 99999);
+    }
 #ifdef _WIN32
     Movie_UpdateScreen ();
 #endif
