@@ -21,11 +21,11 @@
 
 #include "quakedef.h"
 
-#define	BLOCK_WIDTH			128
+#define	BLOCK_WIDTH		128
 #define	BLOCK_HEIGHT		128
 
 #define MAX_LIGHTMAP_SIZE	4096
-#define	MAX_LIGHTMAPS		64
+#define	MAX_LIGHTMAPS		256    // lxndr: was 64
 
 static int    lightmap_textures;
 
@@ -456,11 +456,12 @@ void R_BlendLightmaps (void) {
     float        *v;
     glpoly_t     *p;
 
+    if (r_lightmap.value)              // lxndr: glEnable(GL_BLEND) > return
+        glEnable (GL_BLEND);
+
     glDepthMask (GL_FALSE);            // don't bother writing Z
     glBlendFunc (GL_ZERO, GL_ONE_MINUS_SRC_COLOR);
-
-    if (!r_lightmap.value)
-        glEnable (GL_BLEND);
+    glEnable (GL_BLEND);
 
     for (i = 0; i < MAX_LIGHTMAPS; i++) {
         if (!lightmap_polys[i])
@@ -549,17 +550,17 @@ void R_DrawWaterSurfaces (void) {
         return;
 
     if (blend) {
-        glEnable (GL_BLEND);
         //        glDepthMask (GL_FALSE); // lxndr: useless ?
+        glEnable (GL_BLEND);
     }
 
     for (s = waterchain; s; s = s->texturechain) {
         if (blend) {
-            if (s->flags & SURF_LAVA)
+            if (s->texinfo->flags & TEX_LAVA)
                 glColor4f (1, 1, 1, r_alphalava.value);
-            else if (s->flags & SURF_SLIME)
+            else if (s->texinfo->flags & TEX_SLIME)
                 glColor4f (1, 1, 1, r_alphaslime.value);
-            else if (s->flags & SURF_TELEPORT)
+            else if (s->texinfo->flags & TEX_TELEPORT)
                 glColor4f (1, 1, 1, r_alphateleport.value);
             else
                 glColor4f (1, 1, 1, r_alphawater.value);
@@ -666,6 +667,8 @@ static void R_ClearTextureChains (model_t * clmodel) {
     alphachain_tail = &alphachain;
 }
 
+#define ISUNDERWATER(x) ((x) == CONTENTS_WATER || (x) == CONTENTS_SLIME || (x) == CONTENTS_LAVA)
+#define TruePointContents(p) SV_HullPointContents(&cl.worldmodel->hulls[0], 0, p)
 /*
  * DrawTextureChains
  */
@@ -677,6 +680,12 @@ void DrawTextureChains (model_t * model) {
     qboolean      mtex_lightmaps, mtex_fbs, doMtex1, doMtex2, render_lightmaps = false;
     qboolean      draw_fbs, draw_mtex_fbs, can_mtex_lightmaps, can_mtex_fbs;
 
+    mleaf_t      *leaf;
+    int           isunderwater = 0;
+    leaf = Mod_PointInLeaf (modelorg, cl.worldmodel);
+    if (ISUNDERWATER (leaf->contents)) // lxndr
+        isunderwater = 1;              // lxndr: FIXME: it flags world as underwater if player underwater
+
     if (gl_fb_bmodels.value) {
         can_mtex_lightmaps = gl_mtexable;
         can_mtex_fbs = gl_textureunits >= 3;
@@ -792,7 +801,7 @@ void DrawTextureChains (model_t * model) {
                 }
                 glEnd ();
 
-                if (waterline && gl_caustics.value && underwatertexture) {
+                if ((isunderwater || waterline) && gl_caustics.value && underwatertexture) {
                     s->polys->caustics_chain = caustics_polys;
                     caustics_polys = s->polys;
                 }
@@ -870,6 +879,11 @@ void R_DrawBrushModel (entity_t * ent) {
             return;
     }
 
+    if (!gl_ztrick.value) {
+        glEnable (GL_POLYGON_OFFSET_FILL);
+        glEnable (GL_POLYGON_OFFSET_LINE);
+    }
+
     if (ISTRANSPARENT (ent)) {
         glEnable (GL_BLEND);
         glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
@@ -920,11 +934,13 @@ void R_DrawBrushModel (entity_t * ent) {
             || (!(psurf->flags & SURF_PLANEBACK) && (dot > BACKFACE_EPSILON))) {
             if (psurf->flags & SURF_DRAWSKY) {
                 CHAIN_SURF_B2F (psurf, skychain);
-            } else if (psurf->flags & SURF_DRAWTURB) {  // lxndr: water surfaces are drawn elsewhere
+            } else if (psurf->flags & SURF_DRAWTURB) {  // lxndr: water surfaces are drawn elsewhere, doesn't seems to be used anyway
                 EmitWaterPolys (psurf);
-            } else {
+            } else if (!(psurf->flags & SURF_PLANEBACK)) {
                 underwater = (psurf->flags & SURF_UNDERWATER) ? 1 : 0;
                 CHAIN_SURF_B2F (psurf, psurf->texinfo->texture->texturechain[underwater]);
+            } else {
+                CHAIN_SURF_B2F (psurf, psurf->texinfo->texture->texturechain[0]);
             }
         }
     }
@@ -939,6 +955,12 @@ void R_DrawBrushModel (entity_t * ent) {
         glColor3ubv (color_white);
         glDisable (GL_BLEND);
     }
+
+    if (!gl_ztrick.value) {
+        glDisable (GL_POLYGON_OFFSET_FILL);
+        glDisable (GL_POLYGON_OFFSET_LINE);
+    }
+
 }
 
 /*
@@ -1288,9 +1310,9 @@ void GL_BuildLightmaps (void) {
         r_pcurrentvertbase = m->vertexes;
         currentmodel = m;
         for (i = 0; i < m->numsurfaces; i++) {
-            GL_CreateSurfaceLightmap (m->surfaces + i);
             if (m->surfaces[i].flags & (SURF_DRAWTURB | SURF_DRAWSKY))
                 continue;
+            GL_CreateSurfaceLightmap (m->surfaces + i);
             BuildSurfaceDisplayList (m->surfaces + i);
         }
     }
