@@ -33,6 +33,7 @@ static msurface_t *warpface;
 
 qboolean      r_skyboxloaded;
 
+//cvar_t        gl_subdivide_size = { "gl_subdivide_size", "64", CVAR_ARCHIVE };
 extern cvar_t gl_subdivide_size;
 
 extern byte  *StringToRGB (char *s);
@@ -246,7 +247,12 @@ void EmitWaterPolys (msurface_t * fa) {
             t = ot + SINTABLE_APPROX (os * 0.125 + cl.time);
             t *= (1.0 / 64);
 
-            glTexCoord2f (s, t);
+            if (gl_mtexable) {
+                qglMultiTexCoord2f (GL_TEXTURE0_ARB, s, t);
+                qglMultiTexCoord2f (GL_TEXTURE1_ARB, s, t);
+            } else {
+                glTexCoord2f (s, t);
+            }
             glVertex3fv (v);
         }
         glEnd ();
@@ -395,27 +401,16 @@ void R_InitSky (miptex_t * mt) {
     ((byte *) & transpix)[2] = b / (128 * 128);
     ((byte *) & transpix)[3] = 0;
 
-    if (!solidskytexture)
-        solidskytexture = texture_extension_number++;
+    solidskytexture = GL_LoadTexture ("solidskytexture", 128, 128, (byte *) trans, TEX_MIPMAP | TEX_SKY, 4);
 
-    GL_Bind (solidskytexture);
-    glTexImage2D (GL_TEXTURE_2D, 0, gl_solid_format, 128, 128, 0, GL_RGBA, GL_UNSIGNED_BYTE, trans);
-    glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-    glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-
-    for (i = 0; i < 128; i++)
+    for (i = 0; i < 128; i++) {
         for (j = 0; j < 128; j++) {
             p = src[i * 256 + j];
             trans[(i * 128) + j] = p ? d_8to24table[p] : transpix;
         }
+    }
 
-    if (!alphaskytexture)
-        alphaskytexture = texture_extension_number++;
-
-    GL_Bind (alphaskytexture);
-    glTexImage2D (GL_TEXTURE_2D, 0, gl_alpha_format, 128, 128, 0, GL_RGBA, GL_UNSIGNED_BYTE, trans);
-    glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-    glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+    alphaskytexture = GL_LoadTexture ("alphaskytexture", 128, 128, (byte *) trans, TEX_ALPHA | TEX_SKY, 4);
 }
 
 static char  *skybox_ext[6] = { "rt", "bk", "lf", "ft", "up", "dn" };
@@ -432,7 +427,7 @@ int R_SetSky (char *skyname) {
             && !(data[i] = GL_LoadImagePixels (va ("gfx/env/%s%s", skyname, skybox_ext[i]), 0, 0, 0))
             && !(data[i] = GL_LoadImagePixels (va ("env/%s_%s", skyname, skybox_ext[i]), 0, 0, 0))
             && !(data[i] = GL_LoadImagePixels (va ("gfx/env/%s_%s", skyname, skybox_ext[i]), 0, 0, 0))) {
-            Con_Printf ("Couldn't load skybox \"%s\"\n", skyname);
+            Con_Warnf ("Couldn't load skybox \"%s\"\n", skyname);
             error = 1;
 
             goto cleanup;
@@ -740,10 +735,13 @@ void EmitCausticsPolys (void) {
     float        *v, s, t, os, ot;
     extern glpoly_t *caustics_polys;
 
+    if (!caustics_polys)
+        return;
+
     GL_Bind (underwatertexture);
     glTexEnvf (GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_DECAL);
     glEnable (GL_BLEND);
-    glBlendFunc (GL_DST_COLOR, GL_SRC_COLOR);
+    glBlendFunc (GL_DST_COLOR, GL_DST_COLOR);   // lxndr: GL_SRC_COLOR > GL_ZERO
 
     for (p = caustics_polys; p; p = p->caustics_chain) {
         glBegin (GL_POLYGON);
@@ -751,13 +749,18 @@ void EmitCausticsPolys (void) {
             os = v[3];
             ot = v[4];
 
-            s = os + SINTABLE_APPROX (0.465 * (cl.time + ot));
+            s = os + SINTABLE_APPROX (0.265 * (cl.time + ot));  // lxndr: was 0.465
             s *= -3 * (0.5 / 64);
 
-            t = ot + SINTABLE_APPROX (0.465 * (cl.time + os));
+            t = ot + SINTABLE_APPROX (0.265 * (cl.time + os));  // lxndr: was 0.465
             t *= -3 * (0.5 / 64);
 
-            glTexCoord2f (s, t);
+            if (gl_mtexable) {         // lxndr: from demonquake
+                qglMultiTexCoord2f (GL_TEXTURE0_ARB, s, t);
+                qglMultiTexCoord2f (GL_TEXTURE1_ARB, s, t);
+            } else {
+                glTexCoord2f (s, t);
+            }
             glVertex3fv (v);
         }
         glEnd ();
