@@ -233,7 +233,7 @@ void Host_WriteConfig (char *cfgname) {
     FILE         *f;
 
     if (!(f = fopen (va ("%s/%s", com_gamedir, cfgname), "w"))) {
-        Con_Printf ("Couldn't write %s in %s\n", cfgname, com_gamedir);
+        Con_Warnf ("Couldn't write %s in %s\n", cfgname, com_gamedir);
         return;
     }
 
@@ -478,17 +478,9 @@ void Host_ClearMemory (void) {
  * Returns false if the time is too short to run a frame
  */
 qboolean Host_FilterTime (double time) {
-    double        fps;
-
     realtime += time;
 
-#ifndef __DEVEL__
-    fps = bound (MIN_FPS, cl_maxfps.value, MAX_FPS);    // lxndr: was max(10,value);
-#else
-    fps = cl_maxfps.value;
-#endif
-
-    if (!cls.capturedemo && !cls.timedemo && realtime - oldrealtime < 1.0 / fps)
+    if (!cls.capturedemo && !cls.timedemo && realtime - oldrealtime < 1.0 / cl_maxfps.value)
         return false;
 
 #ifdef _WIN32
@@ -507,6 +499,9 @@ qboolean Host_FilterTime (double time) {
         // don't allow really long or short frames
         host_frametime = bound (0.001, host_frametime, 0.1);
 
+    if (quore && cl.time < 5)
+        host_frametime *= (1.0 - 1.0 / (cl.time * cl.time + 1.0));
+
     return true;
 }
 
@@ -514,15 +509,7 @@ qboolean Host_FilterTime (double time) {
  * MinPhysFrameTime
  */
 static double MinPhysFrameTime (void) {
-    float         fpscap;
-
-#ifndef __DEVEL__
-    fpscap = bound (MIN_FPS, cl_maxfps.value, MAX_FPS);
-#else
-    fpscap = cl_maxfps.value;
-#endif
-
-    return 1 / fpscap;
+    return 1 / cl_maxfps.value;
 }
 
 /*
@@ -731,9 +718,8 @@ void _Host_Frame (double time) {
         // don't allow cheats when recording a single player demo
         if (cls.demorecording) {
             Cvar_SetValue (&cl_truelightning, 0);
-            // don't allow higher than MAX_FPS fps during recording
-            if (cl_maxfps.value > MAX_FPS)
-                Cvar_SetValue (&cl_maxfps, MAX_FPS);
+            if (cl_maxfps.value > DEFAULT_FPS)
+                Cvar_SetValue (&cl_maxfps, DEFAULT_FPS);
         }
     }
 
@@ -830,7 +816,6 @@ void Host_InitVCR (quakeparms_t * parms) {
     }
 }
 
-#include "binds.h"
 /*
  * Host_Init
  */
@@ -911,35 +896,36 @@ void Host_Init (quakeparms_t * parms) {
 
     Con_Printf ("Exe: " __TIME__ " " __DATE__ "\n");
     Con_Printf ("Hunk allocation: %4.1f MB\n", (float) parms->memsize / (1024 * 1024));
-
     Con_Printf ("\n%s version %s\n\n", ENGINE_NAME, VersionString ());
     Con_Printf ("\x1d\x1e\x1e\x1e\x1e\x1e\x1e\x1e %s Initialized \x1e\x1e\x1e\x1e\x1e\x1e\x1e\x1f\n", ENGINE_NAME);
 
 #ifdef GLQUAKE
     if (quore) {
-        Cvar_ForceSet (&ambience, "underworld");
-        Cvar_SetValue (&ambiencehd, 1);
+        Cvar_SetDefault (&gl_consolefont, "charset");
+        Cvar_SetDefault (&gl_fb_bmodels, "1");
         Cvar_SetValue (&r_novis, 1);
-        Cvar_ForceSet (&r_quality, "1");
     }
 #endif
 
-    // lxndr: quake.rc replacement
-    if (COM_CheckParm ("-legacy")) {
+    if (legacy) {
         Con_Printf ("%s's default settings disabled\n", ENGINE_NAME);
         Cbuf_AddText ("exec quake.rc\n");
+        Cbuf_AddText ("mode legacy\n");
     } else {
         Con_Printf ("%s's default settings enabled\n", ENGINE_NAME);
-        Cbuf_AddText (ENGINE_BINDS);
+        Cbuf_AddText ("resetbinds\n");
         Cbuf_AddText ("exec config.cfg\n");
         Cbuf_AddText ("exec autoexec.cfg\n");
         Cbuf_AddText ("stuffcmds\n");
         if (quore)
-            Cbuf_AddText ("map start\n");
+            M_Menu_Main_f ();
         else
             Cbuf_AddText ("startdemos demo1 demo2 demo3\n");
     }
-    Cbuf_AddText ("cl_warncmd 1\n");
+//    Cbuf_AddText ("cl_warncmd 1\n");
+
+    if (quore)
+        Cbuf_AddText ("mode quore");
 
 #ifdef GLQUAKE
     if (nehahra)
