@@ -31,13 +31,13 @@ void          Mod_Print (void);
 
 qboolean OnChange_reload (cvar_t * var, char *string) {
 #ifdef GLQUAKE
-    GL_ResetTextures ();
+    R_ResetTextures ();
 #endif
 
     Host_Reload ();
 
 #ifdef GLQUAKE
-    GL_RefreshTextures ();
+    refresh_levels = true;
 #endif
     return false;
 }
@@ -273,14 +273,15 @@ void Host_Map_f (void) {
     }
 #endif
 
+    key_dest = key_game;               // remove console or menu
+    SCR_BeginLoadingPlaque ();
+
     cls.demonum = -1;                  // stop demo loop in case this fails
+    strcpy (name, Cmd_Argv (1));       // lxndr: FIXME: Cmd_Argv is cleared when calling SCR_UpdateScreen from CL_Disconnect
 
     CL_Disconnect ();
     Host_ShutdownServer (false);
 
-    key_dest = key_game;               // remove console or menu
-    SCR_BeginLoadingPlaque ();
-
     cls.mapstring[0] = 0;
     for (i = 0; i < Cmd_Argc (); i++) {
         strcat (cls.mapstring, Cmd_Argv (i));
@@ -289,7 +290,6 @@ void Host_Map_f (void) {
     strcat (cls.mapstring, "\n");
 
     svs.serverflags = 0;               // haven't completed an episode yet
-    strcpy (name, Cmd_Argv (1));
     SV_SpawnServer (name);
     if (!sv.active)
         return;
@@ -326,6 +326,10 @@ void Host_Changelevel_f (void) {
         Con_Printf ("Only the server may changelevel\n");
         return;
     }
+
+    key_dest = key_game;               // remove console or menu
+    SCR_BeginLoadingPlaque ();
+
     SV_SaveSpawnparms ();
     strcpy (level, Cmd_Argv (1));
     SV_SpawnServer (level);
@@ -371,11 +375,15 @@ extern char   server_name[MAX_QPATH];
 void Host_Connect_f (void) {
     char          name[MAX_QPATH];
 
+    key_dest = key_game;               // remove console or menu
+    SCR_BeginLoadingPlaque ();
+
     cls.demonum = -1;                  // stop demo loop in case this fails
     if (cls.demoplayback) {
         CL_StopPlayback ();
         CL_Disconnect ();
     }
+
     Q_strncpyz (name, Cmd_Argv (1), MAX_QPATH);
     CL_EstablishConnection (name);
     Host_Reconnect_f ();
@@ -463,7 +471,7 @@ void Host_Savegame_f (void) {
 
     Con_Printf ("Saving game to %s...\n", name);
     if (!(f = fopen (name, "w"))) {
-        Con_Printf ("ERROR: couldn't open\n");
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
@@ -523,7 +531,7 @@ void Host_Loadgame_f (void) {
 
     Con_Printf ("Loading game from %s...\n", name);
     if (!(f = fopen (name, "r"))) {
-        Con_Printf ("ERROR: couldn't open.\n");
+        Con_Warnf ("Couldn't open %s.\n", name);
         return;
     }
 
@@ -547,10 +555,9 @@ void Host_Loadgame_f (void) {
     fscanf (f, "%f\n", &time);
 
     CL_Disconnect_f ();
-
     SV_SpawnServer (mapname);
     if (!sv.active) {
-        Con_Printf ("Couldn't load map\n");
+        Con_Warnf ("Couldn't load map\n");
         return;
     }
     sv.paused = true;                  // pause until all clients connect
@@ -631,7 +638,7 @@ void Host_Reload (void) {
 
     Con_DPrintf ("Saving game to %s...\n", name);
     if (!(f = fopen (name, "w"))) {
-        Con_Printf ("ERROR: couldn't open\n");
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
@@ -661,7 +668,7 @@ void Host_Reload (void) {
 
     Con_DPrintf ("Loading game from %s...\n", name);
     if (!(f = fopen (name, "r"))) {
-        Con_Printf ("ERROR: couldn't open.\n");
+        Con_Warnf ("Couldn't open %s.\n", name);
         return;
     }
 
@@ -679,10 +686,9 @@ void Host_Reload (void) {
     fscanf (f, "%f\n", &time);
 
     CL_Disconnect_f ();
-
     SV_SpawnServer (mapname);
     if (!sv.active) {
-        Con_Printf ("Couldn't load map\n");
+        Con_Warnf ("Couldn't load map\n");
         return;
     }
     sv.paused = true;                  // pause until all clients connect
@@ -1001,11 +1007,12 @@ void Host_Pause_f (void) {
     } else {
         sv.paused ^= 1;
 
-        if (sv.paused)
-            SV_BroadcastPrintf ("%s paused the game\n", pr_strings + sv_player->v.netname);
-        else
-            SV_BroadcastPrintf ("%s unpaused the game\n", pr_strings + sv_player->v.netname);
-
+        if (svs.maxclients != 1) {
+            if (sv.paused)
+                SV_BroadcastPrintf ("%s paused the game\n", pr_strings + sv_player->v.netname);
+            else
+                SV_BroadcastPrintf ("%s unpaused the game\n", pr_strings + sv_player->v.netname);
+        }
         // send notification to all clients
         MSG_WriteByte (&sv.reliable_datagram, svc_setpause);
         MSG_WriteByte (&sv.reliable_datagram, sv.paused);
@@ -1581,7 +1588,7 @@ void Host_GetCoords_f (void) {
         return;
 
     if (cls.state != ca_connected) {
-        Con_Printf ("ERROR: You must be connected\n");
+        Con_Warnf ("You must be connected\n");
         return;
     }
 
@@ -1598,7 +1605,7 @@ void Host_GetCoords_f (void) {
     COM_DefaultExtension (name, ".cam");
 
     if (!(f = fopen (va ("%s/%s", com_gamedir, name), "a"))) {
-        Con_Printf ("Couldn't write %s\n", name);
+        Con_Warnf ("Couldn't write %s\n", name);
         return;
     }
 
