@@ -40,12 +40,9 @@ int           key_insert = 1;
 int           key_count;               // incremented every key event
 
 char         *keybindings[256];
-qboolean      consolekeys[256];        // if true, can't be rebound while in
-                                       // console
-qboolean      menubound[256];          // if true, can't be rebound while in
-                                       // menu
-int           keyshift[256];           // key to map to if shift held down in
-                                       // console
+qboolean      consolekeys[256];        // if true, can't be rebound while in console
+qboolean      menubound[256];          // if true, can't be rebound while in menu
+int           keyshift[256];           // key to map to if shift held down in console
 int           key_repeats[256];        // if > 1, it is autorepeating
 qboolean      keydown[256];
 
@@ -197,6 +194,9 @@ keyname_t     keynames[] = {
     {"MWHEELUP", K_MWHEELUP},
     {"MWHEELDOWN", K_MWHEELDOWN},
 
+    {"VOLUMEUP", K_VOLUMEUP},
+    {"VOLUMEDOWN", K_VOLUMEDOWN},
+
     {"SEMICOLON", ';'},                // because a raw semicolon seperates commands
 
     {NULL, 0}
@@ -227,10 +227,11 @@ static void AdjustConsoleHeight (int delta) {
 
     if (!cl.worldmodel || cls.signon != SIGNONS)
         return;
+
     height = (scr_consize.value * vid.height + delta + 5) / 10;
     height *= 10;
-    if (delta < 0 && height < 30)
-        height = 30;
+    if (delta < 0 && height < 10)
+        height = 10;
     if (delta > 0 && height > vid.height - 10)
         height = vid.height - 10;
     Cvar_SetValue (&scr_consize, (float) height / vid.height);
@@ -686,6 +687,18 @@ void Key_Unbindall_f (void) {
             Key_Unbind (i);
 }
 
+void Key_ResetAll (void) {
+    Key_Unbindall_f ();
+
+    // lxndr: this would be much better to call the bind function directly
+    Cbuf_AddText (ENGINE_BINDS);
+    Cbuf_Execute ();
+}
+
+void Key_ResetBinds_f (void) {
+    Key_ResetAll ();
+}
+
 static void Key_PrintBindInfo (int keynum, char *keyname) {
     if (!keyname)
         keyname = Key_KeynumToString (keynum);
@@ -745,8 +758,6 @@ void Key_Bind_f (void) {
         strcat (cmd, Cmd_Argv (i));
     }
 
-    if (developer.value > 1)
-        Con_Printf ("binding %s with '%s'\n", Cmd_Argv (1), cmd);
     Key_SetBinding (b, cmd);
 }
 
@@ -854,6 +865,7 @@ void Key_Init (void) {
     Cmd_AddCommand ("bind", Key_Bind_f);
     Cmd_AddCommand ("unbind", Key_Unbind_f);
     Cmd_AddCommand ("unbindall", Key_Unbindall_f);
+    Cmd_AddCommand ("resetbinds", Key_ResetBinds_f);
 
     Cvar_Register (&cl_chatmode);
 }
@@ -955,12 +967,11 @@ void Key_Event (int key, qboolean down) {
         }
         return;
     }
-    // key up events only generate commands if the game key binding is
-    // a button command (leading + sign). These will occur even in console
-    // mode,
-    // to keep the character from continuing an action started before a console
-    // switch. Button commands include the kenum as a parameter, so multiple
-    // downs can be matched with ups
+    // key up events only generate commands if the game key binding is a button
+    // command (leading + sign). These will occur even in console mode, to keep
+    // the character from continuing an action started before a console switch.
+    // Button commands include the kenum as a parameter, so multiple downs can
+    // be matched with ups
     if (!down) {
         kb = keybindings[key];
         if (kb && kb[0] == '+') {
@@ -977,9 +988,9 @@ void Key_Event (int key, qboolean down) {
         return;
     }
     // if not a consolekey, send to the interpreter no matter what mode is
-    if ((key_dest == key_menu && menubound[key]) || (key_dest == key_console && !consolekeys[key]) || (key_dest == key_game && (!con_forcedup || !consolekeys[key])))   // ||
-        // 
-        // (Key_isSpecial(key) && keybindings[key] != NULL))
+    if ((key_dest == key_menu && menubound[key]) || (key_dest == key_console && !consolekeys[key])
+        || (key_dest == key_game && (!con_forcedup || !consolekeys[key])))
+        // || (Key_isSpecial(key) && keybindings[key] != NULL))
     {
         if (cls.demoplayback && Key_DemoKey (key))
             return;
