@@ -63,22 +63,12 @@ int           unreliableMessagesSent = 0;
 int           unreliableMessagesReceived = 0;
 
 cvar_t        net_messagetimeout = { "net_messagetimeout", "300" };
-cvar_t        net_connecttimeout = { "net_connecttimeout", "10" };      // joe:
-                                                                        // qkick/qflood
-                                                                        // protection
-                                                                        // from
-                                                                        // ProQuake
+cvar_t        net_connecttimeout = { "net_connecttimeout", "10" };      // joe: qkick/qflood protection from ProQuake
 cvar_t        hostname = { "hostname", "UNNAMED" };
-cvar_t        cl_password = { "cl_password", "" };      // joe: password
-                                                        // protection from
-                                                        // ProQuake
-cvar_t        rcon_password = { "rcon_password", "" };  // joe: rcon password
-                                                        // from ProQuake
-cvar_t        rcon_server = { "rcon_server", "" };      // joe: rcon server
-                                                        // from ProQuake
-char          server_name[MAX_QPATH];  // joe: use the current server if
-                                       // rcon_server is not set - ProQuake
-                                       // stuff
+cvar_t        cl_password = { "cl_password", "" };      // joe: password protection from ProQuake
+cvar_t        rcon_password = { "rcon_password", "" };  // joe: rcon password from ProQuake
+cvar_t        rcon_server = { "rcon_server", "" };      // joe: rcon server from ProQuake
+char          server_name[MAX_QPATH];  // joe: use the current server if rcon_server is not set - ProQuake stuff
 
 // joe: rcon from ProQuake
 #define RCON_BUFF_SIZE	8192
@@ -87,14 +77,14 @@ sizebuf_t     rcon_message = { false, false, rcon_buff, RCON_BUFF_SIZE, 0 };
 qboolean      rcon_active = false;
 
 qboolean      configRestored = false;
-cvar_t        config_com_port = { "_config_com_port", "0x3f8", CVAR_ARCHIVE };
-cvar_t        config_com_irq = { "_config_com_irq", "4", CVAR_ARCHIVE };
-cvar_t        config_com_baud = { "_config_com_baud", "57600", CVAR_ARCHIVE };
-cvar_t        config_com_modem = { "_config_com_modem", "1", CVAR_ARCHIVE };
-cvar_t        config_modem_dialtype = { "_config_modem_dialtype", "T", CVAR_ARCHIVE };
-cvar_t        config_modem_clear = { "_config_modem_clear", "ATZ", CVAR_ARCHIVE };
-cvar_t        config_modem_init = { "_config_modem_init", "", CVAR_ARCHIVE };
-cvar_t        config_modem_hangup = { "_config_modem_hangup", "AT H", CVAR_ARCHIVE };
+cvar_t        config_com_port = { "_config_com_port", "0x3f8" };
+cvar_t        config_com_irq = { "_config_com_irq", "4" };
+cvar_t        config_com_baud = { "_config_com_baud", "57600" };
+cvar_t        config_com_modem = { "_config_com_modem", "1" };
+cvar_t        config_modem_dialtype = { "_config_modem_dialtype", "T" };
+cvar_t        config_modem_clear = { "_config_modem_clear", "ATZ" };
+cvar_t        config_modem_init = { "_config_modem_init", "" };
+cvar_t        config_modem_hangup = { "_config_modem_hangup", "AT H" };
 
 #ifdef IDGODS
 cvar_t        idgods = { "idgods", "0" };
