@@ -219,7 +219,6 @@ void PF_setmodel (void) {
 
     e->v.model = m - pr_strings;
     e->v.modelindex = i;               // SV_ModelIndex (m);
-
     mod = sv.models[(int) e->v.modelindex];     // Mod_ForName (m, true);
 
     if (mod)
@@ -439,11 +438,17 @@ void PF_ambientsound (void) {
         return;
     }
     // add an svc_spawnambient command to the level signon packet
-    MSG_WriteByte (&sv.signon, svc_spawnstaticsound);
+    if (soundnum > 255)
+        MSG_WriteByte (&sv.signon, svc_spawnstaticsound2);
+    else
+        MSG_WriteByte (&sv.signon, svc_spawnstaticsound);
     for (i = 0; i < 3; i++)
         MSG_WriteCoord (&sv.signon, pos[i]);
 
-    MSG_WriteByte (&sv.signon, soundnum);
+    if (soundnum > 255)
+        MSG_WriteShort (&sv.signon, soundnum);
+    else
+        MSG_WriteByte (&sv.signon, soundnum);
 
     MSG_WriteByte (&sv.signon, vol * 255);
     MSG_WriteByte (&sv.signon, attenuation * 64);
@@ -1317,14 +1322,31 @@ int           SV_ModelIndex (char *name);
 void PF_makestatic (void) {
     int           i;
     edict_t      *ent;
+    int           bits = 0;
 
     ent = G_EDICT (OFS_PARM0);
 
-    MSG_WriteByte (&sv.signon, svc_spawnstatic);
+    // lxndr: from fitzquake
+    if (SV_ModelIndex (pr_strings + ent->v.model) & 0xFF00)
+        bits |= B_MODEL;
+    if ((int) (ent->v.frame) & 0xFF00)
+        bits |= B_FRAME;
 
-    MSG_WriteByte (&sv.signon, SV_ModelIndex (pr_strings + ent->v.model));
+    if (bits) {
+        MSG_WriteByte (&sv.signon, svc_spawnstatic2);
+        MSG_WriteByte (&sv.signon, bits);
+    } else {
+        MSG_WriteByte (&sv.signon, svc_spawnstatic);
+    }
+    if (bits & B_MODEL)
+        MSG_WriteShort (&sv.signon, SV_ModelIndex (pr_strings + ent->v.model));
+    else
+        MSG_WriteByte (&sv.signon, SV_ModelIndex (pr_strings + ent->v.model));
+    if (bits & B_FRAME)
+        MSG_WriteShort (&sv.signon, ent->v.frame);
+    else
+        MSG_WriteByte (&sv.signon, ent->v.frame);
 
-    MSG_WriteByte (&sv.signon, ent->v.frame);
     MSG_WriteByte (&sv.signon, ent->v.colormap);
     MSG_WriteByte (&sv.signon, ent->v.skin);
     for (i = 0; i < 3; i++) {
