@@ -203,8 +203,6 @@ void Draw_Pixel (int x, int y, byte color) {
     *dest = color;
 }
 
-#define		NUMCROSSHAIRS	5
-
 static qboolean crosshairdata[NUMCROSSHAIRS][64] = {
     {false, false, false, true, false, false, false, false,
      false, false, false, false, false, false, false, false,
@@ -612,6 +610,7 @@ void Draw_CharToConback (int num, byte * dest) {
  * Draw_ConsoleBackground
  */
 void Draw_ConsoleBackground (int lines, float xscale) {
+    int           width;
     int           x, y, v, f, fstep;
     byte         *src, *dest;
     mpic_t       *conback;
@@ -634,12 +633,13 @@ void Draw_ConsoleBackground (int lines, float xscale) {
     for (y = 0; y < lines; y++, dest += vid.rowbytes) {
         v = (vid.conheight - lines + y) * 200 / vid.conheight;
         src = conback->data + v * 320;
+        width = vid.conwidth * xscale;
         if (vid.conwidth == 320)
             memcpy (dest, src, vid.conwidth);
         else {
             f = 0;
-            fstep = 320 * 0x10000 / vid.conwidth * xscale;      // lxndr: xscale not tested
-            for (x = 0; x < vid.conwidth; x += 4) {
+            fstep = 320 * 0x10000 / width;
+            for (x = 0; x < width; x += 4) {
                 dest[x] = src[f >> 16];
                 f += fstep;
                 dest[x + 1] = src[f >> 16];
@@ -777,9 +777,7 @@ void Draw_FadeScreen (void) {
     int           x, y;
     byte         *pbuf;
 
-    VID_UnlockBuffer ();
     S_ExtraUpdate ();
-    VID_LockBuffer ();
 
     for (y = 0; y < vid.height; y++) {
         int           t;
@@ -793,9 +791,7 @@ void Draw_FadeScreen (void) {
         }
     }
 
-    VID_UnlockBuffer ();
     S_ExtraUpdate ();
-    VID_LockBuffer ();
 }
 
 // 
