@@ -588,14 +588,9 @@ void R_ScanEdges (void) {
 
         (*pdrawfunc) ();
 
-        // flush the span list if we can't be sure we have enough spans left
-        // for
-        // the next scan
+        // flush the span list if we can't be sure we have enough spans left for the next scan
         if (span_p > max_span_p) {
-            VID_UnlockBuffer ();
-            S_ExtraUpdate ();          // don't let sound get messed up if
-            // going slow
-            VID_LockBuffer ();
+            S_ExtraUpdate ();          // don't let sound get messed up if going slow
 
             D_DrawSurfaces ();
 
