@@ -308,7 +308,8 @@ void R_SetVrect (vrect_t * pvrectin, vrect_t * pvrect, int lineadj) {
     }
     size /= 100.0;
 
-    h = (!cl_sbar.value && full) ? pvrectin->height : pvrectin->height - lineadj;
+    //    h = (!scr_sbar.value && full) ? pvrectin->height : pvrectin->height - lineadj;
+    h = pvrectin->height;
 
     pvrect->width = full ? pvrectin->width : pvrectin->width * size;
 
@@ -319,7 +320,7 @@ void R_SetVrect (vrect_t * pvrectin, vrect_t * pvrect, int lineadj) {
     pvrect->width &= ~7;
     pvrect->height = pvrectin->height * size;
 
-    if (cl_sbar.value || !full) {
+    if ( /*scr_sbar.value || */ !full) {
         if (pvrect->height > pvrectin->height - lineadj)
             pvrect->height = pvrectin->height - lineadj;
     } else if (pvrect->height > pvrectin->height) {
@@ -355,7 +356,6 @@ void R_ViewChanged (vrect_t * pvrect, int lineadj, float aspect) {
 
     R_SetVrect (pvrect, &r_refdef.vrect, lineadj);
 
-    r_refdef.horizontalFieldOfView = 2.0 * tan (r_refdef.fov_x / 360 * M_PI);
     r_refdef.fvrectx = (float) r_refdef.vrect.x;
     r_refdef.fvrectx_adj = (float) r_refdef.vrect.x - 0.5;
     r_refdef.vrect_x_adj_shift20 = (r_refdef.vrect.x << 20) + (1 << 19) - 1;
@@ -381,12 +381,24 @@ void R_ViewChanged (vrect_t * pvrect, int lineadj, float aspect) {
     xOrigin = r_refdef.xOrigin;
     yOrigin = r_refdef.yOrigin;
 
+#ifdef __DEVEL__
+    pixelAspect = 1;
+    if (aspect < 320 / 240) {
+        r_refdef.horizontalFieldOfView = 2.0 * tan (r_refdef.fov_x / 360 * M_PI);
+        verticalFieldOfView = r_refdef.horizontalFieldOfView / 320 * 240;
+    } else {
+        verticalFieldOfView = 2.0 * tan (r_refdef.fov_y / 360 * M_PI);
+        r_refdef.horizontalFieldOfView = verticalFieldOfView / 240 * 320;
+    }
+#else
     screenAspect = r_refdef.vrect.width * pixelAspect / r_refdef.vrect.height;
     // 320*200 1.0 pixelAspect = 1.6 screenAspect
     // 320*240 1.0 pixelAspect = 1.3333 screenAspect
     // proper 320*200 pixelAspect = 0.8333333
 
+    r_refdef.horizontalFieldOfView = 2.0 * tan (r_refdef.fov_x / 360 * M_PI);
     verticalFieldOfView = r_refdef.horizontalFieldOfView / screenAspect;
+#endif
 
     // values for perspective projection
     // if math were exact, the values would range from 0.5 to to range+0.5
@@ -435,9 +447,18 @@ void R_ViewChanged (vrect_t * pvrect, int lineadj, float aspect) {
     for (i = 0; i < 4; i++)
         VectorNormalize (screenedge[i].normal);
 
+#ifdef __DEVEL__
+    if (aspect < 320 / 240)
+        res_scale =
+            sqrt ((double) (r_refdef.vrect.width * r_refdef.vrect.height) / (320.0 * 152.0)) * (2.0 /
+                                                                                                r_refdef.horizontalFieldOfView);
+    else
+        res_scale = 1;
+#else
     res_scale =
         sqrt ((double) (r_refdef.vrect.width * r_refdef.vrect.height) / (320.0 * 152.0)) * (2.0 /
                                                                                             r_refdef.horizontalFieldOfView);
+#endif
     r_aliastransition = r_aliastransbase.value * res_scale;
     r_resfudge = r_aliastransadj.value * res_scale;
 
@@ -818,10 +839,7 @@ void R_EdgeDrawing (void) {
     }
 
     if (!r_dspeeds.value) {
-        VID_UnlockBuffer ();
-        S_ExtraUpdate ();              // don't let sound get messed up if
-        // going slow
-        VID_LockBuffer ();
+        S_ExtraUpdate ();              // don't let sound get messed up if going slow
     }
 
     R_ScanEdges ();
@@ -849,10 +867,8 @@ void R_RenderView_ (void) {
     // water
 #endif
 
-    // make FDIV fast. This reduces timing precision after we've been running
-    // for a
-    // while, so we don't do it globally.  This also sets chop mode, and we do
-    // it
+    // make FDIV fast. This reduces timing precision after we've been running for a
+    // while, so we don't do it globally.  This also sets chop mode, and we do it
     // here so that setup stuff like the refresh area calculations match what's
     // done in screen.c
     Sys_LowFPPrecision ();
@@ -861,19 +877,13 @@ void R_RenderView_ (void) {
         Sys_Error ("R_RenderView: NULL worldmodel");
 
     if (!r_dspeeds.value) {
-        VID_UnlockBuffer ();
-        S_ExtraUpdate ();              // don't let sound get messed up if
-        // going slow
-        VID_LockBuffer ();
+        S_ExtraUpdate ();              // don't let sound get messed up if going slow
     }
 
     R_EdgeDrawing ();
 
     if (!r_dspeeds.value) {
-        VID_UnlockBuffer ();
-        S_ExtraUpdate ();              // don't let sound get messed up if
-        // going slow
-        VID_LockBuffer ();
+        S_ExtraUpdate ();              // don't let sound get messed up if going slow
     }
 
     if (r_dspeeds.value) {
