@@ -1019,8 +1019,7 @@ void Mod_LoadBrushModel (model_t * mod, void *buffer) {
 
         mod->numleafs = bm->visleafs;
 
-        if (i < mod->numsubmodels - 1) {        // duplicate the basic
-            // information
+        if (i < mod->numsubmodels - 1) {        // duplicate the basic information
             char          name[10];
 
             sprintf (name, "*%i", i + 1);
