@@ -306,7 +306,7 @@ void R_ReadPointFile_f (void) {
 
     COM_FOpenFile (name, &f);
     if (!f) {
-        Con_Printf ("couldn't open %s\n", name);
+        Con_Warnf ("Couldn't open %s\n", name);
         return;
     }
 
