@@ -25,6 +25,8 @@
 #  include "movie.h"
 #endif
 
+int           hudwidth, hudheight;
+
 // only the refresh window will be updated unless these variables are flagged
 int           scr_copytop;
 int           scr_copyeverything;
@@ -32,11 +34,13 @@ int           scr_copyeverything;
 float         scr_con_current;
 float         scr_conlines;            // lines of console to display
 
-float         oldscreensize, oldfov;
-float         oldsbar;
+float         oldscreensize, oldfov, oldsbar;
+
+double        oldzoomstate;
+
 cvar_t        scr_viewsize = { "viewsize", "120", CVAR_ARCHIVE };
 cvar_t        scr_fov = { "fov", "90", CVAR_ARCHIVE };  // 10 - 170
-cvar_t        scr_consize = { "scr_consize", "0.5", CVAR_ARCHIVE };
+cvar_t        scr_consize = { "scr_consize", "0.2", CVAR_ARCHIVE };
 cvar_t        scr_conspeed = { "scr_conspeed", "1000" };
 cvar_t        scr_conswitch = { "scr_conswitch", "0", CVAR_ARCHIVE };
 cvar_t        scr_centertime = { "scr_centertime", "2" };
@@ -184,24 +188,6 @@ void SCR_CheckDrawCenterString (void) {
 
 // 
 
-/*
- * CalcFov
- */
-float CalcFov (float fov_x, float width, float height) {
-    float         a, x;
-
-    if (fov_x < 1 || fov_x > 179)
-        Sys_Error ("Bad fov: %f", fov_x);
-
-    x = width / tan (fov_x / 360 * M_PI);
-
-    a = atan (height / x);
-
-    a = a * 360 / M_PI;
-
-    return a;
-}
-
 /*
  * SCR_CalcRefdef
  *
@@ -231,8 +217,7 @@ static void SCR_CalcRefdef (void) {
     if (scr_fov.value > 170)
         Cvar_SetValue (&scr_fov, 170);
 
-    r_refdef.fov_x = scr_fov.value;
-    r_refdef.fov_y = CalcFov (r_refdef.fov_x, r_refdef.vrect.width, r_refdef.vrect.height);
+    V_CalcFov (); // lxndr: new method
 
     // intermission is always full screen
     if (cl.intermission)
@@ -316,6 +301,9 @@ void SCR_Init (void) {
     Movie_Init ();
 #endif
 
+    hudwidth = vid.width;
+    hudheight = vid.height;
+
     scr_initialized = true;
 }
 
@@ -403,6 +391,9 @@ void SCR_DrawLoading (void) {
 void SCR_SetUpToDrawConsole (void) {
     float         conspeed;
 
+    conwidth = vid.width;
+    conheight = vid.height;
+
     Con_CheckResize ();
 
     if (scr_drawloading)
@@ -412,23 +403,23 @@ void SCR_SetUpToDrawConsole (void) {
     con_forcedup = !cl.worldmodel || cls.signon != SIGNONS;
 
     if (con_forcedup) {
-        scr_conlines = vid.height;     // full screen
+        scr_conlines = conheight;      // full screen
         scr_con_current = scr_conlines;
     } else if (key_dest == key_console) {
-        if (scr_conswitch.value && vid.width > 640)
-            scr_conlines = vid.height;
+        if (scr_conswitch.value && conwidth > 480)
+            scr_conlines = conheight;
         else
-            scr_conlines = vid.height * scr_consize.value;
-        if (scr_conlines < 30)
-            scr_conlines = 30;
-        if (scr_conlines > vid.height)
-            scr_conlines = vid.height;
+            scr_conlines = conheight * scr_consize.value;
+        if (scr_conlines < 10)         // lxndr: was 30
+            scr_conlines = 10;         // lxndr: was 30
+        if (scr_conlines > conheight)
+            scr_conlines = conheight;
     } else {
         scr_conlines = 0;              // none visible
     }
 
     conspeed = scr_conspeed.value;
-    if (scr_conswitch.value && vid.width > 640)
+    if (scr_conswitch.value && conwidth > 480)
         conspeed *= 2;
 
     if (scr_conlines < scr_con_current) {
@@ -444,11 +435,11 @@ void SCR_SetUpToDrawConsole (void) {
 
     if (clearconsole++ < vid.numpages) {
         scr_copytop = 1;
-        Draw_TileClear (0, (int) scr_con_current, vid.width, vid.height - (int) scr_con_current);
+        Draw_TileClear (0, (int) scr_con_current, conwidth, conheight - (int) scr_con_current);
         Sbar_Changed ();
     } else if (clearnotify++ < vid.numpages) {
         scr_copytop = 1;
-        Draw_TileClear (0, 0, vid.width, con_notifylines);
+        Draw_TileClear (0, 0, conwidth, con_notifylines);
     } else {
         con_notifylines = 0;
     }
@@ -479,8 +470,7 @@ int SCR_ScreenShot (char *name) {
     qboolean      ok = false;
     char         *ext;
 
-    D_EnableBackBufferAccess ();       // enable direct drawing of console to
-    // back buffer
+    D_EnableBackBufferAccess ();       // enable direct drawing of console to back buffer
 
     ext = COM_FileExtension (name);
 
@@ -490,8 +480,7 @@ int SCR_ScreenShot (char *name) {
     else
         ok = Image_WritePCX (name, vid.buffer, vid.width, vid.height, vid.rowbytes, current_pal);
 
-    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped
-    // in for linear writes all the time
+    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped in for linear writes all the time
 
     return ok;
 }
@@ -619,6 +608,7 @@ void SCR_UpdateScreen (void) {
     static float  oldscr_viewsize;
     static float  oldlcd_x;
     vrect_t       vrect;
+    extern double zoomtime;
 
     if (cls.state == ca_dedicated)
         return;                        // stdout only
@@ -656,19 +646,20 @@ void SCR_UpdateScreen (void) {
         oldfov = scr_fov.value;
         vid.recalc_refdef = true;
     }
-
     if (oldlcd_x != lcd_x.value) {
         oldlcd_x = lcd_x.value;
         vid.recalc_refdef = true;
     }
-
     if (oldscreensize != scr_viewsize.value) {
         oldscreensize = scr_viewsize.value;
         vid.recalc_refdef = true;
     }
-
-    if (oldsbar != cl_sbar.value) {
-        oldsbar = cl_sbar.value;
+    if ((in_zoom.state & 1) != oldzoomstate || (zoomtime > 0 && zoomtime < 5)) {
+        oldzoomstate = (in_zoom.state & 1);
+        vid.recalc_refdef = true;
+    }
+    if (oldsbar != scr_sbar.value) {
+        oldsbar = scr_sbar.value;
         vid.recalc_refdef = true;
     }
 
@@ -677,8 +668,10 @@ void SCR_UpdateScreen (void) {
         SCR_CalcRefdef ();
     }
     // do 3D refresh drawing, and then update the screen
-    D_EnableBackBufferAccess ();       // of all overlay stuff if drawing
-    // directly
+    D_EnableBackBufferAccess ();       // of all overlay stuff if drawing directly
+
+    // lxndr: FIXME: clear screen everytime
+    Draw_TileClear (0, 0, vid.width, vid.height);
 
     if (scr_fullupdate++ < vid.numpages) {      // clear the entire screen
         scr_copyeverything = 1;
@@ -689,15 +682,11 @@ void SCR_UpdateScreen (void) {
     SCR_SetUpToDrawConsole ();
     SCR_EraseCenterString ();
 
-    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped
-    // in for linear writes all the time
+    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped in for linear writes all the time
 
-    VID_LockBuffer ();
     V_RenderView ();
-    VID_UnlockBuffer ();
 
-    D_EnableBackBufferAccess ();       // of all overlay stuff if drawing
-    // directly
+    D_EnableBackBufferAccess ();       // of all overlay stuff if drawing directly
 
     if (scr_drawdialog) {
         Sbar_Draw ();
@@ -731,8 +720,7 @@ void SCR_UpdateScreen (void) {
         M_Draw ();
     }
 
-    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped
-    // in for linear writes all the time
+    D_DisableBackBufferAccess ();      // for adapters that can't stay mapped in for linear writes all the time
 
     V_UpdatePalette ();
 
