@@ -67,8 +67,9 @@ void          Sbar_MiniDeathmatchOverlay (void);
 void          Sbar_IntermissionNumber (int x, int y, int num, int digits, int color);
 void          Sbar_DeathmatchOverlay (void);
 
+cvar_t        scr_sbar = { "scr_sbar", "1", CVAR_ARCHIVE };
+cvar_t        scr_sbarpos = { "scr_sbarpos", "1", CVAR_ARCHIVE };
 int           sb_ofsx;
-cvar_t        scr_sbarpos = { "scr_sbarpos", "2", CVAR_ARCHIVE };
 
 /*
  * Sbar_ShowScores
@@ -236,6 +237,7 @@ void Sbar_Init (void) {
     sb_face_invis_invuln = Draw_PicFromWad ("face_inv2");
     sb_face_quad = Draw_PicFromWad ("face_quad");
 
+    Cvar_Register (&scr_sbar);
     Cvar_Register (&scr_sbarpos);
 
     Cmd_AddCommand ("+showscores", Sbar_ShowScores);
@@ -261,7 +263,12 @@ void Sbar_Init (void) {
  * Sbar_DrawPic
  */
 void Sbar_DrawPic (int x, int y, mpic_t * pic) {
-    Draw_Pic (x + sb_ofsx, y + (vid.height - SBAR_HEIGHT), pic);
+#ifdef GLQUAKE
+    Draw_Pic (x + sb_ofsx, y + (hudheight - SBAR_HEIGHT), pic);
+    //    Draw_AlphaPic (x + sb_ofsx, y + (hudheight - SBAR_HEIGHT), pic, scr_sbaralpha.value); // lxndr: FIXME: wierd bug when playing with alpha value
+#else
+    Draw_Pic (x + sb_ofsx, y + (hudheight - SBAR_HEIGHT), pic);
+#endif
 }
 
 /*
@@ -269,14 +276,14 @@ void Sbar_DrawPic (int x, int y, mpic_t * pic) {
  * picture in the status bar.
  */
 void Sbar_DrawSubPic (int x, int y, mpic_t * pic, int srcx, int srcy, int width, int height) {
-    Draw_SubPic (x, y + (vid.height - SBAR_HEIGHT), pic, srcx, srcy, width, height);
+    Draw_SubPic (x, y + (hudheight - SBAR_HEIGHT), pic, srcx, srcy, width, height);
 }
 
 /*
  * Sbar_DrawTransPic
  */
 void Sbar_DrawTransPic (int x, int y, mpic_t * pic) {
-    Draw_TransPic (x + sb_ofsx, y + (vid.height - SBAR_HEIGHT), pic);
+    Draw_TransPic (x + sb_ofsx, y + (hudheight - SBAR_HEIGHT), pic);
 }
 
 /*
@@ -285,14 +292,14 @@ void Sbar_DrawTransPic (int x, int y, mpic_t * pic) {
  * Draws one solid graphics character
  */
 void Sbar_DrawCharacter (int x, int y, int num) {
-    Draw_Character (x + 4 + sb_ofsx, y + vid.height - SBAR_HEIGHT, num);
+    Draw_Character (x + 4 + sb_ofsx, y + hudheight - SBAR_HEIGHT, num);
 }
 
 /*
  * Sbar_DrawString
  */
 void Sbar_DrawString (int x, int y, char *str) {
-    Draw_String (x + sb_ofsx, y + (vid.height - SBAR_HEIGHT), str);
+    Draw_String (x + sb_ofsx, y + (hudheight - SBAR_HEIGHT), str);
 }
 
 /*
@@ -455,7 +462,7 @@ void Sbar_DrawInventory (void) {
     float         time;
     qboolean      headsup;
 
-    headsup = !(cl_sbar.value || scr_viewsize.value < 100);
+    headsup = !(scr_sbar.value || scr_viewsize.value < 100);
 
     if (!headsup) {
         if (rogue) {
@@ -481,8 +488,8 @@ void Sbar_DrawInventory (void) {
                 flashon = (flashon % 5) + 2;
 
             if (headsup) {
-                if (i || vid.height > 200)
-                    Sbar_DrawSubPic ((vid.width - 24), ystart - (7 - i) * 16, sb_weapons[flashon][i], 0, 0, 24, 16);
+                if (i || hudheight > 200)
+                    Sbar_DrawSubPic ((hudwidth - 24), ystart - (7 - i) * 16, sb_weapons[flashon][i], 0, 0, 24, 16);
             } else {
                 Sbar_DrawPic (i * 24, -16, sb_weapons[flashon][i]);
             }
@@ -513,8 +520,8 @@ void Sbar_DrawInventory (void) {
                     if ((cl.items & HIT_PROXIMITY_GUN) && flashon) {
                         grenadeflashing = 1;
                         if (headsup) {
-                            if (i || vid.height > 200)
-                                Sbar_DrawSubPic ((vid.width - 24), ystart - 48, hsb_weapons[flashon][2], 0, 0, 24, 16);
+                            if (i || hudheight > 200)
+                                Sbar_DrawSubPic ((hudwidth - 24), ystart - 48, hsb_weapons[flashon][2], 0, 0, 24, 16);
                         } else {
                             Sbar_DrawPic (96, -16, hsb_weapons[flashon][2]);
                         }
@@ -524,17 +531,16 @@ void Sbar_DrawInventory (void) {
                         if (!grenadeflashing) {
                             if (flashon) {
                                 if (headsup) {
-                                    if (i || vid.height > 200)
-                                        Sbar_DrawSubPic ((vid.width - 24), ystart - 48, hsb_weapons[flashon][3], 0, 0,
+                                    if (i || hudheight > 200)
+                                        Sbar_DrawSubPic ((hudwidth - 24), ystart - 48, hsb_weapons[flashon][3], 0, 0,
                                                          24, 16);
                                 } else {
                                     Sbar_DrawPic (96, -16, hsb_weapons[flashon][3]);
                                 }
                             } else {
                                 if (headsup) {
-                                    if (i || vid.height > 200)
-                                        Sbar_DrawSubPic ((vid.width - 24), ystart - 48, hsb_weapons[0][3], 0, 0, 24,
-                                                         16);
+                                    if (i || hudheight > 200)
+                                        Sbar_DrawSubPic ((hudwidth - 24), ystart - 48, hsb_weapons[0][3], 0, 0, 24, 16);
                                 } else {
                                     Sbar_DrawPic (96, -16, hsb_weapons[0][3]);
                                 }
@@ -542,16 +548,16 @@ void Sbar_DrawInventory (void) {
                         }
                     } else {
                         if (headsup) {
-                            if (i || vid.height > 200)
-                                Sbar_DrawSubPic ((vid.width - 24), ystart - 48, hsb_weapons[flashon][4], 0, 0, 24, 16);
+                            if (i || hudheight > 200)
+                                Sbar_DrawSubPic ((hudwidth - 24), ystart - 48, hsb_weapons[flashon][4], 0, 0, 24, 16);
                         } else {
                             Sbar_DrawPic (96, -16, hsb_weapons[flashon][4]);
                         }
                     }
                 } else {
                     if (headsup) {
-                        if (i || vid.height > 200)
-                            Sbar_DrawSubPic ((vid.width - 24), ystart + i * 16, hsb_weapons[flashon][i], 0, 0, 24, 16);
+                        if (i || hudheight > 200)
+                            Sbar_DrawSubPic ((hudwidth - 24), ystart + i * 16, hsb_weapons[flashon][i], 0, 0, 24, 16);
                     } else {
                         Sbar_DrawPic (176 + (i * 24), -16, hsb_weapons[flashon][i]);
                     }
@@ -570,24 +576,24 @@ void Sbar_DrawInventory (void) {
             }
         }
     }
-    // ammo counts
+    // ammo counts // lxndr: added +1 to y for better alignment
     for (i = 0; i < 4; i++) {
         Q_snprintfz (num, sizeof (num), "%3i", cl.stats[STAT_SHELLS + i]);
         if (headsup) {
-            Sbar_DrawSubPic ((vid.width - 42), -24 - (4 - i) * 11, sb_ibar, 3 + (i * 48), 0, 42, 11);
+            Sbar_DrawSubPic ((hudwidth - 42), -24 - (4 - i) * 11, sb_ibar, 3 + (i * 48), 0, 42, 11);
             if (num[0] != ' ')
-                Draw_Character ((vid.width - 35), vid.height - SBAR_HEIGHT - 24 - (4 - i) * 11, 18 + num[0] - '0');
+                Draw_Character ((hudwidth - 35), hudheight - SBAR_HEIGHT - 24 + 1 - (4 - i) * 11, 18 + num[0] - '0');
             if (num[1] != ' ')
-                Draw_Character ((vid.width - 27), vid.height - SBAR_HEIGHT - 24 - (4 - i) * 11, 18 + num[1] - '0');
+                Draw_Character ((hudwidth - 27), hudheight - SBAR_HEIGHT - 24 + 1 - (4 - i) * 11, 18 + num[1] - '0');
             if (num[2] != ' ')
-                Draw_Character ((vid.width - 19), vid.height - SBAR_HEIGHT - 24 - (4 - i) * 11, 18 + num[2] - '0');
+                Draw_Character ((hudwidth - 19), hudheight - SBAR_HEIGHT - 24 + 1 - (4 - i) * 11, 18 + num[2] - '0');
         } else {
             if (num[0] != ' ')
-                Sbar_DrawCharacter ((6 * i + 1) * 8 - 2, -24, 18 + num[0] - '0');
+                Sbar_DrawCharacter ((6 * i + 1) * 8 - 2, -24 + 1, 18 + num[0] - '0');
             if (num[1] != ' ')
-                Sbar_DrawCharacter ((6 * i + 2) * 8 - 2, -24, 18 + num[1] - '0');
+                Sbar_DrawCharacter ((6 * i + 2) * 8 - 2, -24 + 1, 18 + num[1] - '0');
             if (num[2] != ' ')
-                Sbar_DrawCharacter ((6 * i + 3) * 8 - 2, -24, 18 + num[2] - '0');
+                Sbar_DrawCharacter ((6 * i + 3) * 8 - 2, -24 + 1, 18 + num[2] - '0');
         }
     }
 
@@ -672,7 +678,7 @@ void Sbar_DrawFrags (void) {
     l = (scoreboardlines <= 4) ? scoreboardlines : 4;
 
     x = 23;
-    y = vid.height - SBAR_HEIGHT - 23;
+    y = hudheight - SBAR_HEIGHT - 23;
 
     for (i = 0; i < l; i++) {
         k = fragsort[i];
@@ -727,11 +733,11 @@ void Sbar_DrawFace (void) {
         top = Sbar_ColorForMap (top);
         bottom = Sbar_ColorForMap (bottom);
 
-        xofs = (cl.gametype == GAME_DEATHMATCH) ? 113 : ((vid.width - 320) >> 1) + 113;
+        xofs = (cl.gametype == GAME_DEATHMATCH) ? 113 : ((hudwidth - 320) >> 1) + 113;
 
         Sbar_DrawPic (112, 0, rsb_teambord);
-        Draw_Fill (xofs, vid.height - SBAR_HEIGHT + 3, 22, 9, top);
-        Draw_Fill (xofs, vid.height - SBAR_HEIGHT + 12, 22, 9, bottom);
+        Draw_Fill (xofs, hudheight - SBAR_HEIGHT + 3, 22, 9, top);
+        Draw_Fill (xofs, hudheight - SBAR_HEIGHT + 12, 22, 9, bottom);
 
         // draw number
         f = s->frags;
@@ -788,8 +794,7 @@ void Sbar_DrawFace (void) {
  * Sbar_DrawNormal
  */
 void Sbar_DrawNormal (void) {
-    if (cl_sbar.value || scr_viewsize.value < 100)
-        Sbar_DrawPic (0, 0, sb_sbar);
+    Sbar_DrawPic (0, 0, sb_sbar); // lxndr: removed condition
 
     // keys (hipnotic only)
     // MED 01/04/97 moved keys here so they would not be overwritten
@@ -864,12 +869,17 @@ void Sbar_DrawNormal (void) {
  */
 void Sbar_Draw (void) {
     qboolean      headsup;
+    extern int scr_drawloading;
 
-    headsup = !(cl_sbar.value || scr_viewsize.value < 100);
-    if (sb_updates >= vid.numpages && !headsup)
-        return;
+    headsup = !(scr_sbar.value || scr_viewsize.value < 100);
+    //    if (sb_updates >= vid.numpages && !headsup)
+    //        return;
 
-    if (scr_con_current == vid.height)
+    if (con_forcedup || scr_drawloading || cl.intermission || (scr_con_current == conheight && scr_viewsize.value >= 100
+#ifdef GLQUAKE
+                         && !(scr_hudsize.value == 1.5 && scr_sbar.value)
+#endif
+        ))
         return;                        // console is full screen
 
     scr_copyeverything = 1;
@@ -881,23 +891,23 @@ void Sbar_Draw (void) {
             sb_ofsx = 0;
             break;
         case 1:
-            sb_ofsx = (vid.width - 320) >> 1;
+            sb_ofsx = (hudwidth - 320) >> 1;
             break;
         case 2:
-            sb_ofsx = vid.width - 320;
+            sb_ofsx = hudwidth - 320;
             break;
     }
-    //sb_ofsx = scr_centersbar.value ? (vid.width - 320) >> 1 : 0;
+    //sb_ofsx = scr_centersbar.value ? (hudwidth - 320) >> 1 : 0;
 
     // top line
     if (sb_lines > 24) {
         Sbar_DrawInventory ();
-        if (!headsup || vid.width < 512)
+        if ( /*!headsup || */ hudwidth < 512)
             Sbar_DrawFrags ();
     }
     // main area
     if (sb_lines > 0) {
-        if (sb_showscores || cl.stats[STAT_HEALTH] <= 0) {
+        if (sb_showscores || cls.signon != SIGNONS) {
             Sbar_DrawPic (0, 0, sb_scorebar);
             Sbar_DrawScoreboard ();
         } else {
@@ -907,15 +917,6 @@ void Sbar_Draw (void) {
 #ifdef GLQUAKE
     if (sb_showscores || cl.stats[STAT_HEALTH] <= 0)
         sb_updates = 0;
-
-    // clear unused areas in GL
-    if (vid.width > 320 && !headsup) { // left
-        if (scr_sbarpos.value)
-            Draw_TileClear (0, vid.height - sb_lines, sb_ofsx, sb_lines);
-
-        // right
-        Draw_TileClear (320 + sb_ofsx, vid.height - sb_lines, vid.width - (320 + sb_ofsx), sb_lines);
-    }
 #endif
 
     if (sb_lines > 0 && cl.gametype == GAME_DEATHMATCH && !scr_sbarpos.value)
@@ -971,10 +972,10 @@ void Sbar_DeathmatchOverlay (void) {
     scr_copyeverything = 1;
     scr_fullupdate = 0;
 
-    xofs = (vid.width - 320) >> 1;
+    xofs = (hudwidth - 320) >> 1;
 
     pic = Draw_CachePic ("gfx/ranking.lmp");
-    Draw_Pic (xofs + 160 - pic->width / 2, 0, pic);
+    Draw_TransPic (xofs + 160 - pic->width / 2, 0, pic);
 
     // scores
     Sbar_SortFrags ();
@@ -982,7 +983,7 @@ void Sbar_DeathmatchOverlay (void) {
     // draw the stats
     l = scoreboardlines;
 
-    x = 80 + ((vid.width - 320) >> 1);
+    x = 80 + ((hudwidth - 320) >> 1);
     y = 40;
     Draw_String (x, 24, "ping frags name");
     for (i = 0; i < l; i++) {
@@ -1029,7 +1030,7 @@ void Sbar_MiniDeathmatchOverlay (void) {
     char          num[12];
     scoreboard_t *s;
 
-    if (vid.width < 512 || !sb_lines)
+    if (hudwidth < 512 || !sb_lines)
         return;
 
     scr_copyeverything = 1;
@@ -1040,7 +1041,7 @@ void Sbar_MiniDeathmatchOverlay (void) {
 
     // draw the text
     l = scoreboardlines;
-    y = vid.height - sb_lines;
+    y = hudheight - sb_lines;
     numlines = sb_lines / 8;
     if (numlines < 3)
         return;
@@ -1054,7 +1055,7 @@ void Sbar_MiniDeathmatchOverlay (void) {
     i = bound (0, i, scoreboardlines - numlines);
 
     x = 324;
-    for (; i < scoreboardlines && y < vid.height - 8; i++) {
+    for (; i < scoreboardlines && y < hudheight - 8; i++) {
         k = fragsort[i];
         s = &cl.scores[k];
         if (!s->name[0])
@@ -1103,10 +1104,10 @@ void Sbar_IntermissionOverlay (void) {
         return;
     }
 
-    xofs = (vid.width - 320) >> 1;
+    xofs = (hudwidth - 320) >> 1;
 
     pic = Draw_CachePic ("gfx/complete.lmp");
-    Draw_Pic (xofs + 64, 24, pic);
+    Draw_TransPic (xofs + 64, 24, pic);
 
     pic = Draw_CachePic ("gfx/inter.lmp");
     Draw_TransPic (xofs, 56, pic);
@@ -1139,5 +1140,5 @@ void Sbar_FinaleOverlay (void) {
     scr_copyeverything = 1;
 
     pic = Draw_CachePic ("gfx/finale.lmp");
-    Draw_TransPic ((vid.width - pic->width) / 2, 16, pic);
+    Draw_TransPic ((hudwidth - pic->width) / 2, 16, pic);
 }
