@@ -69,7 +69,7 @@ int           desired_bits = 16;
 int           sound_started = 0;
 
 cvar_t        bgmvolume = { "bgmvolume", "1", CVAR_ARCHIVE };
-cvar_t        s_volume = { "s_volume", "0.7", CVAR_ARCHIVE };
+cvar_t        s_volume = { "s_volume", "0.5", CVAR_ARCHIVE };
 cvar_t        s_nosound = { "s_nosound", "0" };
 cvar_t        s_precache = { "s_precache", "1" };
 cvar_t        s_loadas8bit = { "s_loadas8bit", "0" };
@@ -161,14 +161,15 @@ void S_Init (void) {
     Cmd_AddLegacyCommand ("volume", "s_volume");
     Cmd_AddLegacyCommand ("nosound", "s_nosound");
     Cmd_AddLegacyCommand ("precache", "s_precache");
-    Cmd_AddLegacyCommand ("loadas8bit", "s_loadas8bit");
-#ifdef __LEGACY__
-    Cmd_AddLegacyCommand ("ambient_level", "s_ambientlevel");
-    Cmd_AddLegacyCommand ("ambient_fade", "s_ambientfade");
-#endif
-    Cmd_AddLegacyCommand ("snd_noextraupdate", "s_noextraupdate");
-    Cmd_AddLegacyCommand ("snd_show", "s_show");
-    Cmd_AddLegacyCommand ("_snd_mixahead", "s_mixahead");
+    if (legacy) {
+        Cmd_AddLegacyCommand ("loadas8bit", "s_loadas8bit");
+        Cmd_AddLegacyCommand ("ambient_level", "s_ambientlevel");
+        Cmd_AddLegacyCommand ("ambient_fade", "s_ambientfade");
+        Cmd_AddLegacyCommand ("snd_noextraupdate", "s_noextraupdate");
+        Cmd_AddLegacyCommand ("snd_show", "s_show");
+        Cmd_AddLegacyCommand ("_snd_mixahead", "s_mixahead");
+        Cmd_AddLegacyCommand ("play2", "play");
+    }
 
     if (COM_CheckParm ("-nosound"))
         return;
@@ -184,8 +185,6 @@ void S_Init (void) {
     Cmd_AddCommand ("volumedown", S_VolumeDown_f);
     Cmd_AddCommand ("volumeup", S_VolumeUp_f);
 
-    Cmd_AddLegacyCommand ("play2", "play");
-
     if (host_parms.memsize < 0x800000) {
         Cvar_SetValue (&s_loadas8bit, 1);
         Con_Printf ("loading all sounds as 8bit\n");
