@@ -24,8 +24,7 @@
 server_t      sv;
 server_static_t svs;
 
-char          localmodels[MAX_MODELS][5];       // inline model names for
-                                                // precache
+char          localmodels[MAX_MODELS][5];       // inline model names for precache
 
 // 
 
@@ -35,17 +34,17 @@ char          localmodels[MAX_MODELS][5];       // inline model names for
 void SV_Init (void) {
     int           i;
 
-    Cvar_Register (&sv_maxvelocity);
-    Cvar_Register (&sv_gravity);
-    Cvar_Register (&sv_nostep);
+    Cvar_Register (&sv_accelerate);
+    Cvar_Register (&sv_aim);
     Cvar_Register (&sv_friction);
     Cvar_Register (&sv_edgefriction);
-    Cvar_Register (&sv_stopspeed);
-    Cvar_Register (&sv_maxspeed);
-    Cvar_Register (&sv_accelerate);
-    Cvar_Register (&sv_idealpitchscale);
-    Cvar_Register (&sv_aim);
+    Cvar_Register (&sv_gravity);
     Cvar_Register (&sv_healthimpact);
+    Cvar_Register (&sv_idealpitchscale);
+    Cvar_Register (&sv_maxspeed);
+    Cvar_Register (&sv_maxvelocity);
+    Cvar_Register (&sv_nostep);
+    Cvar_Register (&sv_stopspeed);
 
     for (i = 0; i < MAX_MODELS; i++)
         sprintf (localmodels[i], "*%i", i);
@@ -367,7 +366,7 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
     vec3_t        org;
     edict_t      *ent;
 #ifdef GLQUAKE
-    float         alpha, fullbright;
+    float         alpha = 0, fullbright = 0;
     eval_t       *val;
 #endif
 
@@ -379,8 +378,7 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
     ent = NEXT_EDICT (sv.edicts);
     for (e = 1; e < sv.num_edicts; e++, ent = NEXT_EDICT (ent)) {
         // ignore if not touching a PV leaf
-        if (ent != clent)              // clent is ALWAYS sent
-        {
+        if (ent != clent) {            // clent is ALWAYS sent
             // ignore ents without visible models
             if (!ent->v.modelindex || !pr_strings[ent->v.model])
                 continue;
@@ -392,14 +390,13 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
             if (i == ent->num_leafs)
                 continue;              // not visible
 
-            // joe, from ProQuake: don't send updates if the client doesn't
-            // have the map
+            // joe, from ProQuake: don't send updates if the client doesn't have the map
             if (nomap)
                 continue;
         }
 
-        if (msg->maxsize - msg->cursize < 16) {
-            Con_Printf ("packet overflow\n");
+        if (msg->maxsize - msg->cursize < 18) { // lxndr: was 16
+            Con_Printf ("packet overflow (max:%d cur:%d)\n", msg->maxsize, msg->cursize);
             return;
         }
         // send an update
@@ -438,20 +435,25 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
         if (ent->baseline.modelindex != ent->v.modelindex)
             bits |= U_MODEL;
 
+        // lxndr: from fitzquake
+        if (bits & U_FRAME && (int) ent->v.frame & 0xFF00)
+            bits |= U_FRAME2;
+        if (bits & U_MODEL && (int) ent->v.modelindex & 0xFF00)
+            bits |= U_MODEL2;
+
 #ifdef GLQUAKE
-        // nehahra: model alpha
+        if (nehahra) { // nehahra: model alpha
         if ((val = GETEDICTFIELDVALUE (ent, eval_alpha)))
             alpha = val->_float;
         else
             alpha = 1;
-
         if ((val = GETEDICTFIELDVALUE (ent, eval_fullbright)))
             fullbright = val->_float;
         else
             fullbright = 0;
-
         if ((alpha < 1 && alpha > 0) || fullbright)
             bits |= U_TRANS;
+        }
 #endif
 
         if (e >= 256)
@@ -460,11 +462,20 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
         if (bits >= 256)
             bits |= U_MOREBITS;
 
+        // lxndr: from fitzquake
+        if (bits >= 65536)
+            bits |= U_EXTEND1;
+
         // write the message
         MSG_WriteByte (msg, bits | U_SIGNAL);
 
         if (bits & U_MOREBITS)
             MSG_WriteByte (msg, bits >> 8);
+
+        // lxndr: from fitzquake
+        if (bits & U_EXTEND1)
+            MSG_WriteByte (msg, bits >> 16);
+
         if (bits & U_LONGENTITY)
             MSG_WriteShort (msg, e);
         else
@@ -491,8 +502,15 @@ void SV_WriteEntitiesToClient (edict_t * clent, sizebuf_t * msg, qboolean nomap)
             MSG_WriteCoord (msg, ent->v.origin[2]);
         if (bits & U_ANGLE3)
             MSG_WriteAngle (msg, ent->v.angles[2]);
+
+        // lxndr: from fitzquake
+        if (bits & U_FRAME2)
+            MSG_WriteByte (msg, (int) ent->v.frame >> 8);
+        if (bits & U_MODEL2)
+            MSG_WriteByte (msg, (int) ent->v.modelindex >> 8);
+
 #ifdef GLQUAKE
-        if (bits & U_TRANS) {
+        if (nehahra && (bits & U_TRANS)) {
             MSG_WriteFloat (msg, 2);
             MSG_WriteFloat (msg, alpha);
             MSG_WriteFloat (msg, fullbright);
@@ -548,22 +566,18 @@ void SV_WriteClientdataToMessage (edict_t * ent, sizebuf_t * msg) {
 
     if (ent->v.view_ofs[2] != DEFAULT_VIEWHEIGHT)
         bits |= SU_VIEWHEIGHT;
-
     if (ent->v.idealpitch)
         bits |= SU_IDEALPITCH;
 
-    // stuff the sigil bits into the high bits of items for sbar, or else mix
-    // in items2
+    // stuff the sigil bits into the high bits of items for sbar, or else mix in items2
     if ((val = GETEDICTFIELDVALUE (ent, eval_items2)))
         items = (int) ent->v.items | ((int) val->_float << 23);
     else
         items = (int) ent->v.items | ((int) pr_global_struct->serverflags << 28);
-
     bits |= SU_ITEMS;
 
     if ((int) ent->v.flags & FL_ONGROUND)
         bits |= SU_ONGROUND;
-
     if (ent->v.waterlevel >= 2)
         bits |= SU_INWATER;
 
@@ -576,17 +590,44 @@ void SV_WriteClientdataToMessage (edict_t * ent, sizebuf_t * msg) {
 
     if (ent->v.weaponframe)
         bits |= SU_WEAPONFRAME;
-
     if (ent->v.armorvalue)
         bits |= SU_ARMOR;
 
     // if (ent->v.weapon)
     bits |= SU_WEAPON;
 
+    // lxndr: from fitzquake
+    if (bits & SU_WEAPON && SV_ModelIndex (pr_strings + ent->v.weaponmodel) & 0xFF00)
+        bits |= SU_WEAPON2;
+    if ((int) ent->v.armorvalue & 0xFF00)
+        bits |= SU_ARMOR2;
+    if ((int) ent->v.currentammo & 0xFF00)
+        bits |= SU_AMMO2;
+    if ((int) ent->v.ammo_shells & 0xFF00)
+        bits |= SU_SHELLS2;
+    if ((int) ent->v.ammo_nails & 0xFF00)
+        bits |= SU_NAILS2;
+    if ((int) ent->v.ammo_rockets & 0xFF00)
+        bits |= SU_ROCKETS2;
+    if ((int) ent->v.ammo_cells & 0xFF00)
+        bits |= SU_CELLS2;
+    if (bits & SU_WEAPONFRAME && (int) ent->v.weaponframe & 0xFF00)
+        bits |= SU_WEAPONFRAME2;
+    if (bits >= 65536)
+        bits |= SU_EXTEND1;
+    if (bits >= 16777216)
+        bits |= SU_EXTEND2;
+
     // send the data
     MSG_WriteByte (msg, svc_clientdata);
     MSG_WriteShort (msg, bits);
 
+    // lxndr: from fitzquake
+    if (bits & SU_EXTEND1)
+        MSG_WriteByte (msg, bits >> 16);
+    if (bits & SU_EXTEND2)
+        MSG_WriteByte (msg, bits >> 24);
+
     if (bits & SU_VIEWHEIGHT)
         MSG_WriteChar (msg, ent->v.view_ofs[2]);
 
@@ -617,7 +658,7 @@ void SV_WriteClientdataToMessage (edict_t * ent, sizebuf_t * msg) {
     MSG_WriteByte (msg, ent->v.ammo_rockets);
     MSG_WriteByte (msg, ent->v.ammo_cells);
 
-    if (hipnotic || rogue) {
+    if (hipnotic || rogue || quore) { // lxndr: added quore
         for (i = 0; i < 32; i++) {
             if (((int) ent->v.weapon) & (1 << i)) {
                 MSG_WriteByte (msg, i);
@@ -627,6 +668,24 @@ void SV_WriteClientdataToMessage (edict_t * ent, sizebuf_t * msg) {
     } else {
         MSG_WriteByte (msg, ent->v.weapon);
     }
+
+    // lxndr: from fitzquake
+    if (bits & SU_WEAPON2)
+        MSG_WriteByte (msg, SV_ModelIndex (pr_strings + ent->v.weaponmodel) >> 8);
+    if (bits & SU_ARMOR2)
+        MSG_WriteByte (msg, (int) ent->v.armorvalue >> 8);
+    if (bits & SU_AMMO2)
+        MSG_WriteByte (msg, (int) ent->v.currentammo >> 8);
+    if (bits & SU_SHELLS2)
+        MSG_WriteByte (msg, (int) ent->v.ammo_shells >> 8);
+    if (bits & SU_NAILS2)
+        MSG_WriteByte (msg, (int) ent->v.ammo_nails >> 8);
+    if (bits & SU_ROCKETS2)
+        MSG_WriteByte (msg, (int) ent->v.ammo_rockets >> 8);
+    if (bits & SU_CELLS2)
+        MSG_WriteByte (msg, (int) ent->v.ammo_cells >> 8);
+    if (bits & SU_WEAPONFRAME2)
+        MSG_WriteByte (msg, (int) ent->v.weaponframe >> 8);
 }
 
 /*
@@ -827,6 +886,7 @@ int SV_ModelIndex (char *name) {
 void SV_CreateBaseline (void) {
     int           i, entnum;
     edict_t      *svent;
+    int           bits;
 
     for (entnum = 0; entnum < sv.num_edicts; entnum++) {
         // get the current server version
@@ -849,12 +909,29 @@ void SV_CreateBaseline (void) {
             svent->baseline.modelindex = SV_ModelIndex (pr_strings + svent->v.model);
         }
 
-        // add to the message
-        MSG_WriteByte (&sv.signon, svc_spawnbaseline);
-        MSG_WriteShort (&sv.signon, entnum);
+        // lxndr: from fitzquake
+        bits = 0;
+        if (svent->baseline.modelindex & 0xFF00)
+            bits |= B_MODEL;
+        if (svent->baseline.frame & 0xFF00)
+            bits |= B_FRAME;
 
-        MSG_WriteByte (&sv.signon, svent->baseline.modelindex);
-        MSG_WriteByte (&sv.signon, svent->baseline.frame);
+        // add to the message
+        if (bits)
+            MSG_WriteByte (&sv.signon, svc_spawnbaseline2);
+        else
+            MSG_WriteByte (&sv.signon, svc_spawnbaseline);
+        MSG_WriteShort (&sv.signon, entnum);
+        if (bits)
+            MSG_WriteByte (&sv.signon, bits);
+        if (bits & B_MODEL)
+            MSG_WriteShort (&sv.signon, svent->baseline.modelindex);
+        else
+            MSG_WriteByte (&sv.signon, svent->baseline.modelindex);
+        if (bits & B_FRAME)
+            MSG_WriteShort (&sv.signon, svent->baseline.frame);
+        else
+            MSG_WriteByte (&sv.signon, svent->baseline.frame);
         MSG_WriteByte (&sv.signon, svent->baseline.colormap);
         MSG_WriteByte (&sv.signon, svent->baseline.skin);
         for (i = 0; i < 3; i++) {
@@ -921,11 +998,9 @@ void SV_SpawnServer (char *server) {
     extern void   R_PreMapLoad (char *);
 
 #ifdef GLQUAKE
-    if (nehahra) {
-        if (NehGameType == TYPE_DEMO) {
-            M_Menu_Main_f ();
-            return;
-        }
+    if (nehahra && (NehGameType == TYPE_DEMO)) {
+        M_Menu_Main_f ();
+        return;
     }
 #endif
 
