@@ -32,8 +32,6 @@
 #include "quakedef.h"
 
 #include <GL/glx.h>
-
-#include <X11/keysym.h>
 #include <X11/cursorfont.h>
 
 #ifdef HAVE_DGA
@@ -60,7 +58,7 @@ qboolean      vid_hwgamma_enabled = false;
 #define	WARP_WIDTH	320
 #define	WARP_HEIGHT	200
 
-static Display *dpy = NULL;
+//static Display *dpy = NULL;
 static Window win;
 static GLXContext ctx = NULL;
 
@@ -89,10 +87,6 @@ void D_BeginDirectRect (int x, int y, byte * pbitmap, int width, int height) {
 }
 void D_EndDirectRect (int x, int y, int width, int height) {
 }
-void VID_LockBuffer (void) {
-}
-void VID_UnlockBuffer (void) {
-}
 
 const char   *glx_extensions;
 qboolean CheckGLXExtension (Display * dpy, int scr, const char *extension) {
@@ -127,244 +121,13 @@ void CheckVSyncExtensions (Display * dpy, int scr) {
         glxGetVideoSync = qglGetProcAddress ("glXGetVideoSyncSGI");
         glxWaitVideoSync = qglGetProcAddress ("glXWaitVideoSyncSGI");
         if (glxGetVideoSync && glxWaitVideoSync) {
-            Con_Printf ("VSync extensions found\n");
+            Con_Printf ("  GLX_SGI_video_sync\n");
             gl_vsync_ext = true;
             Cvar_Register (&vid_vsync);
         }
     }
 }
 
-static int XLateKey (XKeyEvent * ev) {
-    int           key, kp;
-    char          buf[64];
-    KeySym        keysym;
-
-    key = 0;
-    kp = (int) cl_keypad.value;
-
-    XLookupString (ev, buf, sizeof buf, &keysym, 0);
-
-    switch (keysym) {
-        case XK_Scroll_Lock:
-            key = K_SCRLCK;
-            break;
-
-        case XK_Caps_Lock:
-            key = K_CAPSLOCK;
-            break;
-
-        case XK_Num_Lock:
-            key = kp ? KP_NUMLOCK : K_PAUSE;
-            break;
-
-        case XK_KP_Page_Up:
-            key = kp ? KP_PGUP : K_PGUP;
-            break;
-        case XK_Page_Up:
-            key = K_PGUP;
-            break;
-
-        case XK_KP_Page_Down:
-            key = kp ? KP_PGDN : K_PGDN;
-            break;
-        case XK_Page_Down:
-            key = K_PGDN;
-            break;
-
-        case XK_KP_Home:
-            key = kp ? KP_HOME : K_HOME;
-            break;
-        case XK_Home:
-            key = K_HOME;
-            break;
-
-        case XK_KP_End:
-            key = kp ? KP_END : K_END;
-            break;
-        case XK_End:
-            key = K_END;
-            break;
-
-        case XK_KP_Left:
-            key = kp ? KP_LEFTARROW : K_LEFTARROW;
-            break;
-        case XK_Left:
-            key = K_LEFTARROW;
-            break;
-
-        case XK_KP_Right:
-            key = kp ? KP_RIGHTARROW : K_RIGHTARROW;
-            break;
-        case XK_Right:
-            key = K_RIGHTARROW;
-            break;
-
-        case XK_KP_Down:
-            key = kp ? KP_DOWNARROW : K_DOWNARROW;
-            break;
-
-        case XK_Down:
-            key = K_DOWNARROW;
-            break;
-
-        case XK_KP_Up:
-            key = kp ? KP_UPARROW : K_UPARROW;
-            break;
-
-        case XK_Up:
-            key = K_UPARROW;
-            break;
-
-        case XK_Escape:
-            key = K_ESCAPE;
-            break;
-
-        case XK_KP_Enter:
-            key = kp ? KP_ENTER : K_ENTER;
-            break;
-
-        case XK_Return:
-            key = K_ENTER;
-            break;
-
-        case XK_Tab:
-            key = K_TAB;
-            break;
-
-        case XK_F1:
-            key = K_F1;
-            break;
-
-        case XK_F2:
-            key = K_F2;
-            break;
-
-        case XK_F3:
-            key = K_F3;
-            break;
-
-        case XK_F4:
-            key = K_F4;
-            break;
-
-        case XK_F5:
-            key = K_F5;
-            break;
-
-        case XK_F6:
-            key = K_F6;
-            break;
-
-        case XK_F7:
-            key = K_F7;
-            break;
-
-        case XK_F8:
-            key = K_F8;
-            break;
-
-        case XK_F9:
-            key = K_F9;
-            break;
-
-        case XK_F10:
-            key = K_F10;
-            break;
-
-        case XK_F11:
-            key = K_F11;
-            break;
-
-        case XK_F12:
-            key = K_F12;
-            break;
-
-        case XK_BackSpace:
-            key = K_BACKSPACE;
-            break;
-
-        case XK_KP_Delete:
-            key = kp ? KP_DEL : K_DEL;
-            break;
-        case XK_Delete:
-            key = K_DEL;
-            break;
-
-        case XK_Pause:
-            key = K_PAUSE;
-            break;
-
-        case XK_Shift_L:
-            key = K_LSHIFT;
-            break;
-        case XK_Shift_R:
-            key = K_RSHIFT;
-            break;
-
-        case XK_Execute:
-        case XK_Control_L:
-            key = K_LCTRL;
-            break;
-        case XK_Control_R:
-            key = K_RCTRL;
-            break;
-
-        case XK_Alt_L:
-        case XK_Meta_L:
-            key = K_LALT;
-            break;
-        case XK_Alt_R:
-        case XK_Meta_R:
-            key = K_RALT;
-            break;
-
-        case XK_Super_L:
-            key = K_LWIN;
-            break;
-        case XK_Super_R:
-            key = K_RWIN;
-            break;
-        case XK_Menu:
-            key = K_MENU;
-            break;
-
-        case XK_KP_Begin:
-            key = kp ? KP_5 : '5';
-            break;
-
-        case XK_KP_Insert:
-            key = kp ? KP_INS : K_INS;
-            break;
-        case XK_Insert:
-            key = K_INS;
-            break;
-
-        case XK_KP_Multiply:
-            key = kp ? KP_STAR : '*';
-            break;
-
-        case XK_KP_Add:
-            key = kp ? KP_PLUS : '+';
-            break;
-
-        case XK_KP_Subtract:
-            key = kp ? KP_MINUS : '-';
-            break;
-
-        case XK_KP_Divide:
-            key = kp ? KP_SLASH : '/';
-            break;
-
-        default:
-            key = *(unsigned char *) buf;
-            if (key >= 'A' && key <= 'Z')
-                key = key - 'A' + 'a';
-            break;
-    }
-
-    return key;
-}
-
 static void install_grabs (void) {
     XGrabPointer (dpy, win, True, 0, GrabModeAsync, GrabModeAsync, win, None, CurrentTime);
 
@@ -381,12 +144,11 @@ static void install_grabs (void) {
             dgamouse = true;
         if (DGAflags & XF86DGADirectKeyb)
             dgakeyb = true;
-    } else
-#endif
-    {
-        XWarpPointer (dpy, None, win, 0, 0, 0, 0, vid.width / 2, vid.height / 2);
     }
+    if (!dgamouse)                     // lxndr: XWarpPointer only if dga mouse is disable
+#endif
 
+        XWarpPointer (dpy, None, win, 0, 0, 0, 0, vid.width / 2, vid.height / 2);
     XGrabKeyboard (dpy, win, False, GrabModeAsync, GrabModeAsync, CurrentTime);
 }
 
@@ -512,22 +274,34 @@ void InitHWGamma (void) {
     if (COM_CheckParm ("-nohwgamma"))
         return;
 
+#  ifdef __DEBUG__
+    Con_DPrintf ("InitHWGamma\n");
+#  endif
     XF86VidModeGetGammaRampSize (dpy, scrnum, &xf86vm_gammaramp_size);
 
     vid_gammaworks = (xf86vm_gammaramp_size == 256);
+
     if (vid_gammaworks)
         XF86VidModeGetGammaRamp (dpy, scrnum, xf86vm_gammaramp_size, systemgammaramp[0], systemgammaramp[1],
                                  systemgammaramp[2]);
 }
 
 void RestoreHWGamma (void) {
+#  ifdef __DEBUG__
+    Con_DPrintf ("RestoreHWGamma\n");
+#  endif
     if (vid_gammaworks && customgamma) {
         customgamma = false;
         XF86VidModeSetGammaRamp (dpy, scrnum, 256, systemgammaramp[0], systemgammaramp[1], systemgammaramp[2]);
     }
 }
 
+Colormap cmap;
+#ifndef __DEVEL__
 void VID_SetDeviceGammaRamp (unsigned short *ramps) {
+#  ifdef __DEBUG__
+    Con_DPrintf ("VID_SetDeviceGammaRamp\n");
+#  endif
     if (vid_gammaworks) {
         currentgammaramp = ramps;
         if (vid_hwgamma_enabled) {
@@ -537,6 +311,43 @@ void VID_SetDeviceGammaRamp (unsigned short *ramps) {
     }
 }
 #else
+void VisualInfo (void);
+XVisualInfo  *visinfo;
+void VID_SetDeviceGammaRamp (unsigned short *ramps) {
+    int i;
+    XColor colors[256];
+    XSetWindowAttributes attr;
+    static qboolean alloc = false;
+
+    if (visinfo->class != DirectColor)
+        Sys_Error ("no directcolor");
+
+    if (!alloc) {
+        cmap = XCreateColormap (dpy, win, visinfo->visual, AllocAll);
+        attr.colormap = cmap;
+        XChangeWindowAttributes( dpy, win, CWColormap, &attr );
+        alloc = true;
+    }
+
+    int f = 1;//65536;
+    for (i = 0; i < 256; i++) {
+        colors[i].pixel = i;
+        colors[i].flags = DoRed | DoGreen | DoBlue;
+        colors[i].red   = ramps[i] * f;
+        colors[i].green = ramps[i + 256] * f;
+        colors[i].blue  = ramps[i + 512] * f;
+    }
+
+    XLockDisplay (dpy);
+    XStoreColors (dpy, cmap, colors, 256);
+//    XInstallColormap (dpy, cmap);
+    XSync(dpy, false);
+    XFlush(dpy);
+    XUnlockDisplay (dpy);
+    XSetWindowColormap (dpy, win, cmap);
+}
+#endif
+#else
 void VID_SetDeviceGammaRamp (unsigned short *ramps) {
 }
 #endif
@@ -599,6 +410,11 @@ void VID_Shutdown (void) {
 #endif
 
     if (dpy) {
+#ifdef HAVE_MISC
+        VID_Manage3rdButton (dpy, false);
+#endif
+        VID_RestoreScreenSaver (dpy);
+
         glXDestroyContext (dpy, ctx);
         if (win)
             XDestroyWindow (dpy, win);
@@ -640,6 +456,9 @@ void VID_Init (unsigned char *palette) {
         GLX_BLUE_SIZE, 1,
         GLX_DOUBLEBUFFER,
         GLX_DEPTH_SIZE, 1,
+#ifdef __DEVEL__
+        GLX_X_VISUAL_TYPE, GLX_DIRECT_COLOR, // lxndr: for gamma correction in windowed mode
+#endif
 #ifdef __DEVEL__0
         GLX_SAMPLE_BUFFERS_ARB, 1, GLX_SAMPLES_ARB, 16, // lxndr:
 #endif
@@ -648,8 +467,10 @@ void VID_Init (unsigned char *palette) {
     int           i, width = 640, height = 480;
     XSetWindowAttributes attr;
     unsigned long mask;
-    Window        root;
+#ifndef __DEVEL__
     XVisualInfo  *visinfo;
+#endif
+    Window        root;
     int           MajorVersion, MinorVersion, actualWidth, actualHeight;
 
     Cvar_Register (&vid_mode);
@@ -674,34 +495,33 @@ void VID_Init (unsigned char *palette) {
 
     if (COM_CheckParm ("-fullscreen"))
         fullscreen = true;
-
-    // set vid parameters
-    if (COM_CheckParm ("-current")) {
-        width = DisplayWidth (dpy, scrnum);
-        height = DisplayHeight (dpy, scrnum);
-    } else {
+    if (COM_CheckParm ("-width") || COM_CheckParm ("-height")) {
         if ((i = COM_CheckParm ("-width")) && i + 1 < com_argc)
             width = Q_atoi (com_argv[i + 1]);
 
         if ((i = COM_CheckParm ("-height")) && i + 1 < com_argc)
             height = Q_atoi (com_argv[i + 1]);
+    } else {
+        if (!COM_CheckParm ("-current"))
+            fullscreen = true;
+        width = DisplayWidth (dpy, scrnum);
+        height = DisplayHeight (dpy, scrnum);
     }
 
+    vid.width = scr_width = width;
+    vid.height = scr_height = height;
+    //    vid.aspect = ((float) vid.height / (float) vid.width) * (320.0 / 240.0); // lxndr: not used in gl
+    vid.numpages = 2;
+
     if ((i = COM_CheckParm ("-conwidth")) && i + 1 < com_argc)
         vid.conwidth = Q_atoi (com_argv[i + 1]);
     else
         vid.conwidth = width;
     vid.conwidth &= 0xfff8;            // make it a multiple of eight
-    if (vid.conwidth < 320)
-        vid.conwidth = 320;
-
-    // pick a conheight that matches with correct aspect
-    vid.conheight = vid.conwidth * 3 / 4;
-
     if ((i = COM_CheckParm ("-conheight")) && i + 1 < com_argc)
         vid.conheight = Q_atoi (com_argv[i + 1]);
-    if (vid.conheight < 200)
-        vid.conheight = 200;
+    else
+        vid.conheight = vid.conwidth * height / width;
 
 #ifdef HAVE_VMODE
     // Get video mode list
@@ -784,25 +604,17 @@ void VID_Init (unsigned char *palette) {
     }
 #endif
 
+    VID_DisableScreenSaver (dpy);
+#ifdef HAVE_MISC
+    VID_Manage3rdButton (dpy, true);
+#endif
+
     XFlush (dpy);
 
     ctx = glXCreateContext (dpy, visinfo, NULL, True);
 
     glXMakeCurrent (dpy, win, ctx);
 
-    scr_width = width;
-    scr_height = height;
-
-    if (vid.conheight > height)
-        vid.conheight = height;
-    if (vid.conwidth > width)
-        vid.conwidth = width;
-    vid.width = vid.conwidth;
-    vid.height = vid.conheight;
-
-    vid.aspect = ((float) vid.height / (float) vid.width) * (320.0 / 240.0);
-    vid.numpages = 2;
-
     InitSig ();                        // trap evil signals
 
     GL_Init ();
@@ -887,3 +699,292 @@ void IN_MouseMove (usercmd_t * cmd) {
 void IN_Move (usercmd_t * cmd) {
     IN_MouseMove (cmd);
 }
+
+#ifdef __DEVEL__
+// lxndr: from bzflag
+void VisualInfo (void) {
+    int           n_fbc;
+    GLXFBConfig  *fbc;
+    int           value, ret, i;
+
+    fbc = glXGetFBConfigs (dpy, DefaultScreen (dpy), &n_fbc);
+
+    if (fbc) {
+        if (1) {
+            /* print table header */
+            Sys_Printf (" +-----+-------------------------+-----------------+----------+-------------+-------+------+\n");
+            Sys_Printf (" |     |        visual           |      color      | ax dp st |    accum    |   ms  |  cav |\n");
+            Sys_Printf (" |  id | tp xr cl fm db st lv xp |  sz  r  g  b  a | bf th cl | r  g  b  a  | ns  b |  eat |\n");
+            Sys_Printf (" +-----+-------------------------+-----------------+----------+-------------+-------+------+\n");
+            /* loop through all the fbcs */
+            for (i = 0; i < n_fbc; i++) {
+                /* print out the information for this fbc */
+                /* visual id */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_FBCONFIG_ID, &value);
+                if (ret != Success) {
+                    Sys_Printf ("|  ?  |");
+                } else {
+                    Sys_Printf (" |% 4d | ", value);
+                }
+                /* visual type */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_DRAWABLE_TYPE, &value);
+                if (ret != Success) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value & GLX_WINDOW_BIT) {
+                        if (value & GLX_PBUFFER_BIT) {
+                            Sys_Printf ("wp ");
+                        } else {
+                            Sys_Printf ("wn ");
+                        }
+                    } else {
+                        if (value & GLX_PBUFFER_BIT) {
+                            Sys_Printf ("pb ");
+                        } else if (value & GLX_PIXMAP_BIT) {
+                            Sys_Printf ("pm ");
+                        } else {
+                            Sys_Printf (" ? ");
+                        }
+                    }
+                }
+                /* x renderable */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_X_RENDERABLE, &value);
+                if (ret != Success) {
+                    Sys_Printf (" ? ");
+                } else {
+                    Sys_Printf (value ? " y " : " n ");
+                }
+                /* class */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_X_VISUAL_TYPE, &value);
+                if (ret != Success) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (GLX_TRUE_COLOR == value)
+                        Sys_Printf ("tc ");
+                    else if (GLX_DIRECT_COLOR == value)
+                        Sys_Printf ("dc ");
+                    else if (GLX_PSEUDO_COLOR == value)
+                        Sys_Printf ("pc ");
+                    else if (GLX_STATIC_COLOR == value)
+                        Sys_Printf ("sc ");
+                    else if (GLX_GRAY_SCALE == value)
+                        Sys_Printf ("gs ");
+                    else if (GLX_STATIC_GRAY == value)
+                        Sys_Printf ("sg ");
+                    else if (GLX_X_VISUAL_TYPE == value)
+                        Sys_Printf (" . ");
+                    else
+                        Sys_Printf (" ? ");
+                }
+                /* format */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_RENDER_TYPE, &value);
+                Sys_Printf (" ? ");
+/*                if (ret != Success) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (GLXEW_NV_float_buffer) {
+                        int           ret2, value2;
+                        ret2 = glXGetFBConfigAttrib (dpy, fbc[i], GLX_FLOAT_COMPONENTS_NV, &value2);
+                        if (Success == ret2 && GL_TRUE == value2) {
+                            Sys_Printf (" f ");
+                        } else if (value & GLX_RGBA_BIT)
+                            Sys_Printf (" i ");
+                        else if (value & GLX_COLOR_INDEX_BIT)
+                            Sys_Printf (" c ");
+                        else
+                            Sys_Printf (" ? ");
+                    } else {
+                        if (value & GLX_RGBA_FLOAT_ATI_BIT)
+                            Sys_Printf (" f ");
+                        else if (value & GLX_RGBA_BIT)
+                            Sys_Printf (" i ");
+                        else if (value & GLX_COLOR_INDEX_BIT)
+                            Sys_Printf (" c ");
+                        else
+                            Sys_Printf (" ? ");
+                    }
+                }*/
+                /* double buffer */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_DOUBLEBUFFER, &value);
+                Sys_Printf (" %c ", Success != ret ? '?' : (value ? 'y' : '.'));
+                /* stereo */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_STEREO, &value);
+                Sys_Printf (" %c ", Success != ret ? '?' : (value ? 'y' : '.'));
+                /* level */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_LEVEL, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    Sys_Printf ("%2d ", value);
+                }
+                /* transparency */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_TRANSPARENT_TYPE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? | ");
+                } else {
+                    if (GLX_TRANSPARENT_RGB == value)
+                        Sys_Printf (" r | ");
+                    else if (GLX_TRANSPARENT_INDEX == value)
+                        Sys_Printf (" i | ");
+                    else if (GLX_NONE == value)
+                        Sys_Printf (" . | ");
+                    else
+                        Sys_Printf (" ? | ");
+                }
+                /* color size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_BUFFER_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf ("  ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%3d ", value);
+                    else
+                        Sys_Printf ("  . ");
+                }
+                /* red size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_RED_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* green size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_GREEN_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* blue size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_BLUE_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* alpha size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_ALPHA_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? | ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d | ", value);
+                    else
+                        Sys_Printf (" . | ");
+                }
+                /* aux buffers */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_AUX_BUFFERS, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* depth size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_DEPTH_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* stencil size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_STENCIL_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? | ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d | ", value);
+                    else
+                        Sys_Printf (" . | ");
+                }
+                /* accum red size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_ACCUM_RED_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* accum green size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_ACCUM_GREEN_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* accum blue size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_ACCUM_BLUE_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d ", value);
+                    else
+                        Sys_Printf (" . ");
+                }
+                /* accum alpha size */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_ACCUM_ALPHA_SIZE, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? | ");
+                } else {
+                    if (value)
+                        Sys_Printf ("%2d | ", value);
+                    else
+                        Sys_Printf (" . | ");
+                }
+                /* multisample */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_SAMPLES, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? ");
+                } else {
+                    Sys_Printf ("%2d ", value);
+                }
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_SAMPLE_BUFFERS, &value);
+                if (Success != ret) {
+                    Sys_Printf (" ? | ");
+                } else {
+                    Sys_Printf ("%2d | ", value);
+                }
+                /* caveat */
+                ret = glXGetFBConfigAttrib (dpy, fbc[i], GLX_CONFIG_CAVEAT, &value);
+                if (Success != ret) {
+                    Sys_Printf ("???? |");
+                } else {
+                    if (GLX_NONE == value)
+                        Sys_Printf ("none |\n");
+                    else if (GLX_SLOW_CONFIG == value)
+                        Sys_Printf ("slow |\n");
+                    else if (GLX_NON_CONFORMANT_CONFIG == value)
+                        Sys_Printf ("ncft |\n");
+                    else
+                        Sys_Printf ("???? |\n");
+                }
+            }
+            /* print table footer */
+            Sys_Printf (" +-----+-------------------------+-----------------+----------+-------------+-------+------+\n");
+            Sys_Printf (" |  id | tp xr cl fm db st lv xp |  sz  r  g  b  a | bf th cl | r  g  b  a  | ns  b |  eat |\n");
+            Sys_Printf (" |     |        visual           |      color      | ax dp st |    accum    |   ms  |  cav |\n");
+            Sys_Printf (" +-----+-------------------------+-----------------+----------+-------------+-------+------+\n");
+        }
+    }
+}
+#endif
