@@ -24,7 +24,9 @@
 typedef unsigned short PIXEL16;
 typedef unsigned int PIXEL24;
 
-#include <ctype.h>
+#include "quakedef.h"
+
+//#include <ctype.h> // lxndr: moved to common
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -34,16 +36,12 @@ typedef unsigned int PIXEL24;
 #include <string.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/Xatom.h>
-#include <X11/keysym.h>
+
 #include <X11/extensions/XShm.h>
 
-#include "quakedef.h"
 #include "d_local.h"
 
-cvar_t        _windowed_mouse = { "_windowed_mouse", "0", CVAR_ARCHIVE };
+cvar_t        _windowed_mouse = { "_windowed_mouse", "1", CVAR_ARCHIVE };
 cvar_t        m_filter = { "m_filter", "0", CVAR_ARCHIVE };
 cvar_t        cl_keypad = { "cl_keypad", "1" };
 float         old_windowed_mouse;
@@ -62,7 +60,7 @@ int           p_mouse_x, p_mouse_y;
 int           ignorenext, bits_per_pixel;
 
 static qboolean doShm;
-static Display *x_disp;
+//static Display *x_disp; // lxndr: moved to common
 static Colormap x_cmap;
 static Window x_win;
 static GC     x_gc;
@@ -181,7 +179,7 @@ PIXEL24 xlib_rgb24 (int r, int g, int b) {
 
 void st2_fixup (XImage * framebuf, int x, int y, int width, int height) {
     int           xi, yi;
-    unsigned char *src;                // lxndr:
+    unsigned char *src;                // lxndr: warning
     PIXEL16      *dest;
 
     if (x < 0 || y < 0)
@@ -197,7 +195,7 @@ void st2_fixup (XImage * framebuf, int x, int y, int width, int height) {
 
 void st3_fixup (XImage * framebuf, int x, int y, int width, int height) {
     int           xi, yi;
-    unsigned char *src;                // lxndr:
+    unsigned char *src;                // lxndr: warning
     PIXEL24      *dest;
 
     if (x < 0 || y < 0)
@@ -397,30 +395,6 @@ void VID_Init (unsigned char *palette) {
     // for debugging only
     XSynchronize (x_disp, True);
 
-    // check for command-line window size
-    if ((pnum = COM_CheckParm ("-winsize"))) {
-        if (pnum >= com_argc - 2)
-            Sys_Error ("VID: -winsize <width> <height>\n");
-        vid.width = Q_atoi (com_argv[pnum + 1]);
-        vid.height = Q_atoi (com_argv[pnum + 2]);
-        if (!vid.width || !vid.height)
-            Sys_Error ("VID: Bad window width/height\n");
-    }
-    if ((pnum = COM_CheckParm ("-width"))) {
-        if (pnum >= com_argc - 1)
-            Sys_Error ("VID: -width <width>\n");
-        vid.width = Q_atoi (com_argv[pnum + 1]);
-        if (!vid.width)
-            Sys_Error ("VID: Bad window width\n");
-    }
-    if ((pnum = COM_CheckParm ("-height"))) {
-        if (pnum >= com_argc - 1)
-            Sys_Error ("VID: -height <height>\n");
-        vid.height = Q_atoi (com_argv[pnum + 1]);
-        if (!vid.height)
-            Sys_Error ("VID: Bad window height\n");
-    }
-
     template_mask = 0;
 
     // specify a visual id
@@ -451,6 +425,33 @@ void VID_Init (unsigned char *palette) {
         else
             Sys_Error ("VID: No visuals at depth %d\n", template.depth);
     }
+    // check for command-line window size
+    if (COM_CheckParm ("-current")) {
+        vid.width = DisplayWidth (x_disp, x_visinfo->screen);
+        vid.height = DisplayHeight (x_disp, x_visinfo->screen);
+    } else if ((pnum = COM_CheckParm ("-winsize"))) {
+        if (pnum >= com_argc - 2)
+            Sys_Error ("VID: -winsize <width> <height>\n");
+        vid.width = Q_atoi (com_argv[pnum + 1]);
+        vid.height = Q_atoi (com_argv[pnum + 2]);
+        if (!vid.width || !vid.height)
+            Sys_Error ("VID: Bad window width/height\n");
+    } else {
+        if ((pnum = COM_CheckParm ("-width"))) {
+            if (pnum >= com_argc - 1)
+                Sys_Error ("VID: -width <width>\n");
+            vid.width = Q_atoi (com_argv[pnum + 1]);
+            if (!vid.width)
+                Sys_Error ("VID: Bad window width\n");
+        }
+        if ((pnum = COM_CheckParm ("-height"))) {
+            if (pnum >= com_argc - 1)
+                Sys_Error ("VID: -height <height>\n");
+            vid.height = Q_atoi (com_argv[pnum + 1]);
+            if (!vid.height)
+                Sys_Error ("VID: Bad window height\n");
+        }
+    }
 
     if (verbose) {
         printf ("Using visualid %d:\n", (int) (x_visinfo->visualid));
@@ -462,6 +463,8 @@ void VID_Init (unsigned char *palette) {
         printf ("	bits_per_rgb %d\n", x_visinfo->bits_per_rgb);
     }
 
+    VID_DisableScreenSaver (x_disp);
+
     x_vis = x_visinfo->visual;
 
     // setup attributes for main window
@@ -479,8 +482,7 @@ void VID_Init (unsigned char *palette) {
         attribs.colormap = tmpcmap;
 
         // create the main window
-        x_win = XCreateWindow (x_disp, XRootWindow (x_disp, x_visinfo->screen), 0, 0,   // x,
-                               // y
+        x_win = XCreateWindow (x_disp, XRootWindow (x_disp, x_visinfo->screen), 0, 0,   // x, y
                                vid.width, vid.height, 0,        // borderwidth
                                x_visinfo->depth, InputOutput, x_vis, attribmask, &attribs);
         XStoreName (x_disp, x_win, ENGINE_NAME);
@@ -587,241 +589,11 @@ void VID_SetPalette (unsigned char *palette) {
 // Called at shutdown
 void VID_Shutdown (void) {
     Con_Printf ("VID_Shutdown\n");
+    VID_RestoreScreenSaver (x_disp);
     XAutoRepeatOn (x_disp);
     XCloseDisplay (x_disp);
 }
 
-int XLateKey (XKeyEvent * ev) {
-    int           key, kp;
-    char          buf[64];
-    KeySym        keysym;
-
-    key = 0;
-    kp = (int) cl_keypad.value;
-
-    XLookupString (ev, buf, sizeof buf, &keysym, 0);
-
-    switch (keysym) {
-        case XK_Scroll_Lock:
-            key = K_SCRLCK;
-            break;
-
-        case XK_Caps_Lock:
-            key = K_CAPSLOCK;
-            break;
-
-        case XK_Num_Lock:
-            key = kp ? KP_NUMLOCK : K_PAUSE;
-            break;
-
-        case XK_KP_Page_Up:
-            key = kp ? KP_PGUP : K_PGUP;
-            break;
-        case XK_Page_Up:
-            key = K_PGUP;
-            break;
-
-        case XK_KP_Page_Down:
-            key = kp ? KP_PGDN : K_PGDN;
-            break;
-        case XK_Page_Down:
-            key = K_PGDN;
-            break;
-
-        case XK_KP_Home:
-            key = kp ? KP_HOME : K_HOME;
-            break;
-        case XK_Home:
-            key = K_HOME;
-            break;
-
-        case XK_KP_End:
-            key = kp ? KP_END : K_END;
-            break;
-        case XK_End:
-            key = K_END;
-            break;
-
-        case XK_KP_Left:
-            key = kp ? KP_LEFTARROW : K_LEFTARROW;
-            break;
-        case XK_Left:
-            key = K_LEFTARROW;
-            break;
-
-        case XK_KP_Right:
-            key = kp ? KP_RIGHTARROW : K_RIGHTARROW;
-            break;
-        case XK_Right:
-            key = K_RIGHTARROW;
-            break;
-
-        case XK_KP_Down:
-            key = kp ? KP_DOWNARROW : K_DOWNARROW;
-            break;
-
-        case XK_Down:
-            key = K_DOWNARROW;
-            break;
-
-        case XK_KP_Up:
-            key = kp ? KP_UPARROW : K_UPARROW;
-            break;
-
-        case XK_Up:
-            key = K_UPARROW;
-            break;
-
-        case XK_Escape:
-            key = K_ESCAPE;
-            break;
-
-        case XK_KP_Enter:
-            key = kp ? KP_ENTER : K_ENTER;
-            break;
-
-        case XK_Return:
-            key = K_ENTER;
-            break;
-
-        case XK_Tab:
-            key = K_TAB;
-            break;
-
-        case XK_F1:
-            key = K_F1;
-            break;
-
-        case XK_F2:
-            key = K_F2;
-            break;
-
-        case XK_F3:
-            key = K_F3;
-            break;
-
-        case XK_F4:
-            key = K_F4;
-            break;
-
-        case XK_F5:
-            key = K_F5;
-            break;
-
-        case XK_F6:
-            key = K_F6;
-            break;
-
-        case XK_F7:
-            key = K_F7;
-            break;
-
-        case XK_F8:
-            key = K_F8;
-            break;
-
-        case XK_F9:
-            key = K_F9;
-            break;
-
-        case XK_F10:
-            key = K_F10;
-            break;
-
-        case XK_F11:
-            key = K_F11;
-            break;
-
-        case XK_F12:
-            key = K_F12;
-            break;
-
-        case XK_BackSpace:
-            key = K_BACKSPACE;
-            break;
-
-        case XK_KP_Delete:
-            key = kp ? KP_DEL : K_DEL;
-            break;
-        case XK_Delete:
-            key = K_DEL;
-            break;
-
-        case XK_Pause:
-            key = K_PAUSE;
-            break;
-
-        case XK_Shift_L:
-            key = K_LSHIFT;
-            break;
-        case XK_Shift_R:
-            key = K_RSHIFT;
-            break;
-
-        case XK_Execute:
-        case XK_Control_L:
-            key = K_LCTRL;
-            break;
-        case XK_Control_R:
-            key = K_RCTRL;
-            break;
-
-        case XK_Alt_L:
-        case XK_Meta_L:
-            key = K_LALT;
-            break;
-        case XK_Alt_R:
-        case XK_Meta_R:
-            key = K_RALT;
-            break;
-
-        case XK_Super_L:
-            key = K_LWIN;
-            break;
-        case XK_Super_R:
-            key = K_RWIN;
-            break;
-        case XK_Menu:
-            key = K_MENU;
-            break;
-
-        case XK_KP_Begin:
-            key = kp ? KP_5 : '5';
-            break;
-
-        case XK_KP_Insert:
-            key = kp ? KP_INS : K_INS;
-            break;
-        case XK_Insert:
-            key = K_INS;
-            break;
-
-        case XK_KP_Multiply:
-            key = kp ? KP_STAR : '*';
-            break;
-
-        case XK_KP_Add:
-            key = kp ? KP_PLUS : '+';
-            break;
-
-        case XK_KP_Subtract:
-            key = kp ? KP_MINUS : '-';
-            break;
-
-        case XK_KP_Divide:
-            key = kp ? KP_SLASH : '/';
-            break;
-
-        default:
-            key = *(unsigned char *) buf;
-            if (key >= 'A' && key <= 'Z')
-                key = key - 'A' + 'a';
-            break;
-    }
-
-    return key;
-}
-
 struct {
     int           key;
     int           down;
@@ -910,10 +682,13 @@ void GetEvent (void) {
     if (old_windowed_mouse != _windowed_mouse.value) {
         old_windowed_mouse = _windowed_mouse.value;
 
-        if (!_windowed_mouse.value)    // ungrab the pointer
+        if (!_windowed_mouse.value) {  // ungrab pointer and keyboard
             XUngrabPointer (x_disp, CurrentTime);
-        else                           // grab the pointer
+            XUngrabKeyboard (x_disp, CurrentTime);
+        } else {                       // grab pointer and keyboard
             XGrabPointer (x_disp, x_win, True, 0, GrabModeAsync, GrabModeAsync, x_win, None, CurrentTime);
+            XGrabKeyboard (x_disp, x_win, False, GrabModeAsync, GrabModeAsync, CurrentTime);
+        }
     }
 }
 
@@ -1080,9 +855,3 @@ void IN_Move (usercmd_t * cmd) {
     }
     mouse_x = mouse_y = 0.0;
 }
-
-void VID_LockBuffer (void) {
-}
-
-void VID_UnlockBuffer (void) {
-}
