@@ -36,32 +36,37 @@ cvar_t        lcd_x = { "lcd_x", "0" };
 cvar_t        lcd_yaw = { "lcd_yaw", "0" };
 #endif
 
-cvar_t        scr_ofsx = { "scr_ofsx", "0", CVAR_ARCHIVE };
-cvar_t        scr_ofsy = { "scr_ofsy", "2", CVAR_ARCHIVE };
-cvar_t        scr_ofsz = { "scr_ofsz", "0", CVAR_ARCHIVE };
+cvar_t        v_ofsx = { "v_ofsx", "0", CVAR_ARCHIVE };
+cvar_t        v_ofsy = { "v_ofsy", "2", CVAR_ARCHIVE };
+cvar_t        v_ofsz = { "v_ofsz", "0", CVAR_ARCHIVE };
 
 cvar_t        show_clock = { "show_clock", "0", CVAR_ARCHIVE };
-cvar_t        show_clock_x = { "show_clock_x", "-5", CVAR_ARCHIVE };
-cvar_t        show_clock_y = { "show_clock_y", "-1", CVAR_ARCHIVE };
+cvar_t        show_clock_x = { "show_clock_x", "-1", CVAR_ARCHIVE };
+cvar_t        show_clock_y = { "show_clock_y", "1", CVAR_ARCHIVE };
+cvar_t        show_debug = { "show_debug", "0" };
+cvar_t        show_debug_x = { "show_debug_x", "-1", CVAR_ARCHIVE };
+cvar_t        show_debug_y = { "show_debug_y", "5", CVAR_ARCHIVE };
 cvar_t        show_fps = { "show_fps", "0", CVAR_ARCHIVE };
-cvar_t        show_fps_x = { "show_fps_x", "-5", CVAR_ARCHIVE };
-cvar_t        show_fps_y = { "show_fps_y", "-2", CVAR_ARCHIVE };
+cvar_t        show_fps_x = { "show_fps_x", "-1", CVAR_ARCHIVE };
+cvar_t        show_fps_y = { "show_fps_y", "2", CVAR_ARCHIVE };
 cvar_t        show_speed = { "show_speed", "0" };
-cvar_t        show_stats = { "show_stats", "0" };
-cvar_t        show_stats_small = { "show_stats_small", "0" };
-cvar_t        show_stats_length = { "show_stats_length", "0.5" };
+cvar_t        show_stats = { "show_stats", "0", CVAR_ARCHIVE };
+cvar_t        show_stats_x = { "show_stats_x", "-1", CVAR_ARCHIVE };
+cvar_t        show_stats_y = { "show_stats_y", "0", CVAR_ARCHIVE };
+cvar_t        show_stats_small = { "show_stats_small", "1", CVAR_ARCHIVE };
+cvar_t        show_stats_length = { "show_stats_length", "2" };
 
 cvar_t        cl_rollangle = { "cl_rollangle", "5.0" };
 
-cvar_t        cl_bob = { "cl_bob", "0.02" };
-cvar_t        cl_bobcycle = { "cl_bobcycle", "0.666" }; // lxndr: was 0.6
-cvar_t        cl_bobup = { "cl_bobup", "0.5" };
+cvar_t        cl_bob = { "cl_bob", "0.005" };    // lxndr: was 0.02
+cvar_t        cl_bobcycle = { "cl_bobcycle", "0.333" }; // lxndr: was 0.6
+cvar_t        cl_bobup = { "cl_bobup", "0.25" }; // lxndr: was 0.5
 
 cvar_t        v_kicktime = { "v_kicktime", "0.5" };
 cvar_t        v_kickroll = { "v_kickroll", "0.6" };
 cvar_t        v_kickpitch = { "v_kickpitch", "0.6" };
 
-cvar_t        v_gunkick = { "v_gunkick", "0" };
+cvar_t        v_gunkick = { "v_gunkick", "2" };
 
 cvar_t        v_iyaw_cycle = { "v_iyaw_cycle", "2" };
 cvar_t        v_iroll_cycle = { "v_iroll_cycle", "0.5" };
@@ -76,17 +81,17 @@ cvar_t        crosshair = { "crosshair", "0", CVAR_ARCHIVE };
 cvar_t        crosshaircolor = { "crosshaircolor", "79", CVAR_ARCHIVE };
 cvar_t        crosshairsize = { "crosshairsize", "1" };
 
-cvar_t        v_contentblend = { "v_contentblend", "1" };
-cvar_t        v_damagecshift = { "v_damagecshift", "1" };
-cvar_t        v_quadcshift = { "v_quadcshift", "0.5" };
-cvar_t        v_suitcshift = { "v_suitcshift", "0.2" };
-cvar_t        v_ringcshift = { "v_ringcshift", "0.2" };
-cvar_t        v_pentcshift = { "v_pentcshift", "0.2" };
-
-cvar_t        v_bonusflash = { "v_bonusflash", "1" };
+cvar_t        v_cshiftbonus = { "v_cshiftbonus", "1", CVAR_ARCHIVE };
+cvar_t        v_cshiftcontent = { "v_cshiftcontent", "1", CVAR_ARCHIVE };
+cvar_t        v_cshiftdamage = { "v_cshiftdamage", "1", CVAR_ARCHIVE };
+cvar_t        v_cshiftpent = { "v_cshiftpent", "0.2", CVAR_ARCHIVE };
+cvar_t        v_cshiftquad = { "v_cshiftquad", "0.5", CVAR_ARCHIVE };
+cvar_t        v_cshiftring = { "v_cshiftring", "0.2", CVAR_ARCHIVE };
+cvar_t        v_cshiftsuit = { "v_cshiftsuit", "0.2", CVAR_ARCHIVE };
 
 float         v_dmg_time, v_dmg_roll, v_dmg_pitch;
 float         v_fps, v_fpsold;
+double        zoomtime;
 
 /*
  * V_CalcFPS
@@ -97,7 +102,7 @@ void V_CalcFPS (void) {
     extern int    fps_count;
 
     t = Sys_DoubleTime ();
-    if ((t - lastframetime) >= 1.0) {  // lxndr: was 1.0, changed for more accurate sampling
+    if ((t - lastframetime) > 0.1) {
         v_fpsold = v_fps;
         v_fps = fps_count / (t - lastframetime);
         fps_count = 0;
@@ -132,10 +137,12 @@ float V_CalcBob (float hspeed) {
     static float  bob;
     float         cycle, bobcycle;
 
-    if (cl_bobcycle.value <= 0)
+    if ((quore && !cl.onground) || cl_bobcycle.value <= 0)
         return 0;
 
     bobcycle = cl_bobcycle.value;
+    if (in_zoom.state & 1)
+        bobcycle *= 1.2;
 
     cycle = (cl.time - (int) (cl.time / bobcycle) * bobcycle) / bobcycle;
     if (cycle < cl_bobup.value)
@@ -253,21 +260,16 @@ cshift_t      cshift_lava = { {255, 80, 0}
 };
 
 #ifdef	GLQUAKE
-
-cvar_t        gl_cshiftpercent = { "gl_cshiftpercent", "100" };
-cvar_t        gl_hwblend = { "gl_hwblend", "1" };
-float         v_blend[4];              // rgba 0.0 - 1.0
+cvar_t        v_cshiftpercent = { "v_cshiftpercent", "100", CVAR_ARCHIVE };
 cvar_t        v_gamma = { "gl_gamma", "1.25", CVAR_ARCHIVE };
 cvar_t        v_contrast = { "gl_contrast", "1", CVAR_ARCHIVE };
+float         v_blend[4];              // rgba 0.0 - 1.0
 unsigned short ramps[3][256];
-
 #else
-
 byte          gammatable[256];         // palette is sent through this
 byte          current_pal[768];        // Tonik: used for screenshots
 cvar_t        v_gamma = { "gamma", "1", CVAR_ARCHIVE };
 cvar_t        v_contrast = { "contrast", "1", CVAR_ARCHIVE };
-
 #endif
 
 #ifndef GLQUAKE
@@ -334,7 +336,7 @@ void V_ParseDamage (void) {
     cl.cshifts[CSHIFT_DAMAGE].percent += 3 * damagecount;
     cl.cshifts[CSHIFT_DAMAGE].percent = bound (0, cl.cshifts[CSHIFT_DAMAGE].percent, 150);
 
-    fraction = bound (0, v_damagecshift.value, 1);
+    fraction = bound (0, v_cshiftdamage.value, 1);
     cl.cshifts[CSHIFT_DAMAGE].percent *= fraction;
 
     if (armor > blood) {
@@ -342,11 +344,11 @@ void V_ParseDamage (void) {
         cl.cshifts[CSHIFT_DAMAGE].destcolor[1] = 100;
         cl.cshifts[CSHIFT_DAMAGE].destcolor[2] = 100;
     } else if (armor) {
-        cl.cshifts[CSHIFT_DAMAGE].destcolor[0] = 220;
+        cl.cshifts[CSHIFT_DAMAGE].destcolor[0] = 200;   // lxndr: was 220
         cl.cshifts[CSHIFT_DAMAGE].destcolor[1] = 50;
         cl.cshifts[CSHIFT_DAMAGE].destcolor[2] = 50;
     } else {
-        cl.cshifts[CSHIFT_DAMAGE].destcolor[0] = 255;
+        cl.cshifts[CSHIFT_DAMAGE].destcolor[0] = 200;   // lxndr: was 255
         cl.cshifts[CSHIFT_DAMAGE].destcolor[1] = 0;
         cl.cshifts[CSHIFT_DAMAGE].destcolor[2] = 0;
     }
@@ -384,7 +386,7 @@ void V_cshift_f (void) {
  * When you run over an item, the server sends this command
  */
 void V_BonusFlash_f (void) {
-    if (!v_bonusflash.value)
+    if (!v_cshiftbonus.value)
         return;
 
     cl.cshifts[CSHIFT_BONUS].destcolor[0] = 215;
@@ -410,11 +412,8 @@ void V_KeepConstantLight (void) {
  * Underwater, lava, etc each has a color shift
  */
 void V_SetContentsColor (int contents) {
-    if (!v_contentblend.value) {
+    if (!v_cshiftcontent.value) {
         cl.cshifts[CSHIFT_CONTENTS] = cshift_empty;
-#ifdef GLQUAKE
-        cl.cshifts[CSHIFT_CONTENTS].percent *= 100;
-#endif
         return;
     }
 
@@ -438,19 +437,7 @@ void V_SetContentsColor (int contents) {
             V_KeepConstantLight ();
     }
 
-    if (v_contentblend.value > 0 && v_contentblend.value < 1 && contents != CONTENTS_EMPTY)
-        cl.cshifts[CSHIFT_CONTENTS].percent *= v_contentblend.value;
-
-#ifdef GLQUAKE
-    if (contents != CONTENTS_EMPTY) {
-        if (!gl_polyblend.value)
-            cl.cshifts[CSHIFT_CONTENTS].percent = 0;
-        else
-            cl.cshifts[CSHIFT_CONTENTS].percent *= gl_cshiftpercent.value;
-    } else {
-        cl.cshifts[CSHIFT_CONTENTS].percent *= 100;
-    }
-#endif
+    cl.cshifts[CSHIFT_CONTENTS].percent *= v_cshiftcontent.value;
 }
 
 #ifdef GLQUAKE
@@ -508,22 +495,22 @@ void V_CalcPowerupCshift (void) {
         cl.cshifts[CSHIFT_POWERUP].destcolor[0] = 0;
         cl.cshifts[CSHIFT_POWERUP].destcolor[1] = 0;
         cl.cshifts[CSHIFT_POWERUP].destcolor[2] = 255;
-        fraction = bound (0, v_quadcshift.value, 1);
+        fraction = bound (0, v_cshiftquad.value, 1);
     } else if (cl.items & IT_SUIT) {
         cl.cshifts[CSHIFT_POWERUP].destcolor[0] = 0;
         cl.cshifts[CSHIFT_POWERUP].destcolor[1] = 255;
         cl.cshifts[CSHIFT_POWERUP].destcolor[2] = 0;
-        fraction = bound (0, v_suitcshift.value, 1);
+        fraction = bound (0, v_cshiftsuit.value, 1);
     } else if (cl.items & IT_INVISIBILITY) {
         cl.cshifts[CSHIFT_POWERUP].destcolor[0] = 255;
         cl.cshifts[CSHIFT_POWERUP].destcolor[1] = 255;
         cl.cshifts[CSHIFT_POWERUP].destcolor[2] = 255;
-        fraction = bound (0, v_ringcshift.value, 1);
+        fraction = bound (0, v_cshiftring.value, 1);
     } else if (cl.items & IT_INVULNERABILITY) {
         cl.cshifts[CSHIFT_POWERUP].destcolor[0] = 255;
         cl.cshifts[CSHIFT_POWERUP].destcolor[1] = 255;
         cl.cshifts[CSHIFT_POWERUP].destcolor[2] = 0;
-        fraction = bound (0, v_pentcshift.value, 1);
+        fraction = bound (0, v_cshiftpent.value, 1);
     }
     cl.cshifts[CSHIFT_POWERUP].percent = 100 * fraction;
 }
@@ -536,6 +523,9 @@ void V_CalcBlend (void) {
     int           j;
     float         r, g, b, a, a2;
 
+    if (!gl_polyblend.value)
+        return;
+
     r = g = b = a = 0;
 
     if (cls.state != ca_connected) {
@@ -546,9 +536,15 @@ void V_CalcBlend (void) {
     }
 
     // drop the damage value
-    cl.cshifts[CSHIFT_DAMAGE].percent -= host_frametime * 150;
-    if (cl.cshifts[CSHIFT_DAMAGE].percent <= 0)
-        cl.cshifts[CSHIFT_DAMAGE].percent = 0;
+#  ifdef __DEVEL__
+    if (quore)
+        j = (100 - cl.stats[STAT_HEALTH]) / (5 - skill.value);
+    else
+#  endif
+        j = 0;
+    cl.cshifts[CSHIFT_DAMAGE].percent -= host_frametime * 150.0 / (skill.value + 2) * 2;        // lxndr: added skill scale
+    if (cl.cshifts[CSHIFT_DAMAGE].percent <= j)
+        cl.cshifts[CSHIFT_DAMAGE].percent = j;
 
     // drop the bonus value
     cl.cshifts[CSHIFT_BONUS].percent -= host_frametime * 100;
@@ -556,13 +552,10 @@ void V_CalcBlend (void) {
         cl.cshifts[CSHIFT_BONUS].percent = 0;
 
     for (j = 0; j < NUM_CSHIFTS; j++) {
-        if ((!gl_cshiftpercent.value || !gl_polyblend.value) && j != CSHIFT_CONTENTS)
+        if (!v_cshiftpercent.value)
             continue;
 
-        if (j == CSHIFT_CONTENTS)
-            a2 = cl.cshifts[j].percent / 100.0 / 255.0;
-        else
-            a2 = ((cl.cshifts[j].percent * gl_cshiftpercent.value) / 100.0) / 255.0;
+        a2 = ((cl.cshifts[j].percent * v_cshiftpercent.value) / 100.0) / 255.0;
 
         if (!a2)
             continue;
@@ -581,24 +574,22 @@ void V_CalcBlend (void) {
     v_blend[3] = bound (0, a, 1);
 }
 
-void V_AddLightBlend (float r, float g, float b, float a2) {
-    float         a;
-
-    if (!gl_polyblend.value || !gl_cshiftpercent.value)
+void V_AddLightBlend (float r, float g, float b, float a) {
+    if (!gl_polyblend.value || !v_cshiftpercent.value)
         return;
 
-    a2 *= gl_cshiftpercent.value / 100.0;
+    a *= v_cshiftpercent.value / 100.0;
 
-    v_blend[3] = a = v_blend[3] + a2 * (1 - v_blend[3]);
+    v_blend[3] = v_blend[3] + a * (1 - v_blend[3]);
 
-    if (!a)
+    if (!v_blend[3])
         return;
 
-    a2 /= a;
+    a /= v_blend[3];
 
-    v_blend[0] = v_blend[0] * (1 - a2) + r * a2;
-    v_blend[1] = v_blend[1] * (1 - a2) + g * a2;
-    v_blend[2] = v_blend[2] * (1 - a2) + b * a2;
+    v_blend[0] = v_blend[0] * (1 - a) + r * a;
+    v_blend[1] = v_blend[1] * (1 - a) + g * a;
+    v_blend[2] = v_blend[2] * (1 - a) + b * a;
 }
 #endif
 
@@ -607,70 +598,45 @@ void V_AddLightBlend (float r, float g, float b, float a2) {
  */
 #ifdef	GLQUAKE
 void V_UpdatePalette (void) {
-    int           i, j, c;
+    int           i, c;
     qboolean      new;
-    float         a, rgb[3], gamma, contrast;
-    static float  prev_blend[4], old_gamma, old_contrast, old_hwblend;
+    float         gamma, contrast;
+    static float  old_gamma, old_contrast;
     extern float  vid_gamma;
 
     new = false;
 
-    for (i = 0; i < 4; i++) {
-        if (v_blend[i] != prev_blend[i]) {
-            new = true;
-            prev_blend[i] = v_blend[i];
-        }
-    }
-
-    gamma = bound (0.3, v_gamma.value, 3);
+    gamma = bound (0.5, v_gamma.value, 4.5);
     if (gamma != old_gamma) {
         old_gamma = gamma;
         new = true;
     }
 
-    contrast = bound (1, v_contrast.value, 3);
+    contrast = bound (1, v_contrast.value, 5);
     if (contrast != old_contrast) {
         old_contrast = contrast;
         new = true;
     }
 
-    if (gl_hwblend.value != old_hwblend) {
-        new = true;
-        old_hwblend = gl_hwblend.value;
-    }
-
     if (!new)
         return;
 
-    a = v_blend[3];
-
-    if (!vid_hwgamma_enabled || !gl_hwblend.value)
-        a = 0;
-
-    rgb[0] = 255 * v_blend[0] * a;
-    rgb[1] = 255 * v_blend[1] * a;
-    rgb[2] = 255 * v_blend[2] * a;
-
-    a = 1 - a;
-
     if (vid_gamma != 1.0) {
         contrast = pow (contrast, vid_gamma);
         gamma /= vid_gamma;
     }
 
     for (i = 0; i < 256; i++) {
-        for (j = 0; j < 3; j++) {
-            // apply blend and contrast
-            c = (i * a + rgb[j]) * contrast;
-            if (c > 255)
-                c = 255;
-            // apply gamma
-            c = 255 * pow ((c + 0.5) / 255.5, gamma) + 0.5;
-            c = bound (0, c, 255);
-            ramps[j][i] = c << 8;
-        }
+        // apply contrast
+        c = i * contrast;
+        if (c > 255)
+            c = 255;
+        // apply gamma
+        c = 255 * pow ((c + 0.5) / 255.5, gamma) + 0.5;
+        c = bound (0, c, 255);
+        ramps[0][i] = ramps[1][i] = ramps[2][i] = c << 8;
     }
-    //Con_DPrintf("V_UpdatePalette\n");
+
     VID_SetDeviceGammaRamp ((unsigned short *) ramps);
 }
 #else                                  // !GLQUAKE
@@ -755,56 +721,16 @@ float angledelta (float a) {
     return a;
 }
 
+float healthscale;
+
 /*
- * CalcGunAngle
+ * V_CalcHealthScale
  */
-void CalcGunAngle (void) {
-    float         yaw, pitch, move, scale;
-    static float  oldyaw = 0, oldpitch = 0;
-
-    yaw = r_refdef.viewangles[YAW];
-    pitch = -r_refdef.viewangles[PITCH];
-
-    yaw = angledelta (yaw - r_refdef.viewangles[YAW]) * 0.4;
-    yaw = bound (-10, yaw, 10);
-
-    pitch = angledelta (-pitch - r_refdef.viewangles[PITCH]) * 0.4;
-    pitch = bound (-10, pitch, 10);
-
-    move = host_frametime * 20;
-    if (yaw > oldyaw) {
-        if (oldyaw + move < yaw)
-            yaw = oldyaw + move;
-    } else {
-        if (oldyaw - move > yaw)
-            yaw = oldyaw - move;
-    }
-
-    if (pitch > oldpitch) {
-        if (oldpitch + move < pitch)
-            pitch = oldpitch + move;
-    } else {
-        if (oldpitch - move > pitch)
-            pitch = oldpitch - move;
-    }
-
-    oldyaw = yaw;
-    oldpitch = pitch;
-
-    cl.viewent.angles[PITCH] = -(r_refdef.viewangles[PITCH] + pitch);
-    cl.viewent.angles[YAW] = r_refdef.viewangles[YAW] + yaw;
-    //    cl.viewent.angles[ROLL] = r_refdef.viewangles[ROLL];        // joe: this makes it fix when strafing
-
-    //    scale = v_idlescale.value * (loadscale + 1);
-    scale = v_idlescale.value;
-
-    cl.viewent.angles[PITCH] -= scale * sin (cl.time * v_ipitch_cycle.value) * v_ipitch_level.value;
-    cl.viewent.angles[YAW] -= scale * sin (cl.time * v_iyaw_cycle.value) * v_iyaw_level.value;
-    cl.viewent.angles[ROLL] -= scale * sin (cl.time * v_iroll_cycle.value) * v_iroll_level.value;
-
-    cl.viewent.angles[ROLL] -= scale * sin (cl.time) * 2;
-    cl.viewent.angles[PITCH] -= scale * fabs (sin (cl.time) + cos (cl.time)) / 2;
-    cl.viewent.angles[YAW] -= scale * sin (cl.time);
+void V_CalcHealthScale (void) {
+    if (sv_healthimpact.value)
+        healthscale = max (0, 100 - cl.stats[STAT_HEALTH]) / (50 / (skill.value + 1));
+    else
+        healthscale = 1;
 }
 
 /*
@@ -830,9 +756,13 @@ void V_BoundOffsets (void) {
  * Idle swaying
  */
 void V_AddIdle (void) {
-    r_refdef.viewangles[ROLL] += v_idlescale.value * sin (cl.time * v_iroll_cycle.value) * v_iroll_level.value;
-    r_refdef.viewangles[PITCH] += v_idlescale.value * sin (cl.time * v_ipitch_cycle.value) * v_ipitch_level.value;
-    r_refdef.viewangles[YAW] += v_idlescale.value * sin (cl.time * v_iyaw_cycle.value) * v_iyaw_level.value;
+    float         scale;
+
+    scale = v_idlescale.value * healthscale;
+
+    r_refdef.viewangles[ROLL] += scale * sin (cl.time * v_iroll_cycle.value) * v_iroll_level.value;
+    r_refdef.viewangles[PITCH] += scale * sin (cl.time * v_ipitch_cycle.value) * v_ipitch_level.value;
+    r_refdef.viewangles[YAW] += scale * sin (cl.time * v_iyaw_cycle.value) * v_iyaw_level.value;
 }
 
 /*
@@ -853,8 +783,185 @@ void V_CalcViewRoll (void) {
     }
 }
 
+/*
+ * CalcFov
+ */
+float CalcFov (float fov_x, float width, float height) {
+    float         a, x;
+
+    if (fov_x < 1 || fov_x > 179)
+        Sys_Error ("Bad fov: %f", fov_x);
+
+    x = width / tan (fov_x / 360 * M_PI);
+
+    a = atan (height / x);
+
+    a = a * 360 / M_PI;
+
+    return a;
+}
+
+/*
+ * InvCalcFov // lxndr: not used
+ */
+float InvCalcFov (float fov_y, float width, float height) {
+    float         a, x, fov_x;
+
+    a = fov_y * M_PI / 360;
+
+    x = height / tan (a);
+
+    fov_x = atan (width / x) * (360 / M_PI);
+
+    return fov_x;
+}
+
+/*
+ * V_CalcFov
+ */
+void V_CalcFov () {
+    extern cvar_t scr_fov;
+
+    if ((in_zoom.state & 1) && cl.stats[STAT_HEALTH] > 0) {
+        if (zoomtime < 5 && r_refdef.fov_x > (scr_fov.value - 20 + healthscale)) {
+            r_refdef.fov_x -= (50.0 / (1 + healthscale)) * host_frametime;
+            if (r_refdef.fov_x < (scr_fov.value - 20 + healthscale)) {
+                r_refdef.fov_x = scr_fov.value - 20 + healthscale;
+                zoomtime = 5;
+            } else {
+                zoomtime += host_frametime;
+            }
+        }
+    } else if (zoomtime > 0) {
+        r_refdef.fov_x += 80 * host_frametime;
+        if (r_refdef.fov_x > scr_fov.value) {
+            r_refdef.fov_x = scr_fov.value;
+            zoomtime = 0;
+        } else {
+            zoomtime -= host_frametime;
+        }
+    } else {
+        r_refdef.fov_x = scr_fov.value;
+    }
+    r_refdef.fov_y = CalcFov (r_refdef.fov_x, r_refdef.vrect.width, r_refdef.vrect.height);
+}
+
+/*
+ * V_CalcGunZoomOffset
+ */
+void V_CalcGunZoomOffset (float *outofsx, float *outofsy, float *outofsz) {
+    static float  ofsx, ofsy, ofsz;
+
+    if (in_zoom.state & 1) {
+        if (zoomtime < 5) {
+            if (ofsx < 2) {
+                ofsx += 5 * host_frametime;
+                if (ofsx > 2)
+                    ofsx = 2;
+            }
+            if (v_ofsy.value > 0) {
+                if (ofsy > (v_ofsy.value / 2)) {
+                    ofsy -= 2 * ofsy * host_frametime;
+                    if (ofsy < (v_ofsy.value / 2))
+                        ofsy = v_ofsy.value / 2;
+                }
+            } else {
+                if (ofsy < (v_ofsy.value / 2)) {
+                    ofsy += 2 * ofsy * host_frametime;
+                    if (ofsy > (v_ofsy.value / 2))
+                        ofsy = v_ofsy.value / 2;
+                }
+            }
+            if (ofsz < 5) {
+                ofsz += (20.0 / (1.0 + healthscale / 2)) * host_frametime;
+                if (ofsz > 5)
+                    ofsz = 5;
+            }
+        }
+    } else if (zoomtime > 0) {
+        ofsx -= 2 * host_frametime;
+        if (ofsx < v_ofsx.value)
+            ofsx = v_ofsx.value;
+        if (v_ofsy.value > 0) {
+            ofsy += 10 * ofsy * host_frametime;
+            if (ofsy > v_ofsy.value)
+                ofsy = v_ofsy.value;
+        } else {
+            ofsy -= 10 * ofsy * host_frametime;
+            if (ofsy < v_ofsy.value)
+                ofsy = v_ofsy.value;
+        }
+        ofsz -= (20 - healthscale / 2) * host_frametime;
+        if (ofsz < v_ofsz.value)
+            ofsz = v_ofsz.value;
+    } else {
+        ofsx = v_ofsx.value;
+        ofsy = v_ofsy.value;
+        ofsz = v_ofsz.value;
+    }
+    *outofsx = v_ofsx.value; // lxndr: disable x offset for now
+    *outofsy = ofsy;
+    *outofsz = ofsz;
+}
+
+/*
+ * V_CalcGunAngle
+ */
+void V_CalcGunAngle (float bob, float hspeed) {
+    float         yaw, pitch, move, scale;
+    static float  oldyaw = 0, oldpitch = 0;
+
+    yaw = r_refdef.viewangles[YAW];
+    pitch = -r_refdef.viewangles[PITCH];
+    yaw = angledelta (yaw - r_refdef.viewangles[YAW]) * 0.4;
+    yaw = bound (-10, yaw, 10);
+    pitch = angledelta (-pitch - r_refdef.viewangles[PITCH]) * 0.4;
+    pitch = bound (-10, pitch, 10);
+
+    move = host_frametime * 20;
+    if (yaw > oldyaw) {
+        if (oldyaw + move < yaw)
+            yaw = oldyaw + move;
+    } else {
+        if (oldyaw - move > yaw)
+            yaw = oldyaw - move;
+    }
+    if (pitch > oldpitch) {
+        if (oldpitch + move < pitch)
+            pitch = oldpitch + move;
+    } else {
+        if (oldpitch - move > pitch)
+            pitch = oldpitch - move;
+    }
+
+    oldyaw = yaw;
+    oldpitch = pitch;
+
+    cl.viewent.angles[PITCH] = -(r_refdef.viewangles[PITCH] + pitch);
+    cl.viewent.angles[YAW] = r_refdef.viewangles[YAW] + yaw;
+    //    cl.viewent.angles[ROLL] = r_refdef.viewangles[ROLL];        // joe: this makes it fix when strafing
+
+    scale = v_idlescale.value;
+
+    cl.viewent.angles[PITCH] -= scale * sin (cl.time * v_ipitch_cycle.value) * v_ipitch_level.value;
+    if (!(in_zoom.state & 1))
+        cl.viewent.angles[YAW] -= scale * sin (cl.time * v_iyaw_cycle.value) * v_iyaw_level.value;
+    cl.viewent.angles[ROLL] -= scale * sin (cl.time * v_iroll_cycle.value) * v_iroll_level.value;
+
+    if (!legacy) {
+        cl.viewent.angles[ROLL] -= scale * sin (cl.time) * 2;
+        cl.viewent.angles[PITCH] -= scale * fabs (sin (cl.time) + cos (cl.time)) / 2;
+        cl.viewent.angles[PITCH] -= scale * cl.velocity[2] / 100; // jumping
+        cl.viewent.angles[PITCH] -= hspeed / 100; // running
+        cl.viewent.angles[YAW] -= cos (tan (cl.time * cl.time)) / (50.0 / healthscale); // noise
+    }
+}
+
+/*
+ * V_AddViewWeapon
+ */
 void V_AddViewWeapon (float bob, float hspeed) {
-    //    int           i;
+    float         ofsx, ofsy, ofsz;
     vec3_t        forward, right, up;
     entity_t     *view;
 
@@ -872,25 +979,52 @@ void V_AddViewWeapon (float bob, float hspeed) {
 
     // set up gun position
     VectorCopy (cl.viewangles, view->angles);
-    CalcGunAngle ();
+    V_CalcGunAngle (bob, hspeed);          // lxndr: added parameters
+    V_CalcGunZoomOffset (&ofsx, &ofsy, &ofsz); // lxndr: added
+
+    // lxndr: compensate screen ratio
+    // there might be a cleaner way by playing with fov calculation within R_SetupGL or the like
+    // or by checking if CalcFov functions have the right width and height arguments
+    ofsz += (240 - (float) r_refdef.vrect.height / (float) r_refdef.vrect.width * 320) / 20;     // the 0.1 factor is guessed
+
+    if (legacy) {
+        ofsx += bob * 0.4;
+    } else {
+        if (!(in_zoom.state & 1))
+            ofsy += sin (cl.time * 8) * hspeed / 8000;
+        ofsz += bob / 8 + cl.velocity[2] / 200 + hspeed / 200;
+    }
+
+    // all weapon do not behave the same way, try to adjust values
+    switch (cl.stats[STAT_ACTIVEWEAPON]) {
+        case IT_SHOTGUN:
+        case IT_SUPER_SHOTGUN:
+            ofsz /= 2;
+            break;
+        case IT_GRENADE_LAUNCHER:
+            ofsz /= 1.5;
+            break;
+        case IT_ROCKET_LAUNCHER:
+        case IT_LIGHTNING:
+            ofsz /= 1.4;
+            break;
+        case IT_NAILGUN:
+        case IT_SUPER_NAILGUN:
+            ofsz /= 1.2;
+            break;
+        case IT_AXE:
+            if (in_zoom.state & 1)
+                ofsz /= 2;
+            ofsz += bob / 8 + cl.velocity[2] / 100;
+            break;
+        default:
+            ofsz /= 1.5;
+    }
 
     VectorCopy (r_refdef.vieworg, view->origin);
-
-    VectorMA (view->origin, scr_ofsx.value - fabs (bob * 0.1), forward, view->origin);
-    VectorMA (view->origin, scr_ofsy.value + sin (cl.time * 8) * hspeed / 800, right, view->origin);
-    VectorMA (view->origin, scr_ofsz.value - fabs (bob * 0.1), up, view->origin);
-
-    // fudge position around to keep amount of weapon visible roughly equal with different FOV
-    /*
-     * if (scr_viewsize.value == 110)
-     * view->origin[2] += 1;
-     * else if (scr_viewsize.value == 100)
-     * view->origin[2] += 2;
-     * else if (scr_viewsize.value == 90)
-     * view->origin[2] += 1;
-     * else if (scr_viewsize.value == 80)
-     * view->origin[2] += 0.5;
-     */
+    VectorMA (view->origin, ofsx, forward, view->origin);
+    VectorMA (view->origin, ofsy, right, view->origin);
+    VectorMA (view->origin, ofsz, up, view->origin);
 
     view->model = cl.model_precache[cl.stats[STAT_WEAPON]];
     view->frame = cl.stats[STAT_WEAPONFRAME];
@@ -931,6 +1065,7 @@ void V_CalcRefdef (void) {
     float         bob, hspeed;
 
     V_DriftPitch ();
+    V_CalcHealthScale ();
 
     // ent is the player model (visible when out of body)
     ent = &cl_entities[cl.viewentity];
@@ -981,8 +1116,8 @@ void V_CalcRefdef (void) {
         Chase_Update ();
 }
 
-#define	ELEMENT_X_COORD(var)	((var##_x.value < 0) ? vid.width - strlen(str) * 8 + 8 * var##_x.value: 8 * var##_x.value)
-#define	ELEMENT_Y_COORD(var)	((var##_y.value < 0) ? vid.height - sb_lines + 8 * var##_y.value : 8 * var##_y.value)
+#define	ELEMENT_X_COORD(var)	((var##_x.value < 0) ? hudwidth - strlen(str) * 8 + 8 * var##_x.value: 8 * var##_x.value)
+#define	ELEMENT_Y_COORD(var)	((var##_y.value < 0) ? hudheight - sb_lines + 8 * var##_y.value : 8 * var##_y.value)
 
 char         *LocalTime (char *format) {
     time_t        t;
@@ -1008,20 +1143,21 @@ void SCR_DrawClock (void) {
     if (!show_clock.value)
         return;
 
-    if (scr_con_current == vid.height)
-        return;                        // console is full screen
-
     switch ((int) show_clock.value) {
         case 2:
-            str = LocalTime ("%I:%M:%S %p");
+            str = LocalTime ("%I:%M:%S %P");
             break;
 
         case 3:
-            str = LocalTime ("%a %b %I:%M:%S %p");
+            str = LocalTime ("%a %b %d %I:%M:%S %P");
             break;
 
         case 4:
-            str = LocalTime ("%a %b %H:%M:%S");
+            str = LocalTime ("%a %d %b %H:%M:%S");
+            break;
+
+        case 5:
+            str = LocalTime ("%Y-%m-%d %H:%M:%S");
             break;
 
         default:
@@ -1034,20 +1170,49 @@ void SCR_DrawClock (void) {
     Draw_String (x, y, str);
 }
 
+/*
+ * SCR_DrawDebug
+ */
+void SCR_DrawDebug (void) {
+    static char   str[80];
+    int           x, y;
+    float         t;
+    static double lastframetime;
+
+    if (!show_debug.value)
+        return;
+
+    t = Sys_DoubleTime ();
+    if ((t - lastframetime) > 0.1) {
+        lastframetime = t;
+
+        Q_strncpyz (str, debugstr, sizeof (str));
+    }
+
+    x = ELEMENT_X_COORD (show_debug);
+    y = ELEMENT_Y_COORD (show_debug);
+    Draw_String (x, y, str);
+}
+
 /*
  * SCR_DrawFPS
  */
 void SCR_DrawFPS (void) {
+    static char   str[80];
     int           x, y;
-    char          str[80];
+    float         t;
+    static double lastframetime;
 
     if (!show_fps.value)
         return;
 
-    if (scr_con_current == vid.height)
-        return;                        // console is full screen
+    t = Sys_DoubleTime ();
+    if ((t - lastframetime) > 0.1) {
+        lastframetime = t;
+
+        Q_strncpyz (str, va ("%3.1f %s", v_fps, show_fps.value == 2 ? "fps" : ""), sizeof (str));
+    }
 
-    Q_snprintfz (str, sizeof (str), "%3.1f%s", v_fps + 0.05, show_fps.value == 2 ? " fps" : "");
     x = ELEMENT_X_COORD (show_fps);
     y = ELEMENT_Y_COORD (show_fps);
     Draw_String (x, y, str);
@@ -1067,6 +1232,9 @@ void SCR_DrawSpeed (void) {
     if (!show_speed.value)
         return;
 
+    if (con_forcedup || scr_con_current == conheight)
+        return;                        // console is full screen
+
     if (lastrealtime > realtime) {
         lastrealtime = 0;
         display_speed = -1;
@@ -1084,19 +1252,19 @@ void SCR_DrawSpeed (void) {
     if (display_speed >= 0) {
         sprintf (st, "%3d", (int) display_speed);
 
-        x = vid.width / 2 - 80;
+        x = hudwidth / 2 - 80;
 
         if (scr_viewsize.value >= 120)
-            y = vid.height - 16;
+            y = hudheight - 16;
 
         if (scr_viewsize.value < 120)
-            y = vid.height - 8 * 5;
+            y = hudheight - 8 * 5;
 
         if (scr_viewsize.value < 110)
-            y = vid.height - 8 * 8;
+            y = hudheight - 8 * 8;
 
         if (cl.intermission)
-            y = vid.height - 16;
+            y = hudheight - 16;
 
         Draw_Fill (x, y - 1, 160, 1, 10);
         Draw_Fill (x, y + 9, 160, 1, 10);
@@ -1131,6 +1299,8 @@ float         drawstats_limit;
  * SCR_DrawStats
  */
 void SCR_DrawStats (void) {
+    int           x, y;
+    char          str[80];
     int           mins, secs, tens;
     extern mpic_t *sb_colon, *sb_nums[2][11];
 
@@ -1142,25 +1312,35 @@ void SCR_DrawStats (void) {
     tens = (int) (cl.ctime * 10) % 10;
 
     if (!show_stats_small.value) {
-        Sbar_IntermissionNumber (vid.width - 140, 0, mins, 2, 0);
+        if (con_forcedup || scr_con_current == conheight)
+            return;                    // console is full screen
 
-        Draw_TransPic (vid.width - 92, 0, sb_colon);
-        Draw_TransPic (vid.width - 80, 0, sb_nums[0][secs / 10]);
-        Draw_TransPic (vid.width - 58, 0, sb_nums[0][secs % 10]);
+        Sbar_IntermissionNumber (hudwidth / 8, 0, mins, 2, 0);
 
-        Draw_TransPic (vid.width - 36, 0, sb_colon);
-        Draw_TransPic (vid.width - 24, 0, sb_nums[0][tens]);
+        Draw_TransPic (hudwidth / 8 + 46, 0, sb_colon);
+        Draw_TransPic (hudwidth / 8 + 64, 0, sb_nums[0][secs / 10]);
+        Draw_TransPic (hudwidth / 8 + 88, 0, sb_nums[0][secs % 10]);
+
+        Draw_TransPic (hudwidth / 8 + 110, 0, sb_colon);
+        Draw_TransPic (hudwidth / 8 + 128, 0, sb_nums[0][tens]);
 
         if (show_stats.value == 2 || show_stats.value == 4) {
-            Sbar_IntermissionNumber (vid.width - 48, 24, cl.stats[STAT_SECRETS], 2, 0);
-            Sbar_IntermissionNumber (vid.width - 72, 48, cl.stats[STAT_MONSTERS], 3, 0);
+            Sbar_IntermissionNumber (hudwidth / 8 + 160, 0, cl.stats[STAT_MONSTERS], 3, 0);
+            Sbar_IntermissionNumber (hudwidth / 8 + 240, 0, cl.stats[STAT_SECRETS], 2, 0);
         }
     } else {
-        Draw_String (vid.width - 56, 0, va ("%2i:%02i:%i", mins, secs, tens));
-        if (show_stats.value == 2 || show_stats.value == 4) {
-            Draw_String (vid.width - 16, 8, va ("%2i", cl.stats[STAT_SECRETS]));
-            Draw_String (vid.width - 24, 16, va ("%3i", cl.stats[STAT_MONSTERS]));
-        }
+
+        if (show_stats.value == 2 || show_stats.value == 4)
+            Q_strcpy (str,
+                      va ("%3i kills %2i secrets %02i:%02i:%i ", cl.stats[STAT_MONSTERS], cl.stats[STAT_SECRETS], mins,
+                          secs, tens));
+        else
+            Q_strcpy (str, va ("%02i:%02i:%i ", mins, secs, tens));
+
+        x = ELEMENT_X_COORD (show_stats);
+        y = ELEMENT_Y_COORD (show_stats);
+
+        Draw_String (x, y, str);
     }
 }
 
@@ -1198,8 +1378,8 @@ void SCR_DrawVolume (void) {
     else
         yofs = 8;
 
-    Draw_String (vid.width - 88, yofs, bar);
-    Draw_String (vid.width - 88, yofs + 8, "volume");
+    Draw_String (hudwidth - 88, yofs, bar);
+    Draw_String (hudwidth - 88, yofs + 8, "volume");
 }
 
 /*
@@ -1232,8 +1412,8 @@ void SCR_DrawPlaybackStats (void) {
     else
         yofs = 24;
 
-    Draw_String (vid.width - 136, yofs, va ("demo speed: %.1lfx", cl_demospeed.value));
-    Draw_String (vid.width - 136, yofs + 8, va ("playback mode: %s", cl_demorewind.value ? "rewind" : "forward"));
+    Draw_String (hudwidth - 136, yofs, va ("demo speed: %.1lfx", cl_demospeed.value));
+    Draw_String (hudwidth - 136, yofs + 8, va ("playback mode: %s", cl_demorewind.value ? "rewind" : "forward"));
 #endif
 }
 
@@ -1266,13 +1446,6 @@ void V_RenderView (void) {
     if (con_forcedup)
         return;
 
-    // don't allow cheats in multiplayer
-    if (cl.maxclients > 1) {
-        Cvar_SetValue (&scr_ofsx, 0);
-        Cvar_SetValue (&scr_ofsy, 0);
-        Cvar_SetValue (&scr_ofsz, 0);
-    }
-
     if (cls.state != ca_connected) {
 #ifdef GLQUAKE
         V_CalcBlend ();
@@ -1367,18 +1540,23 @@ void V_Init (void) {
     Cvar_Register (&crosshaircolor);
     Cvar_Register (&crosshairsize);
 
-    Cvar_Register (&scr_ofsx);
-    Cvar_Register (&scr_ofsy);
-    Cvar_Register (&scr_ofsz);
+    Cvar_Register (&v_ofsx);
+    Cvar_Register (&v_ofsy);
+    Cvar_Register (&v_ofsz);
 
     Cvar_Register (&show_clock);
     Cvar_Register (&show_clock_x);
     Cvar_Register (&show_clock_y);
+    Cvar_Register (&show_debug);
+    Cvar_Register (&show_debug_x);
+    Cvar_Register (&show_debug_y);
     Cvar_Register (&show_fps);
     Cvar_Register (&show_fps_x);
     Cvar_Register (&show_fps_y);
     Cvar_Register (&show_speed);
     Cvar_Register (&show_stats);
+    Cvar_Register (&show_stats_x);
+    Cvar_Register (&show_stats_y);
     Cvar_Register (&show_stats_small);
     Cvar_Register (&show_stats_length);
 
@@ -1394,16 +1572,15 @@ void V_Init (void) {
 
     Cvar_Register (&v_gunkick);
 
-    Cvar_Register (&v_bonusflash);
-    Cvar_Register (&v_contentblend);
-    Cvar_Register (&v_damagecshift);
-    Cvar_Register (&v_quadcshift);
-    Cvar_Register (&v_suitcshift);
-    Cvar_Register (&v_ringcshift);
-    Cvar_Register (&v_pentcshift);
+    Cvar_Register (&v_cshiftbonus);
+    Cvar_Register (&v_cshiftcontent);
+    Cvar_Register (&v_cshiftdamage);
+    Cvar_Register (&v_cshiftpent);
+    Cvar_Register (&v_cshiftquad);
+    Cvar_Register (&v_cshiftring);
+    Cvar_Register (&v_cshiftsuit);
 #ifdef GLQUAKE
-    Cvar_Register (&gl_cshiftpercent);
-    Cvar_Register (&gl_hwblend);
+    Cvar_Register (&v_cshiftpercent);
 #endif
 
     Cvar_Register (&v_gamma);
